@@ -2,15 +2,13 @@
 
 # Test if we are in a project directory:
 
-if [ ! -f "DC-massxpert-user-manual" ]
+if [ ! -f "DC-user-manual" ]
 then
-	if [ ! -f "DC-minexpert-user-manual" ]
-	then
-		echo "Please enter a project directory, either massxpert or minexpert."
-		exit 1
-	fi
+	echo "Please enter a project directory, either massxpert or minexpert."
+	exit 1
 fi
 
+
 echo "For each image dir, the unused images will stored in a \"unused\" directory."
 
 curDir=$(pwd)
