@@ -47,7 +47,7 @@
 #include "AboutDlg.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace massxpert
 {
@@ -217,4 +217,4 @@ namespace massxpert
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
