@@ -39,13 +39,13 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/IsotopicData.hpp>
+#include <libXpertMass/IsotopicData.hpp>
 
 
 /////////////////////// libmassgui includes
-#include <libmass/PolChemDefEntity.hpp>
-#include <libmass/Sequence.hpp>
-#include <libmassgui/IsotopicClusterGeneratorDlg.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
+#include <libXpertMass/Sequence.hpp>
+#include <libXpertMassGui/IsotopicClusterGeneratorDlg.hpp>
 
 
 /////////////////////// Local includes
@@ -56,7 +56,7 @@
 #include "../nongui/ConfigSetting.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -86,7 +86,7 @@ CalculatorWnd::CalculatorWnd(ProgramWindow *parent,
 
   // Start by creating the polymer chemistry definition.
 
-  msp_polChemDef = std::make_shared<libmass::PolChemDef>();
+  msp_polChemDef = std::make_shared<libXpertMass::PolChemDef>();
 
   if(polChemDefFilePath.isEmpty())
     {
@@ -111,7 +111,7 @@ CalculatorWnd::CalculatorWnd(ProgramWindow *parent,
 
 
     QString formula_string = "-H2O";
-  libmass::Formula formula(formula_string);
+  libXpertMass::Formula formula(formula_string);
 
   formula.validate(msp_polChemDef->getIsotopicDataCstSPtr());
 
@@ -314,7 +314,7 @@ CalculatorWnd::initialize()
 
   mpa_chemPadDlg = new CalculatorChemPadDlg(this);
 
-  if(!libmass::PolChemDef::renderXmlPolChemDefFile(msp_polChemDef))
+  if(!libXpertMass::PolChemDef::renderXmlPolChemDefFile(msp_polChemDef))
     return false;
 
   if(!populatePolChemDefComboBoxes())
@@ -364,7 +364,7 @@ CalculatorWnd::initialize()
 }
 
 
-libmass::PolChemDefCstSPtr
+libXpertMass::PolChemDefCstSPtr
 CalculatorWnd::polChemDef()
 {
   return msp_polChemDef;
@@ -396,7 +396,7 @@ CalculatorWnd::populatePolChemDefComboBoxes()
 
   for(iter = 0; iter < msp_polChemDef->monomerList().size(); ++iter)
     {
-      libmass::Monomer *monomer = msp_polChemDef->monomerList().at(iter);
+      libXpertMass::Monomer *monomer = msp_polChemDef->monomerList().at(iter);
 
       stringList << monomer->name();
     }
@@ -406,7 +406,7 @@ CalculatorWnd::populatePolChemDefComboBoxes()
 
   for(iter = 0; iter < msp_polChemDef->modifList().size(); ++iter)
     {
-      libmass::Modif *modif = msp_polChemDef->modifList().at(iter);
+      libXpertMass::Modif *modif = msp_polChemDef->modifList().at(iter);
 
       stringList << modif->name();
     }
@@ -488,8 +488,8 @@ CalculatorWnd::recordResult()
 {
   QString recorder =
     tr("Done: mono: %2 -- avg: %3\n")
-      .arg(m_tempPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_tempPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+      .arg(m_tempPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_tempPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   mpa_recorderDlg->record(recorder);
 }
@@ -499,9 +499,9 @@ void
 CalculatorWnd::updateSeedResultLineEdits()
 {
   m_ui.seedMonoMassLineEdit->setText(
-    m_seedPonderable.monoString(libmass::OLIGOMER_DEC_PLACES));
+    m_seedPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES));
   m_ui.seedAvgMassLineEdit->setText(
-    m_seedPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+    m_seedPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   // The m_resultPonderable must always be consistent with the data in
   // the corresponding lineEdits.
@@ -510,9 +510,9 @@ CalculatorWnd::updateSeedResultLineEdits()
   m_resultPonderable.setAvg(m_tempPonderable.avg());
 
   m_ui.resultMonoMassLineEdit->setText(
-    m_resultPonderable.monoString(libmass::OLIGOMER_DEC_PLACES));
+    m_resultPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES));
   m_ui.resultAvgMassLineEdit->setText(
-    m_resultPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+    m_resultPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 }
 
 
@@ -572,10 +572,10 @@ CalculatorWnd::addToResult()
     tr(
       "Added seed(mono: %1 ; avg: %2) \n"
       "to result(was mono:%3 ; avg: %4) \n")
-      .arg(m_seedPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_seedPonderable.avgString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_resultPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_resultPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+      .arg(m_seedPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_seedPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_resultPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_resultPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   // Make the calculations.
   m_resultPonderable.incrementMono(m_seedPonderable.mono());
@@ -584,9 +584,9 @@ CalculatorWnd::addToResult()
   // Update the lineEdits.
 
   m_ui.resultMonoMassLineEdit->setText(
-    m_resultPonderable.monoString(libmass::OLIGOMER_DEC_PLACES));
+    m_resultPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES));
   m_ui.resultAvgMassLineEdit->setText(
-    m_resultPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+    m_resultPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   // And now append the new recorder string to the recorder textEdit.
   mpa_recorderDlg->record(recorder);
@@ -634,10 +634,10 @@ CalculatorWnd::sendToResult()
     tr(
       "Sent seed(mono: %1 ; avg: %2) \n"
       "to result(was mono:%3 ; avg: %4) \n")
-      .arg(m_seedPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_seedPonderable.avgString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_resultPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_resultPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+      .arg(m_seedPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_seedPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_resultPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_resultPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   m_resultPonderable.setMono(m_seedPonderable.mono());
   m_resultPonderable.setAvg(m_seedPonderable.avg());
@@ -645,9 +645,9 @@ CalculatorWnd::sendToResult()
   // Update the lineEdits.
 
   m_ui.resultMonoMassLineEdit->setText(
-    m_resultPonderable.monoString(libmass::OLIGOMER_DEC_PLACES));
+    m_resultPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES));
   m_ui.resultAvgMassLineEdit->setText(
-    m_resultPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+    m_resultPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 }
 
 void
@@ -692,10 +692,10 @@ CalculatorWnd::removeFromResult()
     tr(
       "Removed seed(mono: %1 ; avg: %2) \n"
       "from result(was mono:%3 ; avg: %4) \n")
-      .arg(m_seedPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_seedPonderable.avgString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_resultPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_resultPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+      .arg(m_seedPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_seedPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_resultPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_resultPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   // Make the calculations.
   m_resultPonderable.decrementMono(m_seedPonderable.mono());
@@ -704,9 +704,9 @@ CalculatorWnd::removeFromResult()
   // Update the lineEdits.
 
   m_ui.resultMonoMassLineEdit->setText(
-    m_resultPonderable.monoString(libmass::OLIGOMER_DEC_PLACES));
+    m_resultPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES));
   m_ui.resultAvgMassLineEdit->setText(
-    m_resultPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+    m_resultPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   // And now append the new recorder string to the recorder textEdit.
   mpa_recorderDlg->record(recorder);
@@ -763,10 +763,10 @@ CalculatorWnd::addToSeed()
     tr(
       "Added result(mono: %1 ; avg: %2) \n"
       "to seed(was mono:%3 ; avg: %4) \n")
-      .arg(m_resultPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_resultPonderable.avgString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_seedPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_seedPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+      .arg(m_resultPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_resultPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_seedPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_seedPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   // Make the calculations.
   m_seedPonderable.incrementMono(m_resultPonderable.mono());
@@ -775,9 +775,9 @@ CalculatorWnd::addToSeed()
   // Update the lineEdits.
 
   m_ui.seedMonoMassLineEdit->setText(
-    m_seedPonderable.monoString(libmass::OLIGOMER_DEC_PLACES));
+    m_seedPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES));
   m_ui.seedAvgMassLineEdit->setText(
-    m_seedPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+    m_seedPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   // And now append the new recorder string to the recorder textEdit.
   mpa_recorderDlg->record(recorder);
@@ -795,10 +795,10 @@ CalculatorWnd::sendToSeed()
     tr(
       "Sent result(mono: %1 ; avg: %2) \n"
       "to seed(was mono:%3 ; avg: %4) \n")
-      .arg(m_resultPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_resultPonderable.avgString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_seedPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_seedPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+      .arg(m_resultPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_resultPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_seedPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_seedPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   m_seedPonderable.setMono(m_resultPonderable.mono());
   m_seedPonderable.setAvg(m_resultPonderable.avg());
@@ -806,9 +806,9 @@ CalculatorWnd::sendToSeed()
   // Update the lineEdits.
 
   m_ui.seedMonoMassLineEdit->setText(
-    m_seedPonderable.monoString(libmass::OLIGOMER_DEC_PLACES));
+    m_seedPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES));
   m_ui.seedAvgMassLineEdit->setText(
-    m_seedPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+    m_seedPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 }
 
 void
@@ -853,10 +853,10 @@ CalculatorWnd::removeFromSeed()
     tr(
       "Removed result(mono: %1 ; avg: %2) \n"
       "from seed(was mono:%3 ; avg: %4) \n")
-      .arg(m_resultPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_resultPonderable.avgString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_seedPonderable.monoString(libmass::OLIGOMER_DEC_PLACES))
-      .arg(m_seedPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+      .arg(m_resultPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_resultPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_seedPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES))
+      .arg(m_seedPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   // Make the calculations.
   m_seedPonderable.decrementMono(m_resultPonderable.mono());
@@ -865,9 +865,9 @@ CalculatorWnd::removeFromSeed()
   // Update the lineEdits.
 
   m_ui.seedMonoMassLineEdit->setText(
-    m_seedPonderable.monoString(libmass::OLIGOMER_DEC_PLACES));
+    m_seedPonderable.monoString(libXpertMass::OLIGOMER_DEC_PLACES));
   m_ui.seedAvgMassLineEdit->setText(
-    m_seedPonderable.avgString(libmass::OLIGOMER_DEC_PLACES));
+    m_seedPonderable.avgString(libXpertMass::OLIGOMER_DEC_PLACES));
 
   // And now append the new recorder string to the recorder textEdit.
   mpa_recorderDlg->record(recorder);
@@ -894,7 +894,7 @@ CalculatorWnd::apply(const QString &formula)
   bool calculationPerformed = false;
   int res                   = -1;
 
-  libmass::IsotopicDataSPtr isotopic_data_sp =
+  libXpertMass::IsotopicDataSPtr isotopic_data_sp =
     msp_polChemDef->getIsotopicDataSPtr();
 
   if(!isotopic_data_sp->size())
@@ -1207,7 +1207,7 @@ CalculatorWnd::formulaActionsComboBoxActivated(int index)
 void
 CalculatorWnd::isotopicPatternCalculation()
 {
-  libmassgui::IsotopicClusterGeneratorDlg *dlg = new libmassgui::IsotopicClusterGeneratorDlg(
+  libXpertMassGui::IsotopicClusterGeneratorDlg *dlg = new libXpertMassGui::IsotopicClusterGeneratorDlg(
     this, m_applicationName, "Isotopic cluster generator");
 
   dlg->show();
@@ -1228,7 +1228,7 @@ CalculatorWnd::accountFormula(const QString &formula, double times)
   // does that test for when the calculation is triggered by clicking
   // on the apply button.
 
-  libmass::IsotopicDataSPtr isotopic_data_sp =
+  libXpertMass::IsotopicDataSPtr isotopic_data_sp =
     msp_polChemDef->getIsotopicDataSPtr();
 
   if(!isotopic_data_sp->size())
@@ -1277,7 +1277,7 @@ CalculatorWnd::accountFormula(const QString &formula, double times)
       count = times;
     }
 
-  libmass::Modif fake(msp_polChemDef, "NOT_SET", formula_text);
+  libXpertMass::Modif fake(msp_polChemDef, "NOT_SET", formula_text);
 
   // First calculate the masses for the formula. These masses
   // become member data of the Modif.
@@ -1330,10 +1330,10 @@ CalculatorWnd::accountMonomer()
   // Locate and make a copy of the reference monomer, that we may not
   // use itself, as the formula parsing operation do modify the
   // object..
-  libmass::Monomer monomer(msp_polChemDef, "NOT_SET");
+  libXpertMass::Monomer monomer(msp_polChemDef, "NOT_SET");
 
   int index = -1;
-  index     = libmass::Monomer::isNameInList(
+  index     = libXpertMass::Monomer::isNameInList(
     text, msp_polChemDef->monomerList(), &monomer);
 
   // It cannot be that the text in the combobox does not correspond to
@@ -1374,11 +1374,11 @@ CalculatorWnd::accountModif()
 
   // Locate the reference modif and make a copy of it, as we may not
   // use itself, as the parsing operation do modify the object.
-  libmass::Modif modif(msp_polChemDef, "NOT_SET");
+  libXpertMass::Modif modif(msp_polChemDef, "NOT_SET");
   int index = -1;
 
   index =
-    libmass::Modif::isNameInList(text, msp_polChemDef->modifList(), &modif);
+    libXpertMass::Modif::isNameInList(text, msp_polChemDef->modifList(), &modif);
 
   // It cannot be that the text in the combobox does not correspond to
   // a known modif.
@@ -1420,7 +1420,7 @@ CalculatorWnd::accountSequence()
     return 0;
 
 
-  libmass::Sequence sequence(text);
+  libXpertMass::Sequence sequence(text);
 
   if(sequence.makeMonomerList(msp_polChemDef, false, 0) == -1)
     return -1;
@@ -1435,7 +1435,7 @@ CalculatorWnd::accountSequence()
 
   for(int iter = 0; iter < sequence.size(); ++iter)
     {
-      const libmass::Monomer *monomer = sequence.at(iter);
+      const libXpertMass::Monomer *monomer = sequence.at(iter);
       Q_ASSERT(monomer);
 
       if(!monomer->accountMasses(
@@ -1558,7 +1558,7 @@ CalculatorWnd::simplifyFormula()
   // To do the simplification we need the list of atoms of the
   // current polymer chemistry definition.
 
-  libmass::IsotopicDataSPtr isotopic_data_sp =
+  libXpertMass::IsotopicDataSPtr isotopic_data_sp =
     msp_polChemDef->getIsotopicDataSPtr();
 
   if(!isotopic_data_sp->size())
@@ -1590,7 +1590,7 @@ CalculatorWnd::simplifyFormula()
   // Validate the formula by creating a fake modification object
   // with it and by accounting masses for that formula.
 
-  libmass::Modif fake(msp_polChemDef, "NOT_SET", text);
+  libXpertMass::Modif fake(msp_polChemDef, "NOT_SET", text);
   if(!fake.calculateMasses())
     {
       QMessageBox::warning(
@@ -1622,4 +1622,4 @@ CalculatorWnd::simplifyFormula()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
