@@ -41,14 +41,14 @@
 /////////////////////// Local includes
 #include "ui_CalculatorWnd.h"
 #include "AbstractMainTaskWindow.hpp"
-#include "libmass/Ponderable.hpp"
-#include "libmass/PolChemDef.hpp"
+#include <libXpertMass/Ponderable.hpp>
+#include <libXpertMass/PolChemDef.hpp>
 #include "CalculatorRecorderDlg.hpp"
 #include "CalculatorChemPadDlg.hpp"
-#include <libmass/PolChemDefEntity.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -84,7 +84,7 @@ namespace massxpert
     int m_formulaHandling = FORMULA_HANDLING_IMMEDIATE;
 
 
-    libmass::PolChemDefCstSPtr polChemDef();
+    libXpertMass::PolChemDefCstSPtr polChemDef();
     QString polChemDefName();
 
     void updateWindowTitle();
@@ -133,14 +133,14 @@ namespace massxpert
     private:
     Ui::CalculatorWnd m_ui;
 
-    libmass::Ponderable m_seedPonderable;
-    libmass::Ponderable m_tempPonderable;
-    libmass::Ponderable m_resultPonderable;
+    libXpertMass::Ponderable m_seedPonderable;
+    libXpertMass::Ponderable m_tempPonderable;
+    libXpertMass::Ponderable m_resultPonderable;
 
     CalculatorRecorderDlg *mpa_recorderDlg = 0;
     CalculatorChemPadDlg *mpa_chemPadDlg   = 0;
 
-    libmass::PolChemDefSPtr msp_polChemDef;
+    libXpertMass::PolChemDefSPtr msp_polChemDef;
 
     void readSettings();
     void writeSettings();
@@ -152,7 +152,7 @@ namespace massxpert
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
 #endif // CALCULATOR_WND_HPP
