@@ -41,14 +41,15 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/PolChemDefEntity.hpp>
-#include <libmass/IsotopicClusterGenerator.hpp>
-#include <libmass/IsotopicClusterShaper.hpp>
-#include <libmass/IsotopicData.hpp>
-#include <libmass/MassPeakShaper.hpp>
-#include <libmass/MassPeakShaperConfig.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
+#include <libXpertMass/IsotopicDataUserConfigHandler.hpp>
+#include <libXpertMass/IsotopicClusterGenerator.hpp>
+#include <libXpertMass/IsotopicClusterShaper.hpp>
+#include <libXpertMass/IsotopicData.hpp>
+#include <libXpertMass/MassPeakShaper.hpp>
+#include <libXpertMass/MassPeakShaperConfig.hpp>
 
-#include <libmassgui/ColorSelector.hpp>
+#include <libXpertMassGui/ColorSelector.hpp>
 
 /////////////////////// Local includes
 #include "../nongui/globals.hpp"
@@ -56,7 +57,7 @@
 #include "CleaveOligomerTableViewModel.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -64,14 +65,14 @@ namespace massxpert
 
 
 CleavageDlg::CleavageDlg(SequenceEditorWnd *editorWnd,
-                         libmass::Polymer *polymer,
-                         libmass::PolChemDefCstSPtr polChemDefCstSPtr,
+                         libXpertMass::Polymer *polymer,
+                         libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr,
                          const QString &configSettingsFilePath,
                          const QString &applicationName,
                          const QString &description,
                          QByteArray hash,
-                         const libmass::CalcOptions &calcOptions,
-                         const libmass::IonizeRule *ionizeRule)
+                         const libXpertMass::CalcOptions &calcOptions,
+                         const libXpertMass::IonizeRule *ionizeRule)
   : AbstractSeqEdWndDependentDlg(editorWnd,
                                  polymer,
                                  polChemDefCstSPtr,
@@ -306,8 +307,8 @@ CleavageDlg::initialize()
 bool
 CleavageDlg::populateSelectedOligomerData()
 {
-  libmass::CoordinateList coordList;
-  libmass::Coordinates *coordinates = 0;
+  libXpertMass::CoordinateList coordList;
+  libXpertMass::Coordinates *coordinates = 0;
 
   if(!mp_editorWnd->mpa_editorGraphicsView->selectionIndices(&coordList))
     {
@@ -320,7 +321,7 @@ CleavageDlg::populateSelectedOligomerData()
       // whole polymer sequence. Set its coordinates to the list of
       // coordinates.
 
-      coordinates = new libmass::Coordinates(0, mp_polymer->size() - 1);
+      coordinates = new libXpertMass::Coordinates(0, mp_polymer->size() - 1);
 
       // Set the newly created coordinates to the coordinates list
       // that we'll feed into the calculation options.
@@ -344,7 +345,7 @@ CleavageDlg::populateSelectedOligomerData()
       // Set the selection data as if all of the sequence was to be
       // cleaved.
 
-      coordinates = new libmass::Coordinates(0, mp_polymer->size() - 1);
+      coordinates = new libXpertMass::Coordinates(0, mp_polymer->size() - 1);
 
       // Set the newly created coordinates to the coordinates list
       // that we'll feed into the calculation options.
@@ -364,7 +365,7 @@ CleavageDlg::populateSelectedOligomerData()
       // The cleavage is to be performed on the whole polymer
       // sequence.
 
-      coordinates = new libmass::Coordinates(0, mp_polymer->size() - 1);
+      coordinates = new libXpertMass::Coordinates(0, mp_polymer->size() - 1);
 
       // Set the newly created coordinates to the coordinates list
       // that we'll feed into the calculation options.
@@ -387,23 +388,23 @@ CleavageDlg::populateSelectedOligomerData()
 
   // We have to count the incomplete cross-links.
 
-  const libmass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
+  const libXpertMass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
 
   int crossLinkPartial = 0;
 
   for(int iter = 0; iter < crossLinkList.size(); ++iter)
     {
-      libmass::CrossLink *crossLink = crossLinkList.at(iter);
+      libXpertMass::CrossLink *crossLink = crossLinkList.at(iter);
 
       int ret = crossLink->encompassedBy(coordList);
 
-      if(ret == libmass::CROSS_LINK_ENCOMPASSED_FULL)
+      if(ret == libXpertMass::CROSS_LINK_ENCOMPASSED_FULL)
         {
           // 		qDebug() << __FILE__ << __LINE__
           // 			  << "CrossLink at iter:" << iter
           // 			  << "is fully encompassed";
         }
-      else if(ret == libmass::CROSS_LINK_ENCOMPASSED_PARTIAL)
+      else if(ret == libXpertMass::CROSS_LINK_ENCOMPASSED_PARTIAL)
         {
           // 		qDebug() << __FILE__ << __LINE__
           // 			  << "CrossLink at iter:" << iter
@@ -425,7 +426,7 @@ CleavageDlg::populateSelectedOligomerData()
       // region does not encompass all of the cross-linked material.
 
       QMessageBox::information(this,
-                               tr("massXpert - libmass::Polymer Cleavage"),
+                               tr("massXpert - libXpertMass::Polymer Cleavage"),
                                tr("There are incomplete cross-links"),
                                QMessageBox::Ok);
     }
@@ -448,7 +449,7 @@ CleavageDlg::populateCleaveSpecListWidget()
       iter < polChemDefRendering->getPolChemDef()->cleaveSpecList().size();
       ++iter)
     {
-      libmass::CleaveSpec *cleaveSpec =
+      libXpertMass::CleaveSpec *cleaveSpec =
         polChemDefRendering->getPolChemDef()->cleaveSpecList().at(iter);
       Q_ASSERT(cleaveSpec);
 
@@ -494,7 +495,7 @@ CleavageDlg::cleave()
 {
   // What's the cleavage agent ?
   int value                       = m_ui.cleavageAgentListWidget->currentRow();
-  libmass::CleaveSpec *cleaveSpec = mcsp_polChemDef->cleaveSpecList().at(value);
+  libXpertMass::CleaveSpec *cleaveSpec = mcsp_polChemDef->cleaveSpecList().at(value);
 
   // What's the asked level of partial cleavages?
   value = m_ui.partialCleavageSpinBox->value();
@@ -531,7 +532,7 @@ CleavageDlg::cleave()
       delete mpa_cleaver;
 
       QMessageBox::critical(this,
-                            tr("massXpert - libmass::Polymer Cleavage"),
+                            tr("massXpert - libXpertMass::Polymer Cleavage"),
                             tr("Failed to perform cleavage."),
                             QMessageBox::Ok);
       return;
@@ -601,34 +602,34 @@ CleavageDlg::cleave()
 
 
 void
-CleavageDlg::updateCleavageDetails(const libmass::CalcOptions &calcOptions)
+CleavageDlg::updateCleavageDetails(const libXpertMass::CalcOptions &calcOptions)
 {
-  if(calcOptions.capping() & libmass::CAP_LEFT)
+  if(calcOptions.capping() & libXpertMass::CAP_LEFT)
     m_ui.leftCapCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.leftCapCheckBox->setCheckState(Qt::Unchecked);
 
-  if(calcOptions.capping() & libmass::CAP_RIGHT)
+  if(calcOptions.capping() & libXpertMass::CAP_RIGHT)
     m_ui.rightCapCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.rightCapCheckBox->setCheckState(Qt::Unchecked);
 
-  if(calcOptions.polymerEntities() & libmass::POLYMER_CHEMENT_LEFT_END_MODIF)
+  if(calcOptions.polymerEntities() & libXpertMass::POLYMER_CHEMENT_LEFT_END_MODIF)
     m_ui.leftModifCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.leftModifCheckBox->setCheckState(Qt::Unchecked);
 
-  if(calcOptions.polymerEntities() & libmass::POLYMER_CHEMENT_RIGHT_END_MODIF)
+  if(calcOptions.polymerEntities() & libXpertMass::POLYMER_CHEMENT_RIGHT_END_MODIF)
     m_ui.rightModifCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.rightModifCheckBox->setCheckState(Qt::Unchecked);
 
-  if(calcOptions.monomerEntities() & libmass::MONOMER_CHEMENT_MODIF)
+  if(calcOptions.monomerEntities() & libXpertMass::MONOMER_CHEMENT_MODIF)
     m_ui.modificationsCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.modificationsCheckBox->setCheckState(Qt::Unchecked);
 
-  if(calcOptions.monomerEntities() & libmass::MONOMER_CHEMENT_CROSS_LINK)
+  if(calcOptions.monomerEntities() & libXpertMass::MONOMER_CHEMENT_CROSS_LINK)
     m_ui.crossLinksCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.crossLinksCheckBox->setCheckState(Qt::Unchecked);
@@ -862,7 +863,7 @@ CleavageDlg::traceColorPushButtonClicked()
   QPushButton *colored_push_button = m_ui.colorSelectorPushButton;
 
   // Allow (true) the user to select a color that has been chosen already.
-  QColor color = libmassgui::ColorSelector::chooseColor(true);
+  QColor color = libXpertMassGui::ColorSelector::chooseColor(true);
 
   if(color.isValid())
     {
@@ -956,7 +957,7 @@ CleavageDlg::configureMassPeakShaper()
 {
   if(mp_massPeakShaperConfigDlg == nullptr)
     {
-      mp_massPeakShaperConfigDlg = new libmassgui::MassPeakShaperConfigDlg(
+      mp_massPeakShaperConfigDlg = new libXpertMassGui::MassPeakShaperConfigDlg(
         this, m_applicationName, "Mass peak shaper configuration");
 
       if(mp_massPeakShaperConfigDlg == nullptr)
@@ -966,8 +967,8 @@ CleavageDlg::configureMassPeakShaper()
   // The signal below is only emitted when checking parameters worked ok.
   connect(
     mp_massPeakShaperConfigDlg,
-    &libmassgui::MassPeakShaperConfigDlg::updatedMassPeakShaperConfigSignal,
-    [this](const libmass::MassPeakShaperConfig &config) {
+    &libXpertMassGui::MassPeakShaperConfigDlg::updatedMassPeakShaperConfigSignal,
+    [this](const libXpertMass::MassPeakShaperConfig &config) {
       m_massPeakShaperConfig = config;
 
       // qDebug().noquote() << "Our local copy of the config:"
@@ -997,16 +998,17 @@ CleavageDlg::loadIsotopicDataFromFile()
       return false;
     }
 
-  QString error;
+  libXpertMass::IsotopicDataUserConfigHandler handler;
+  handler.loadData(file_name);
 
-  msp_isotopicData = libmass::loadIsotopicDataFromFile(file_name, error);
+  msp_isotopicData = handler.getIsotopicData();
 
-  if(msp_isotopicData == nullptr)
+  if(msp_isotopicData == nullptr || !msp_isotopicData->size())
     {
       QMessageBox::warning(
         this,
         QString("%1 - %2").arg(m_applicationName).arg(m_windowDescription),
-        error,
+        "Failed to load the isotopic data.",
         QMessageBox::Ok);
 
       return false;
@@ -1069,7 +1071,7 @@ CleavageDlg::synthesizeMassSpectra()
   // want a non-const shared pointer!
 
   if(msp_isotopicData == nullptr)
-    msp_isotopicData = std::make_shared<libmass::IsotopicData>(
+    msp_isotopicData = std::make_shared<libXpertMass::IsotopicData>(
       *mp_editorWnd->polChemDefRendering()->getPolChemDef()->getIsotopicDataCstSPtr());
 
   if(msp_isotopicData == nullptr)
@@ -1079,14 +1081,14 @@ CleavageDlg::synthesizeMassSpectra()
 
   // And now we can instantiate a cluster generator
 
-  libmass::IsotopicClusterGenerator isotopic_cluster_generator(
+  libXpertMass::IsotopicClusterGenerator isotopic_cluster_generator(
     msp_isotopicData);
 
   // Construct the formula/charge pairs needed for the isotopic cluster
   // calculations.
-  std::vector<libmass::FormulaChargePair> formula_charge_pairs;
+  std::vector<libXpertMass::FormulaChargePair> formula_charge_pairs;
 
-  for(libmass::OligomerSPtr oligomer_sp : selected_oligomers)
+  for(libXpertMass::OligomerSPtr oligomer_sp : selected_oligomers)
     {
       int charge           = oligomer_sp->charge();
       QString formula_text = oligomer_sp->elementalComposition();
@@ -1098,7 +1100,7 @@ CleavageDlg::synthesizeMassSpectra()
       // generator.
 
       formula_charge_pairs.push_back(
-        libmass::FormulaChargePair(formula_text, charge));
+        libXpertMass::FormulaChargePair(formula_text, charge));
     }
 
   // At this point, we can copy all the formula/charge pairs to the cluster
@@ -1107,7 +1109,7 @@ CleavageDlg::synthesizeMassSpectra()
   isotopic_cluster_generator.setFormulaChargePairs(formula_charge_pairs);
 
   isotopic_cluster_generator.setIsotopicDataType(
-    libmass::IsotopicDataType::LIBRARY_CONFIG);
+    libXpertMass::IsotopicDataType::LIBRARY_CONFIG);
 
   double cumulated_probabilities = m_ui.cumulatedProbsDoubleSpinBox->value();
   isotopic_cluster_generator.setMaxSummedProbability(cumulated_probabilities);
@@ -1121,7 +1123,7 @@ CleavageDlg::synthesizeMassSpectra()
 
   // And now perform the work. For each formula/charge pair, the generator will
   // create an isotopic cluster shaped trace associated to the corresponding
-  // charge in a libmass::IsotopicClusterChargePair. All these pairs are stored
+  // charge in a libXpertMass::IsotopicClusterChargePair. All these pairs are stored
   // in a vector.
 
   count = isotopic_cluster_generator.run();
@@ -1142,7 +1144,7 @@ CleavageDlg::synthesizeMassSpectra()
 
   // qDebug() << "The number of clusters generated:" << count;
 
-  std::vector<libmass::IsotopicClusterChargePair>
+  std::vector<libXpertMass::IsotopicClusterChargePair>
     isotopic_cluster_charge_pairs =
       isotopic_cluster_generator.getIsotopicClusterChargePairs();
 
@@ -1155,13 +1157,13 @@ CleavageDlg::synthesizeMassSpectra()
 
   // Note how we ask a reference to the pair that is iterated into, otherwise we
   // would get a copy and we would lose the local charge modification.
-  for(libmass::IsotopicClusterChargePair &pair : isotopic_cluster_charge_pairs)
+  for(libXpertMass::IsotopicClusterChargePair &pair : isotopic_cluster_charge_pairs)
     pair.second = 1;
 
   // Now instantiate the isotopic cluster shaper and set the clusters' data in
   // it.
 
-  libmass::IsotopicClusterShaper isotopic_cluster_shaper(
+  libXpertMass::IsotopicClusterShaper isotopic_cluster_shaper(
     isotopic_cluster_charge_pairs, m_massPeakShaperConfig);
 
   isotopic_cluster_shaper.setNormalizeIntensity(normalization_intensity);
@@ -1367,7 +1369,7 @@ CleavageDlg::prepareResultsTxtString(bool append)
   // Note that name and coords are optional.
   bool forXpertMiner         = false;
   bool noHeader              = false;
-  libmass::MassType massType = libmass::MassType::MASS_NONE;
+  libXpertMass::MassType massType = libXpertMass::MassType::MASS_NONE;
 
   forXpertMiner = m_ui.forXpertMinerCheckBox->isChecked();
   noHeader      = m_ui.noHeaderCheckBox->isChecked();
@@ -1377,7 +1379,7 @@ CleavageDlg::prepareResultsTxtString(bool append)
       *mpa_resultsString += QString(
                               "# \n"
                               "# ---------------------------\n"
-                              "# libmass::Polymer sequence cleavage: %1\n"
+                              "# libXpertMass::Polymer sequence cleavage: %1\n"
                               "# ---------------------------\n")
                               .arg(mp_polymer->name());
     }
@@ -1387,9 +1389,9 @@ CleavageDlg::prepareResultsTxtString(bool append)
       // the mono or avg masses.
 
       if(m_ui.monoRadioButton->isChecked())
-        massType = libmass::MassType::MASS_MONO;
+        massType = libXpertMass::MassType::MASS_MONO;
       else
-        massType = libmass::MassType::MASS_AVG;
+        massType = libXpertMass::MassType::MASS_AVG;
     }
 
   bool withSequence = m_ui.withSequenceCheckBox->isChecked();
@@ -1487,4 +1489,4 @@ CleavageDlg::selectResultsFile()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
