@@ -41,14 +41,14 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/IsotopicData.hpp>
-#include <libmass/MassPeakShaperConfig.hpp>
-#include <libmass/PolChemDefEntity.hpp>
-#include <libmass/IonizeRule.hpp>
+#include <libXpertMass/IsotopicData.hpp>
+#include <libXpertMass/MassPeakShaperConfig.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
+#include <libXpertMass/IonizeRule.hpp>
 
 
 /////////////////////// libmassgui includes
-#include <libmassgui/MassPeakShaperConfigDlg.hpp>
+#include <libXpertMassGui/MassPeakShaperConfigDlg.hpp>
 #include <pappsomspp/trace/trace.h>
 
 
@@ -60,7 +60,7 @@
 #include "CleaveOligomerTableViewSortProxyModel.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -85,14 +85,14 @@ class CleavageDlg : public AbstractSeqEdWndDependentDlg
 
   public:
   CleavageDlg(SequenceEditorWnd *editorWnd,
-              libmass::Polymer *polymer,
-              libmass::PolChemDefCstSPtr polChemDefCstSPtr,
+              libXpertMass::Polymer *polymer,
+              libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr,
               const QString &configSettingsFilePath,
               const QString &applicationName,
               const QString &description,
               QByteArray hash,
-              const libmass::CalcOptions &calcOptions,
-              const libmass::IonizeRule *ionizeRule);
+              const libXpertMass::CalcOptions &calcOptions,
+              const libXpertMass::IonizeRule *ionizeRule);
 
   ~CleavageDlg();
 
@@ -104,7 +104,7 @@ class CleavageDlg : public AbstractSeqEdWndDependentDlg
   SequenceEditorWnd *editorWnd();
   QByteArray polymerHash() const;
 
-  void updateCleavageDetails(const libmass::CalcOptions &);
+  void updateCleavageDetails(const libXpertMass::CalcOptions &);
   void updateOligomerSequence(QString *);
 
   bool calculateTolerance(double);
@@ -157,13 +157,13 @@ class CleavageDlg : public AbstractSeqEdWndDependentDlg
 
   OligomerList m_oligomerList;
 
-  libmass::IsotopicDataSPtr msp_isotopicData = nullptr;
-  libmass::MassPeakShaperConfig m_massPeakShaperConfig;
+  libXpertMass::IsotopicDataSPtr msp_isotopicData = nullptr;
+  libXpertMass::MassPeakShaperConfig m_massPeakShaperConfig;
 
   pappso::Trace m_syntheticMassSpectrum;
 
-  libmass::CalcOptions m_calcOptions;
-  const libmass::IonizeRule *mp_ionizeRule = nullptr;
+  libXpertMass::CalcOptions m_calcOptions;
+  const libXpertMass::IonizeRule *mp_ionizeRule = nullptr;
 
   Cleaver *mpa_cleaver;
 
@@ -173,7 +173,7 @@ class CleavageDlg : public AbstractSeqEdWndDependentDlg
   CleaveOligomerTableViewModel *mpa_oligomerTableViewModel;
   CleaveOligomerTableViewSortProxyModel *mpa_proxyModel;
 
-  libmassgui::MassPeakShaperConfigDlg *mp_massPeakShaperConfigDlg = nullptr;
+  libXpertMassGui::MassPeakShaperConfigDlg *mp_massPeakShaperConfigDlg = nullptr;
 
   // For the filtering of the data in the treeview.
   QAction *filterAct;
@@ -187,7 +187,7 @@ class CleavageDlg : public AbstractSeqEdWndDependentDlg
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
 #endif // CLEAVAGE_DLG_HPP
