@@ -44,12 +44,12 @@
 #include "../nongui/globals.hpp"
 #include "CleaveOligomerTableView.hpp"
 #include "CleaveOligomerTableViewSortProxyModel.hpp"
-#include "libmass/Oligomer.hpp"
+#include <libXpertMass/Oligomer.hpp>
 #include "CleavageDlg.hpp"
 #include "CleaveOligomerTableViewMimeData.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -218,7 +218,7 @@ CleaveOligomerTableView::selectedOligomers(OligomerList *oligomerList,
       // the user of the list of oligomers to highlight regions in
       // the sequence editor.
 
-      libmass::NoDeletePointerProp *prop = new libmass::NoDeletePointerProp(
+      libXpertMass::NoDeletePointerProp *prop = new libXpertMass::NoDeletePointerProp(
         "SEQUENCE_EDITOR_WND", static_cast<void *>(mp_parentDlg->editorWnd()));
 
       new_oligomer_sp->appendProp(prop);
@@ -239,7 +239,7 @@ CleaveOligomerTableView::selectedOligomersAsPlainText(
   QString delimiter,
   bool withSequence,
   bool forXpertMiner,
-  libmass::MassType massType) const
+  libXpertMass::MassType massType) const
 {
   // Let's get all the currently selected oligomers in one list.
   OligomerList oligomerList;
@@ -280,7 +280,7 @@ CleaveOligomerTableView::selectedOligomersAsPlainText(
 
   while(!oligomerList.isEmpty())
     {
-      // libmass::OligomerSPtr oligomer_sp = oligomerList.takeFirst();
+      // libXpertMass::OligomerSPtr oligomer_sp = oligomerList.takeFirst();
 
       CleaveOligomerSPtr oligomer_sp =
         std::dynamic_pointer_cast<CleaveOligomer>(oligomerList.takeFirst());
@@ -326,17 +326,17 @@ CleaveOligomerTableView::selectedOligomersAsPlainText(
 
 QString *
 CleaveOligomerTableView::selectedOligomersAsPlainTextWithDelimiter(
-  libmass::Oligomer *p_oligomer,
+  libXpertMass::Oligomer *p_oligomer,
   const QString &delimiter,
   bool withSequence,
   bool forXpertMiner,
-  libmass::MassType massType) const
+  libXpertMass::MassType massType) const
 {
   if(p_oligomer == nullptr)
     qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
   // For export to XpertMiner, we only want the masses asked for:
-  // libmass::MassType::MASS_MONO or MASS_AVG. Also, we want the format to be
+  // libXpertMass::MassType::MASS_MONO or MASS_AVG. Also, we want the format to be
   // :
 
   // mass <delim> charge <delim> name <delim> coords
@@ -346,23 +346,23 @@ CleaveOligomerTableView::selectedOligomersAsPlainTextWithDelimiter(
   if(!forXpertMiner)
     *text += QString("\n%1%2").arg(p_oligomer->description()).arg(delimiter);
 
-  if(forXpertMiner && massType == libmass::MassType::MASS_AVG)
+  if(forXpertMiner && massType == libXpertMass::MassType::MASS_AVG)
     {
     }
   else
     {
       *text += QString("%1%2")
-                 .arg(p_oligomer->monoString(libmass::OLIGOMER_DEC_PLACES))
+                 .arg(p_oligomer->monoString(libXpertMass::OLIGOMER_DEC_PLACES))
                  .arg(delimiter);
     }
 
-  if(forXpertMiner && massType == libmass::MassType::MASS_MONO)
+  if(forXpertMiner && massType == libXpertMass::MassType::MASS_MONO)
     {
     }
   else
     {
       *text += QString("%1%2")
-                 .arg(p_oligomer->avgString(libmass::OLIGOMER_DEC_PLACES))
+                 .arg(p_oligomer->avgString(libXpertMass::OLIGOMER_DEC_PLACES))
                  .arg(delimiter);
     }
 
@@ -373,7 +373,7 @@ CleaveOligomerTableView::selectedOligomersAsPlainTextWithDelimiter(
   *text +=
     QString("%1%2")
       .arg(
-        static_cast<libmass::CoordinateList *>(p_oligomer)->positionsAsText())
+        static_cast<libXpertMass::CoordinateList *>(p_oligomer)->positionsAsText())
       .arg(delimiter);
 
   if(!forXpertMiner)
@@ -398,7 +398,7 @@ CleaveOligomerTableView::selectedOligomersAsPlainTextWithDelimiter(
 
 QString *
 CleaveOligomerTableView::selectedOligomersAsPlainTextWithPattern(
-  libmass::Oligomer *p_oligomer, const QString &pattern) const
+  libXpertMass::Oligomer *p_oligomer, const QString &pattern) const
 {
   // We receive a pattern that we use to craft the output. The following
   // shortcuts are used:
@@ -499,13 +499,13 @@ CleaveOligomerTableView::selectedOligomersAsPlainTextWithPattern(
             }
           if(curChar == 'm')
             {
-              *text += p_oligomer->monoString(libmass::OLIGOMER_DEC_PLACES);
+              *text += p_oligomer->monoString(libXpertMass::OLIGOMER_DEC_PLACES);
               prevChar = ' ';
               continue;
             }
           if(curChar == 'a')
             {
-              *text += p_oligomer->avgString(libmass::OLIGOMER_DEC_PLACES);
+              *text += p_oligomer->avgString(libXpertMass::OLIGOMER_DEC_PLACES);
               prevChar = ' ';
               continue;
             }
@@ -529,7 +529,7 @@ CleaveOligomerTableView::selectedOligomersAsPlainTextWithPattern(
           if(curChar == 'l')
             {
               QString *sequence      = p_oligomer->monomerText();
-              QString elidedSequence = libmass::elideText(*sequence);
+              QString elidedSequence = libXpertMass::elideText(*sequence);
               delete sequence;
               *text += elidedSequence;
 
@@ -538,7 +538,7 @@ CleaveOligomerTableView::selectedOligomersAsPlainTextWithPattern(
             }
           if(curChar == 'c')
             {
-              *text += static_cast<libmass::CoordinateList *>(p_oligomer)
+              *text += static_cast<libXpertMass::CoordinateList *>(p_oligomer)
                          ->positionsAsText();
               prevChar = ' ';
               continue;
@@ -716,7 +716,7 @@ CleaveOligomerTableView::currentChanged(const QModelIndex &current,
   // Get the mass calculation engine's options out of the oligomer,
   // so that we can display them correctly.
 
-  libmass::CalcOptions calcOptions = oligomer_sp->calcOptions();
+  libXpertMass::CalcOptions calcOptions = oligomer_sp->calcOptions();
 
   mp_parentDlg->updateCleavageDetails(calcOptions);
 
@@ -746,15 +746,15 @@ CleaveOligomerTableView::itemActivated(const QModelIndex &index)
 
   SequenceEditorWnd *editorWnd = mp_parentDlg->editorWnd();
 
-  libmass::CoordinateList *coordinateList =
-    static_cast<libmass::CoordinateList *>(oligomer);
+  libXpertMass::CoordinateList *coordinateList =
+    static_cast<libXpertMass::CoordinateList *>(oligomer);
 
   // Remove the previous selection, so that we can start fresh.
   editorWnd->mpa_editorGraphicsView->resetSelection();
 
   for(int iter = 0; iter < coordinateList->size(); ++iter)
     {
-      libmass::Coordinates *coordinates = coordinateList->at(iter);
+      libXpertMass::Coordinates *coordinates = coordinateList->at(iter);
 
       int start = coordinates->start();
       int end   = coordinates->end();
@@ -789,14 +789,14 @@ CleaveOligomerTableView::itemActivated(const QModelIndex &index)
 void
 CleaveOligomerTableView::copyMono()
 {
-  return copyMassList(libmass::MassType::MASS_MONO);
+  return copyMassList(libXpertMass::MassType::MASS_MONO);
 }
 
 
 void
 CleaveOligomerTableView::copyAvg()
 {
-  return copyMassList(libmass::MassType::MASS_AVG);
+  return copyMassList(libXpertMass::MassType::MASS_AVG);
 }
 
 
@@ -831,10 +831,10 @@ CleaveOligomerTableView::copyMassList(int monoOrAvg)
       CleaveOligomer *oligomer =
         static_cast<CleaveOligomer *>(mp_oligomerList->at(sourceRow).get());
 
-      if(monoOrAvg == libmass::MassType::MASS_MONO)
-        massList += oligomer->monoString(libmass::OLIGOMER_DEC_PLACES);
-      else if(monoOrAvg == libmass::MassType::MASS_AVG)
-        massList += oligomer->avgString(libmass::OLIGOMER_DEC_PLACES);
+      if(monoOrAvg == libXpertMass::MassType::MASS_MONO)
+        massList += oligomer->monoString(libXpertMass::OLIGOMER_DEC_PLACES);
+      else if(monoOrAvg == libXpertMass::MassType::MASS_AVG)
+        massList += oligomer->avgString(libXpertMass::OLIGOMER_DEC_PLACES);
       else
         qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
@@ -852,4 +852,4 @@ CleaveOligomerTableView::copyMassList(int monoOrAvg)
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
