@@ -37,8 +37,8 @@
 
 
 /////////////////////// libmass includes
-#include "libmass/PolChemDef.hpp"
-#include <libmass/PolChemDefEntity.hpp>
+#include <libXpertMass/PolChemDef.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
 
 
 /////////////////////// Local includes
@@ -46,14 +46,14 @@
 #include "PolChemDefWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
 {
 
 
-CleaveSpecDefDlg::CleaveSpecDefDlg(libmass::PolChemDefSPtr polChemDefSPtr,
+CleaveSpecDefDlg::CleaveSpecDefDlg(libXpertMass::PolChemDefSPtr polChemDefSPtr,
                                    PolChemDefWnd *polChemDefWnd,
                                    const QString &settingsFilePath,
                                    const QString &applicationName,
@@ -134,7 +134,7 @@ CleaveSpecDefDlg::initialize()
 
   for(int iter = 0; iter < mp_list->size(); ++iter)
     {
-      libmass::CleaveSpec *cleaveSpec = mp_list->at(iter);
+      libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(iter);
 
       m_ui.cleaveSpecListWidget->addItem(cleaveSpec->name());
     }
@@ -221,7 +221,7 @@ CleaveSpecDefDlg::addCleaveSpecPushButtonClicked()
   // Returns -1 if the list is empty.
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
-  libmass::CleaveSpec *newCleaveSpec = new libmass::CleaveSpec(
+  libXpertMass::CleaveSpec *newCleaveSpec = new libXpertMass::CleaveSpec(
     msp_polChemDef, tr("Type Spec Name"), tr("Type Pattern"));
 
   mp_list->insert(index, newCleaveSpec);
@@ -261,7 +261,7 @@ CleaveSpecDefDlg::removeCleaveSpecPushButtonClicked()
   QListWidgetItem *item = m_ui.cleaveSpecListWidget->takeItem(index);
   delete item;
 
-  libmass::CleaveSpec *cleaveSpec = mp_list->takeAt(index);
+  libXpertMass::CleaveSpec *cleaveSpec = mp_list->takeAt(index);
   Q_ASSERT(cleaveSpec);
   delete cleaveSpec;
 
@@ -374,12 +374,12 @@ CleaveSpecDefDlg::addCleaveRulePushButtonClicked()
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
   // What's the actual cleaveSpec?
-  libmass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
   Q_ASSERT(cleaveSpec);
 
   // Allocate the new cleaveRule.
-  libmass::CleaveRule *newCleaveRule =
-    new libmass::CleaveRule(msp_polChemDef, tr("Type Rule Name"));
+  libXpertMass::CleaveRule *newCleaveRule =
+    new libXpertMass::CleaveRule(msp_polChemDef, tr("Type Rule Name"));
 
   // Get the row index of the current cleaveRule item. Returns -1 if the
   // list is empty.
@@ -418,7 +418,7 @@ CleaveSpecDefDlg::removeCleaveRulePushButtonClicked()
   // which cleaveSpec we'll remove the cleaveRule.
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
-  libmass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
   Q_ASSERT(cleaveSpec);
 
   // Get the index of the current cleaveRule.
@@ -433,9 +433,9 @@ CleaveSpecDefDlg::removeCleaveRulePushButtonClicked()
 
   // Remove the cleaveRule from the cleaveSpec proper.
 
-  QList<libmass::CleaveRule *> *cleaveRuleList = cleaveSpec->ruleList();
+  QList<libXpertMass::CleaveRule *> *cleaveRuleList = cleaveSpec->ruleList();
 
-  libmass::CleaveRule *cleaveRule = cleaveRuleList->at(index);
+  libXpertMass::CleaveRule *cleaveRule = cleaveRuleList->at(index);
 
   cleaveSpec->ruleList()->removeAt(index);
   delete cleaveRule;
@@ -480,7 +480,7 @@ CleaveSpecDefDlg::moveUpCleaveRulePushButtonClicked()
 
   // Get the cleaveSpec to which the cleaveRule belongs.
   int index                       = m_ui.cleaveSpecListWidget->currentRow();
-  libmass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
 
   // Get the index of the current cleaveRule item.
   index = m_ui.cleaveRuleListWidget->currentRow();
@@ -490,7 +490,7 @@ CleaveSpecDefDlg::moveUpCleaveRulePushButtonClicked()
     return;
 
   // Get the cleaveRule itself from the cleaveSpec.
-  libmass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
+  libXpertMass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
 
   cleaveSpec->ruleList()->removeAt(index);
   cleaveSpec->ruleList()->insert(index - 1, cleaveRule);
@@ -519,7 +519,7 @@ CleaveSpecDefDlg::moveDownCleaveRulePushButtonClicked()
 
   // Get the cleaveSpec to which the cleaveRule belongs.
   int index                       = m_ui.cleaveSpecListWidget->currentRow();
-  libmass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
 
   // Get the index of the current cleaveRule item.
   index = m_ui.cleaveRuleListWidget->currentRow();
@@ -529,7 +529,7 @@ CleaveSpecDefDlg::moveDownCleaveRulePushButtonClicked()
     return;
 
   // Get the cleaveRule itself from the cleaveSpec.
-  libmass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
+  libXpertMass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
 
   cleaveSpec->ruleList()->removeAt(index);
   cleaveSpec->ruleList()->insert(index + 1, cleaveRule);
@@ -559,7 +559,7 @@ CleaveSpecDefDlg::applyCleaveSpecPushButtonClicked()
   // Get the index of the current cleaveSpec item.
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
-  libmass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
 
   // We do not want more than one cleaveSpec by the same name or the same
   // symbol.
@@ -571,7 +571,7 @@ CleaveSpecDefDlg::applyCleaveSpecPushButtonClicked()
   // cleaveSpec is not the one that is current in the cleaveSpec list,
   // then we are making a double entry, which is not allowed.
 
-  int nameRes = libmass::CleaveSpec::isNameInList(editName, *mp_list);
+  int nameRes = libXpertMass::CleaveSpec::isNameInList(editName, *mp_list);
   if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
@@ -581,7 +581,7 @@ CleaveSpecDefDlg::applyCleaveSpecPushButtonClicked()
       return;
     }
 
-  libmass::CleaveSpec newSpec(msp_polChemDef, "NOT_SET", editPattern);
+  libXpertMass::CleaveSpec newSpec(msp_polChemDef, "NOT_SET", editPattern);
   if(!newSpec.parse())
     {
       QMessageBox::warning(this,
@@ -618,13 +618,13 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
 
   // Get the cleaveSpec to which the cleaveRule belongs.
   int index                       = m_ui.cleaveSpecListWidget->currentRow();
-  libmass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
 
   // Get the index of the current cleaveRule item.
   index = m_ui.cleaveRuleListWidget->currentRow();
 
   // Get the cleaveRule itself from the cleaveSpec.
-  libmass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
+  libXpertMass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
 
   QString editName = m_ui.cleaveRuleNameLineEdit->text();
 
@@ -641,7 +641,7 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
   // then we are making a double entry, which is not allowed.
 
   int nameRes =
-    libmass::CleaveRule::isNameInList(editName, *cleaveSpec->ruleList());
+    libXpertMass::CleaveRule::isNameInList(editName, *cleaveSpec->ruleList());
   if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
@@ -654,10 +654,10 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
 
   if(!leftCode.isEmpty())
     {
-      const QList<libmass::Monomer *> &monomerList =
+      const QList<libXpertMass::Monomer *> &monomerList =
         msp_polChemDef->monomerList();
 
-      if(libmass::Monomer::isCodeInList(leftCode, monomerList) == -1)
+      if(libXpertMass::Monomer::isCodeInList(leftCode, monomerList) == -1)
         {
           QMessageBox::warning(this,
                                tr("massXpert - Cleavage definition"),
@@ -667,15 +667,15 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
         }
 
 
-      libmass::Formula formula(leftFormula);
+      libXpertMass::Formula formula(leftFormula);
 
-      libmass::IsotopicDataSPtr isotopic_data_sp =
+      libXpertMass::IsotopicDataSPtr isotopic_data_sp =
         msp_polChemDef->getIsotopicDataSPtr();
 
       if(!formula.validate(isotopic_data_sp))
         {
           QMessageBox::warning(this,
-                               tr("massXpert - libmass::Monomer definition"),
+                               tr("massXpert - libXpertMass::Monomer definition"),
                                tr("The formula failed to validate."),
                                QMessageBox::Ok);
           return;
@@ -684,10 +684,10 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
 
   if(!rightCode.isEmpty())
     {
-      const QList<libmass::Monomer *> &monomerList =
+      const QList<libXpertMass::Monomer *> &monomerList =
         msp_polChemDef->monomerList();
 
-      if(libmass::Monomer::isCodeInList(rightCode, monomerList) == -1)
+      if(libXpertMass::Monomer::isCodeInList(rightCode, monomerList) == -1)
         {
           QMessageBox::warning(this,
                                tr("massXpert - Cleavage definition"),
@@ -696,15 +696,15 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
           return;
         }
 
-      libmass::Formula formula(rightFormula);
+      libXpertMass::Formula formula(rightFormula);
 
-      libmass::IsotopicDataSPtr isotopic_data_sp =
+      libXpertMass::IsotopicDataSPtr isotopic_data_sp =
         msp_polChemDef->getIsotopicDataSPtr();
 
       if(!formula.validate(isotopic_data_sp))
         {
           QMessageBox::warning(this,
-                               tr("massXpert - libmass::Monomer definition"),
+                               tr("massXpert - libXpertMass::Monomer definition"),
                                tr("The formula failed to validate."),
                                QMessageBox::Ok);
           return;
@@ -757,7 +757,7 @@ CleaveSpecDefDlg::validatePushButtonClicked()
     {
       QListWidgetItem *item = m_ui.cleaveSpecListWidget->item(iter);
 
-      libmass::CleaveSpec *cleaveSpec = mp_list->at(iter);
+      libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(iter);
 
       if(item->text() != cleaveSpec->name())
         errorList << QString(tr("\nCleavage at index %1 has not the same\n"
@@ -807,7 +807,7 @@ CleaveSpecDefDlg::cleaveSpecListWidgetItemSelectionChanged()
   // Get the index of the current cleaveSpec.
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
-  libmass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
   Q_ASSERT(cleaveSpec);
 
   // Set the data of the cleaveSpec to their respective widgets.
@@ -818,7 +818,7 @@ CleaveSpecDefDlg::cleaveSpecListWidgetItemSelectionChanged()
 
   for(int iter = 0; iter < cleaveSpec->ruleList()->size(); ++iter)
     {
-      libmass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(iter);
+      libXpertMass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(iter);
 
       m_ui.cleaveRuleListWidget->addItem(cleaveRule->name());
     }
@@ -850,7 +850,7 @@ CleaveSpecDefDlg::cleaveRuleListWidgetItemSelectionChanged()
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
   // Find the cleaveRule object in the list of cleaveRules.
-  libmass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
   Q_ASSERT(cleaveSpec);
 
   // Get the index of the current cleaveRule.
@@ -858,7 +858,7 @@ CleaveSpecDefDlg::cleaveRuleListWidgetItemSelectionChanged()
 
   // Get the cleaveRule that is currently selected from the cleaveSpec's list
   // of cleaveRules.
-  libmass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
+  libXpertMass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
   Q_ASSERT(cleaveRule);
 
   // Set the data of the cleaveRule to their respective widgets.
@@ -868,7 +868,7 @@ CleaveSpecDefDlg::cleaveRuleListWidgetItemSelectionChanged()
 
 void
 CleaveSpecDefDlg::updateCleaveSpecIdentityDetails(
-  libmass::CleaveSpec *cleaveSpec)
+  libXpertMass::CleaveSpec *cleaveSpec)
 {
   if(cleaveSpec)
     {
@@ -884,7 +884,7 @@ CleaveSpecDefDlg::updateCleaveSpecIdentityDetails(
 
 
 void
-CleaveSpecDefDlg::updateCleaveRuleDetails(libmass::CleaveRule *cleaveRule)
+CleaveSpecDefDlg::updateCleaveRuleDetails(libXpertMass::CleaveRule *cleaveRule)
 {
   if(cleaveRule)
     {
@@ -934,4 +934,4 @@ CleaveSpecDefDlg::validate()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
