@@ -38,15 +38,15 @@
 
 
 /////////////////////// libmass includes
-#include "libmass/Coordinates.hpp"
-#include "libmass/CrossLink.hpp"
-#include "libmass/Monomer.hpp"
+#include <libXpertMass/Coordinates.hpp>
+#include <libXpertMass/CrossLink.hpp>
+#include <libXpertMass/Monomer.hpp>
 
 
 /////////////////////// Local includes
 #include "CompositionsDlg.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -54,13 +54,13 @@ namespace massxpert
 
 
 CompositionsDlg::CompositionsDlg(SequenceEditorWnd *editorWnd,
-                                 libmass::Polymer *polymer,
-                                 /* no libmass::PolChemDef **/
+                                 libXpertMass::Polymer *polymer,
+                                 /* no libXpertMass::PolChemDef **/
                                  const QString &configSettingsFilePath,
                                  const QString &applicationName,
                                  const QString &description,
-                                 libmass::CalcOptions *calcOptions,
-                                 libmass::IonizeRule *ionizeRule)
+                                 libXpertMass::CalcOptions *calcOptions,
+                                 libXpertMass::IonizeRule *ionizeRule)
   : AbstractSeqEdWndDependentDlg(editorWnd,
                                  polymer,
                                  0 /*polChemDef*/,
@@ -206,7 +206,7 @@ CompositionsDlg::fetchValidateInputData()
   if(!m_ui.selectedSequenceRadioButton->isChecked())
     {
       m_coordinateList.setCoordinates(
-        libmass::Coordinates(0, mp_polymer->size() - 1));
+        libXpertMass::Coordinates(0, mp_polymer->size() - 1));
     }
 
   // Make sure the sequence still has a number of residues
@@ -219,7 +219,7 @@ CompositionsDlg::fetchValidateInputData()
   for(int iter = 0; iter < m_coordinateList.size(); ++iter)
     {
       // New coordinates instance we are iterating into.
-      libmass::Coordinates *coordinates = m_coordinateList.at(iter);
+      libXpertMass::Coordinates *coordinates = m_coordinateList.at(iter);
 
       if(coordinates->start() >= polymerSize ||
          coordinates->end() >= polymerSize)
@@ -235,7 +235,7 @@ CompositionsDlg::fetchValidateInputData()
 
   // We also want to know if the cross-links should be taken into account.
 
-  if(mp_calcOptions->monomerEntities() & libmass::MONOMER_CHEMENT_CROSS_LINK)
+  if(mp_calcOptions->monomerEntities() & libXpertMass::MONOMER_CHEMENT_CROSS_LINK)
     {
       // If the whole sequence is dealt with, then by definition all
       // the cross-links are encompassed by the sequence.
@@ -249,24 +249,24 @@ CompositionsDlg::fetchValidateInputData()
         {
           // We have to count the incomplete cross-links.
 
-          const libmass::CrossLinkList &crossLinkList =
+          const libXpertMass::CrossLinkList &crossLinkList =
             mp_polymer->crossLinkList();
 
           int crossLinkPartial = 0;
 
           for(int iter = 0; iter < crossLinkList.size(); ++iter)
             {
-              libmass::CrossLink *crossLink = crossLinkList.at(iter);
+              libXpertMass::CrossLink *crossLink = crossLinkList.at(iter);
 
               int ret = crossLink->encompassedBy(m_coordinateList);
 
-              if(ret == libmass::CROSS_LINK_ENCOMPASSED_FULL)
+              if(ret == libXpertMass::CROSS_LINK_ENCOMPASSED_FULL)
                 {
                   // 		qDebug() << __FILE__ << __LINE__
                   // 			  << "CrossLink at iter:" << iter
                   // 			  << "is fully encompassed";
                 }
-              else if(ret == libmass::CROSS_LINK_ENCOMPASSED_PARTIAL)
+              else if(ret == libXpertMass::CROSS_LINK_ENCOMPASSED_PARTIAL)
                 {
                   // 		qDebug() << __FILE__ << __LINE__
                   // 			  << "CrossLink at iter:" << iter
@@ -308,7 +308,7 @@ CompositionsDlg::monomericComposition()
       return;
     }
 
-  libmass::Monomer *fakeMonomer = 0;
+  libXpertMass::Monomer *fakeMonomer = 0;
 
   // Empty the treeview. This will also remove all the monomer items
   // in the m_monomerList.
@@ -334,14 +334,14 @@ CompositionsDlg::monomericComposition()
   for(int iter = 0; iter < m_coordinateList.size(); ++iter)
     {
       // New coordinates instance we are iterating into.
-      libmass::Coordinates *coordinates = m_coordinateList.at(iter);
+      libXpertMass::Coordinates *coordinates = m_coordinateList.at(iter);
 
       for(int jter = coordinates->start(); jter < coordinates->end() + 1;
           ++jter)
         {
           bool processed = false;
 
-          const libmass::Monomer *iterMonomer = mp_polymer->at(jter);
+          const libXpertMass::Monomer *iterMonomer = mp_polymer->at(jter);
           Q_ASSERT(iterMonomer);
 
           // Check if monomer by same name is not already in our list of
@@ -354,7 +354,7 @@ CompositionsDlg::monomericComposition()
 
               if(iterMonomer->name() == fakeMonomer->name())
                 {
-                  libmass::Prop *prop = fakeMonomer->prop("MONOMER_COUNT");
+                  libXpertMass::Prop *prop = fakeMonomer->prop("MONOMER_COUNT");
 
                   // The fake monomer MUST have a count prop !
                   Q_ASSERT(prop);
@@ -368,7 +368,7 @@ CompositionsDlg::monomericComposition()
                     {
                       // The monomer in the sequence is modified. Let the
                       // fake monomer know it.
-                      libmass::Prop *prop = fakeMonomer->prop("MODIF_COUNT");
+                      libXpertMass::Prop *prop = fakeMonomer->prop("MODIF_COUNT");
 
                       // The fake monomer might not have a modif prop.
                       if(prop)
@@ -380,8 +380,8 @@ CompositionsDlg::monomericComposition()
                         }
                       else
                         {
-                          libmass::IntProp *prop =
-                            new libmass::IntProp("MODIF_COUNT", 1);
+                          libXpertMass::IntProp *prop =
+                            new libXpertMass::IntProp("MODIF_COUNT", 1);
                           fakeMonomer->appendProp(prop);
                         }
                     }
@@ -400,9 +400,9 @@ CompositionsDlg::monomericComposition()
 
           if(!processed)
             {
-              fakeMonomer = new libmass::Monomer(*iterMonomer);
+              fakeMonomer = new libXpertMass::Monomer(*iterMonomer);
 
-              libmass::IntProp *prop = new libmass::IntProp("MONOMER_COUNT", 1);
+              libXpertMass::IntProp *prop = new libXpertMass::IntProp("MONOMER_COUNT", 1);
               fakeMonomer->appendProp(prop);
 
               if(iterMonomer->isModified())
@@ -410,8 +410,8 @@ CompositionsDlg::monomericComposition()
                   // The monomer in the sequence is modified. Let the
                   // fake monomer know it.
 
-                  libmass::IntProp *prop =
-                    new libmass::IntProp("MODIF_COUNT", 1);
+                  libXpertMass::IntProp *prop =
+                    new libXpertMass::IntProp("MODIF_COUNT", 1);
                   fakeMonomer->appendProp(prop);
                 }
 
@@ -535,7 +535,7 @@ CompositionsDlg::prepareResultsTxtString(int target)
 
 
       bool withEntities =
-        (mp_calcOptions->monomerEntities() & libmass::MONOMER_CHEMENT_MODIF);
+        (mp_calcOptions->monomerEntities() & libXpertMass::MONOMER_CHEMENT_MODIF);
 
       // We want a delimited sequence with indication of the
       // different sequence regions for which the composition was
@@ -555,9 +555,9 @@ CompositionsDlg::prepareResultsTxtString(int target)
 
       // Left end and right end modifs
       withEntities = (mp_calcOptions->polymerEntities() &
-                        libmass::POLYMER_CHEMENT_LEFT_END_MODIF ||
+                        libXpertMass::POLYMER_CHEMENT_LEFT_END_MODIF ||
                       mp_calcOptions->polymerEntities() &
-                        libmass::POLYMER_CHEMENT_RIGHT_END_MODIF);
+                        libXpertMass::POLYMER_CHEMENT_RIGHT_END_MODIF);
 
       if(!withEntities)
         {
@@ -569,7 +569,7 @@ CompositionsDlg::prepareResultsTxtString(int target)
 
           // Left end modif
           withEntities = (mp_calcOptions->polymerEntities() &
-                          libmass::POLYMER_CHEMENT_LEFT_END_MODIF);
+                          libXpertMass::POLYMER_CHEMENT_LEFT_END_MODIF);
           if(withEntities)
             {
               *mpa_resultsString += QObject::tr("Left end modif: %1 - ")
@@ -578,7 +578,7 @@ CompositionsDlg::prepareResultsTxtString(int target)
 
           // Right end modif
           withEntities = (mp_calcOptions->polymerEntities() &
-                          libmass::POLYMER_CHEMENT_RIGHT_END_MODIF);
+                          libXpertMass::POLYMER_CHEMENT_RIGHT_END_MODIF);
           if(withEntities)
             {
               *mpa_resultsString += QObject::tr("Right end modif: %1")
@@ -706,4 +706,4 @@ CompositionsDlg::selectResultsFile()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
