@@ -37,7 +37,7 @@
 
 
 /////////////////////// libmass includes
-#include "libmass/PolChemDef.hpp"
+#include <libXpertMass/PolChemDef.hpp>
 
 
 /////////////////////// Local includes
@@ -45,14 +45,14 @@
 #include "PolChemDefWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
 {
 
 
-CrossLinkerDefDlg::CrossLinkerDefDlg(libmass::PolChemDefSPtr polChemDefSPtr,
+CrossLinkerDefDlg::CrossLinkerDefDlg(libXpertMass::PolChemDefSPtr polChemDefSPtr,
                                      PolChemDefWnd *polChemDefWnd,
                                      const QString &settingsFilePath,
                                      const QString &applicationName,
@@ -130,7 +130,7 @@ CrossLinkerDefDlg::initialize()
 
   for(int iter = 0; iter < mp_list->size(); ++iter)
     {
-      libmass::CrossLinker *crossLinker = mp_list->at(iter);
+      libXpertMass::CrossLinker *crossLinker = mp_list->at(iter);
 
       m_ui.crossLinkerListWidget->addItem(crossLinker->name());
     }
@@ -220,7 +220,7 @@ CrossLinkerDefDlg::populateAvailableModifList()
 
   for(int iter = 0; iter < msp_polChemDef->modifList().size(); ++iter)
     {
-      libmass::Modif *modif = msp_polChemDef->modifList().at(iter);
+      libXpertMass::Modif *modif = msp_polChemDef->modifList().at(iter);
       Q_ASSERT(modif);
 
       m_ui.modifNameComboBox->addItem(modif->name());
@@ -239,7 +239,7 @@ CrossLinkerDefDlg::addCrossLinkerPushButtonClicked()
   // Returns -1 if the list is empty.
   int index = m_ui.crossLinkerListWidget->currentRow();
 
-  libmass::CrossLinker *newCrossLinker = new libmass::CrossLinker(
+  libXpertMass::CrossLinker *newCrossLinker = new libXpertMass::CrossLinker(
     msp_polChemDef, tr("Type Name"), tr("Type Formula"));
 
   mp_list->insert(index, newCrossLinker);
@@ -279,7 +279,7 @@ CrossLinkerDefDlg::removeCrossLinkerPushButtonClicked()
   QListWidgetItem *item = m_ui.crossLinkerListWidget->takeItem(index);
   delete item;
 
-  libmass::CrossLinker *crossLinker = mp_list->takeAt(index);
+  libXpertMass::CrossLinker *crossLinker = mp_list->takeAt(index);
   Q_ASSERT(crossLinker);
   delete crossLinker;
 
@@ -383,7 +383,7 @@ CrossLinkerDefDlg::addModifPushButtonClicked()
     {
       QMessageBox::information(
         this,
-        tr("massXpert - libmass::CrossLinker definition"),
+        tr("massXpert - libXpertMass::CrossLinker definition"),
         tr("Please, select a crossLinker first."),
         QMessageBox::Ok);
       return;
@@ -394,12 +394,12 @@ CrossLinkerDefDlg::addModifPushButtonClicked()
   int index = m_ui.crossLinkerListWidget->currentRow();
 
   // What's the actual crossLinker?
-  libmass::CrossLinker *crossLinker = mp_list->at(index);
+  libXpertMass::CrossLinker *crossLinker = mp_list->at(index);
   Q_ASSERT(crossLinker);
 
   // Allocate the new modif.
-  libmass::Modif *newModif =
-    new libmass::Modif(msp_polChemDef, tr("Select modification"));
+  libXpertMass::Modif *newModif =
+    new libXpertMass::Modif(msp_polChemDef, tr("Select modification"));
 
   // Get the row index of the current modif item. Returns -1 if the
   // list is empty.
@@ -436,7 +436,7 @@ CrossLinkerDefDlg::removeModifPushButtonClicked()
   // which crossLinker we'll remove the modif.
   int index = m_ui.crossLinkerListWidget->currentRow();
 
-  libmass::CrossLinker *crossLinker = mp_list->at(index);
+  libXpertMass::CrossLinker *crossLinker = mp_list->at(index);
   Q_ASSERT(crossLinker);
 
   // Get the index of the current modif.
@@ -451,9 +451,9 @@ CrossLinkerDefDlg::removeModifPushButtonClicked()
 
   // Remove the modif from the crossLinker proper.
 
-  QList<libmass::Modif *> modifList = crossLinker->modifList();
+  QList<libXpertMass::Modif *> modifList = crossLinker->modifList();
 
-  libmass::Modif *modif = modifList.at(index);
+  libXpertMass::Modif *modif = modifList.at(index);
 
   crossLinker->modifList().removeAt(index);
   delete modif;
@@ -497,7 +497,7 @@ CrossLinkerDefDlg::moveUpModifPushButtonClicked()
 
   // Get the crossLinker to which the modif belongs.
   int index                         = m_ui.crossLinkerListWidget->currentRow();
-  libmass::CrossLinker *crossLinker = mp_list->at(index);
+  libXpertMass::CrossLinker *crossLinker = mp_list->at(index);
 
   // Get the index of the current modif item.
   index = m_ui.modifListWidget->currentRow();
@@ -507,7 +507,7 @@ CrossLinkerDefDlg::moveUpModifPushButtonClicked()
     return;
 
   // Get the modif itself from the crossLinker.
-  libmass::Modif *modif = crossLinker->modifList().at(index);
+  libXpertMass::Modif *modif = crossLinker->modifList().at(index);
 
   crossLinker->modifList().removeAt(index);
   crossLinker->modifList().insert(index - 1, modif);
@@ -535,7 +535,7 @@ CrossLinkerDefDlg::moveDownModifPushButtonClicked()
 
   // Get the crossLinker to which the modif belongs.
   int index                         = m_ui.crossLinkerListWidget->currentRow();
-  libmass::CrossLinker *crossLinker = mp_list->at(index);
+  libXpertMass::CrossLinker *crossLinker = mp_list->at(index);
 
   // Get the index of the current modif item.
   index = m_ui.modifListWidget->currentRow();
@@ -545,7 +545,7 @@ CrossLinkerDefDlg::moveDownModifPushButtonClicked()
     return;
 
   // Get the modif itself from the crossLinker.
-  libmass::Modif *modif = crossLinker->modifList().at(index);
+  libXpertMass::Modif *modif = crossLinker->modifList().at(index);
 
   crossLinker->modifList().removeAt(index);
   crossLinker->modifList().insert(index + 1, modif);
@@ -575,7 +575,7 @@ CrossLinkerDefDlg::applyCrossLinkerPushButtonClicked()
   // Get the index of the current crossLinker item.
   int index = m_ui.crossLinkerListWidget->currentRow();
 
-  libmass::CrossLinker *crossLinker = mp_list->at(index);
+  libXpertMass::CrossLinker *crossLinker = mp_list->at(index);
 
   // We do not want more than one crossLinker by the same name or the same
   // symbol.
@@ -596,11 +596,11 @@ CrossLinkerDefDlg::applyCrossLinkerPushButtonClicked()
   // crossLinker is not the one that is current in the crossLinker list,
   // then we are making a double entry, which is not allowed.
 
-  int nameRes = libmass::CrossLinker::isNameInList(editName, *mp_list);
+  int nameRes = libXpertMass::CrossLinker::isNameInList(editName, *mp_list);
   if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::CrossLinker definition"),
+                           tr("massXpert - libXpertMass::CrossLinker definition"),
                            tr("A crossLinker with same name "
                               "exists already."),
                            QMessageBox::Ok);
@@ -614,16 +614,16 @@ CrossLinkerDefDlg::applyCrossLinkerPushButtonClicked()
   if(msp_polChemDef->referenceModifByName(editName))
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::CrossLinker definition"),
+                           tr("massXpert - libXpertMass::CrossLinker definition"),
                            tr("The name of the cross-linker is already "
                               "used by a modification."),
                            QMessageBox::Ok);
       return;
     }
 
-  libmass::Formula formula(editFormula);
+  libXpertMass::Formula formula(editFormula);
 
-  libmass::IsotopicDataSPtr isotopic_data_sp =
+  libXpertMass::IsotopicDataSPtr isotopic_data_sp =
     msp_polChemDef->getIsotopicDataSPtr();
 
   if(!formula.validate(isotopic_data_sp))
@@ -632,7 +632,7 @@ CrossLinkerDefDlg::applyCrossLinkerPushButtonClicked()
         {
           QMessageBox::warning(
             this,
-            tr("massXpert - libmass::CrossLinker definition"),
+            tr("massXpert - libXpertMass::CrossLinker definition"),
             tr("The formula is empty, please enter a formula "
                "like '-H+H' if no reaction is required."),
             QMessageBox::Ok);
@@ -641,7 +641,7 @@ CrossLinkerDefDlg::applyCrossLinkerPushButtonClicked()
         {
           QMessageBox::warning(
             this,
-            tr("massXpert - libmass::CrossLinker definition"),
+            tr("massXpert - libXpertMass::CrossLinker definition"),
             tr("The formula failed to validate."),
             QMessageBox::Ok);
         }
@@ -677,28 +677,28 @@ CrossLinkerDefDlg::applyModifPushButtonClicked()
 
   // Get the crossLinker to which the modif belongs.
   int index                         = m_ui.crossLinkerListWidget->currentRow();
-  libmass::CrossLinker *crossLinker = mp_list->at(index);
+  libXpertMass::CrossLinker *crossLinker = mp_list->at(index);
 
   // Get the index of the current modif item.
   index = m_ui.modifListWidget->currentRow();
 
   // Get the modif itself from the crossLinker.
-  libmass::Modif *crosslinker_modif = crossLinker->modifList().at(index);
+  libXpertMass::Modif *crosslinker_modif = crossLinker->modifList().at(index);
 
   QString modifName = m_ui.modifNameComboBox->currentText();
 
   // Make sure the modification is known to the polymer chemistry
   // definition.
 
-  libmass::Modif reference_modif =
-    libmass::Modif(msp_polChemDef, "NOT_SET", "NOT_SET");
+  libXpertMass::Modif reference_modif =
+    libXpertMass::Modif(msp_polChemDef, "NOT_SET", "NOT_SET");
 
   // Populate reference_modif with the data in the modification by the same name
   // in the reference list belonging to the polymer chemistry definition.
   if(!msp_polChemDef->referenceModifByName(modifName, &reference_modif))
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::CrossLinker definition"),
+                           tr("massXpert - libXpertMass::CrossLinker definition"),
                            tr("The modification is not known to the "
                               "polymer chemistry definition."),
                            QMessageBox::Ok);
@@ -739,7 +739,7 @@ CrossLinkerDefDlg::validatePushButtonClicked()
            "is not identical.\n"));
 
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::CrossLinker definition"),
+                           tr("massXpert - libXpertMass::CrossLinker definition"),
                            errorList.join("\n"),
                            QMessageBox::Ok);
       return false;
@@ -749,7 +749,7 @@ CrossLinkerDefDlg::validatePushButtonClicked()
     {
       QListWidgetItem *item = m_ui.crossLinkerListWidget->item(iter);
 
-      libmass::CrossLinker *crossLinker = mp_list->at(iter);
+      libXpertMass::CrossLinker *crossLinker = mp_list->at(iter);
 
       if(item->text() != crossLinker->name())
         errorList << QString(tr("\nCrossLinker at index %1 has not the same\n"
@@ -769,7 +769,7 @@ CrossLinkerDefDlg::validatePushButtonClicked()
   if(errorList.size())
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::CrossLinker definition"),
+                           tr("massXpert - libXpertMass::CrossLinker definition"),
                            errorList.join("\n"),
                            QMessageBox::Ok);
       return false;
@@ -777,7 +777,7 @@ CrossLinkerDefDlg::validatePushButtonClicked()
   else
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::CrossLinker definition"),
+                           tr("massXpert - libXpertMass::CrossLinker definition"),
                            ("Validation: success\n"),
                            QMessageBox::Ok);
     }
@@ -803,7 +803,7 @@ CrossLinkerDefDlg::crossLinkerListWidgetItemSelectionChanged()
   // Get the index of the current crossLinker.
   int index = m_ui.crossLinkerListWidget->currentRow();
 
-  libmass::CrossLinker *crossLinker = mp_list->at(index);
+  libXpertMass::CrossLinker *crossLinker = mp_list->at(index);
   Q_ASSERT(crossLinker);
 
   // Set the data of the crossLinker to their respective widgets.
@@ -814,7 +814,7 @@ CrossLinkerDefDlg::crossLinkerListWidgetItemSelectionChanged()
 
   for(int iter = 0; iter < crossLinker->modifList().size(); ++iter)
     {
-      libmass::Modif *modif = crossLinker->modifList().at(iter);
+      libXpertMass::Modif *modif = crossLinker->modifList().at(iter);
 
       m_ui.modifListWidget->addItem(modif->name());
     }
@@ -845,7 +845,7 @@ CrossLinkerDefDlg::modifListWidgetItemSelectionChanged()
   int index = m_ui.crossLinkerListWidget->currentRow();
 
   // Find the modif object in the list of modifs.
-  libmass::CrossLinker *crossLinker = mp_list->at(index);
+  libXpertMass::CrossLinker *crossLinker = mp_list->at(index);
   Q_ASSERT(crossLinker);
 
   // Get the index of the current modif.
@@ -853,7 +853,7 @@ CrossLinkerDefDlg::modifListWidgetItemSelectionChanged()
 
   // Get the modif that is currently selected from the crossLinker's list
   // of modifs.
-  libmass::Modif *modif = crossLinker->modifList().at(index);
+  libXpertMass::Modif *modif = crossLinker->modifList().at(index);
   Q_ASSERT(modif);
 
   // Set the data of the modif to their respective widgets.
@@ -863,7 +863,7 @@ CrossLinkerDefDlg::modifListWidgetItemSelectionChanged()
 
 void
 CrossLinkerDefDlg::updateCrossLinkerIdentityDetails(
-  libmass::CrossLinker *crossLinker)
+  libXpertMass::CrossLinker *crossLinker)
 {
   if(crossLinker)
     {
@@ -879,7 +879,7 @@ CrossLinkerDefDlg::updateCrossLinkerIdentityDetails(
 
 
 void
-CrossLinkerDefDlg::updateModifDetails(libmass::Modif *modif)
+CrossLinkerDefDlg::updateModifDetails(libXpertMass::Modif *modif)
 {
   if(modif)
     {
@@ -923,4 +923,4 @@ CrossLinkerDefDlg::validate()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
