@@ -37,7 +37,7 @@
 
 
 /////////////////////// libmass includes
-#include "libmass/PolChemDef.hpp"
+#include <libXpertMass/PolChemDef.hpp>
 
 
 /////////////////////// Local includes
@@ -45,14 +45,14 @@
 #include "PolChemDefWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
 {
 
 
-FragSpecDefDlg::FragSpecDefDlg(libmass::PolChemDefSPtr polChemDefSPtr,
+FragSpecDefDlg::FragSpecDefDlg(libXpertMass::PolChemDefSPtr polChemDefSPtr,
                                PolChemDefWnd *polChemDefWnd,
                                const QString &settingsFilePath,
                                const QString &applicationName,
@@ -132,7 +132,7 @@ FragSpecDefDlg::initialize()
 
   for(int iter = 0; iter < mp_list->size(); ++iter)
     {
-      libmass::FragSpec *fragSpec = mp_list->at(iter);
+      libXpertMass::FragSpec *fragSpec = mp_list->at(iter);
 
       m_ui.fragSpecListWidget->addItem(fragSpec->name());
     }
@@ -229,11 +229,11 @@ FragSpecDefDlg::addFragSpecPushButtonClicked()
   // Returns -1 if the list is empty.
   int index = m_ui.fragSpecListWidget->currentRow();
 
-  libmass::FragSpec *newFragSpec =
-    new libmass::FragSpec(msp_polChemDef,
+  libXpertMass::FragSpec *newFragSpec =
+    new libXpertMass::FragSpec(msp_polChemDef,
                           tr("Type Spec Name"),
                           tr("Type Spec Formula"),
-                          libmass::FRAG_END_NONE);
+                          libXpertMass::FRAG_END_NONE);
 
   mp_list->insert(index, newFragSpec);
   m_ui.fragSpecListWidget->insertItem(index, newFragSpec->name());
@@ -272,7 +272,7 @@ FragSpecDefDlg::removeFragSpecPushButtonClicked()
   QListWidgetItem *item = m_ui.fragSpecListWidget->takeItem(index);
   delete item;
 
-  libmass::FragSpec *fragSpec = mp_list->takeAt(index);
+  libXpertMass::FragSpec *fragSpec = mp_list->takeAt(index);
   Q_ASSERT(fragSpec);
   delete fragSpec;
 
@@ -385,12 +385,12 @@ FragSpecDefDlg::addFragRulePushButtonClicked()
   int index = m_ui.fragSpecListWidget->currentRow();
 
   // What's the actual fragSpec?
-  libmass::FragSpec *fragSpec = mp_list->at(index);
+  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
   Q_ASSERT(fragSpec);
 
   // Allocate the new fragRule.
-  libmass::FragRule *newFragRule =
-    new libmass::FragRule(msp_polChemDef, tr("Type Rule Name"));
+  libXpertMass::FragRule *newFragRule =
+    new libXpertMass::FragRule(msp_polChemDef, tr("Type Rule Name"));
 
   // Get the row index of the current fragRule item. Returns -1 if the
   // list is empty.
@@ -429,7 +429,7 @@ FragSpecDefDlg::removeFragRulePushButtonClicked()
   // which fragSpec we'll remove the fragRule.
   int index = m_ui.fragSpecListWidget->currentRow();
 
-  libmass::FragSpec *fragSpec = mp_list->at(index);
+  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
   Q_ASSERT(fragSpec);
 
   // Get the index of the current fragRule.
@@ -444,9 +444,9 @@ FragSpecDefDlg::removeFragRulePushButtonClicked()
 
   // Remove the fragRule from the fragSpec proper.
 
-  QList<libmass::FragRule *> fragRuleList = fragSpec->ruleList();
+  QList<libXpertMass::FragRule *> fragRuleList = fragSpec->ruleList();
 
-  libmass::FragRule *fragRule = fragRuleList.at(index);
+  libXpertMass::FragRule *fragRule = fragRuleList.at(index);
 
   fragSpec->ruleList().removeAt(index);
   delete fragRule;
@@ -491,7 +491,7 @@ FragSpecDefDlg::moveUpFragRulePushButtonClicked()
 
   // Get the fragSpec to which the fragRule belongs.
   int index                   = m_ui.fragSpecListWidget->currentRow();
-  libmass::FragSpec *fragSpec = mp_list->at(index);
+  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
 
   // Get the index of the current fragRule item.
   index = m_ui.fragRuleListWidget->currentRow();
@@ -501,7 +501,7 @@ FragSpecDefDlg::moveUpFragRulePushButtonClicked()
     return;
 
   // Get the fragRule itself from the fragSpec.
-  libmass::FragRule *fragRule = fragSpec->ruleList().at(index);
+  libXpertMass::FragRule *fragRule = fragSpec->ruleList().at(index);
 
   fragSpec->ruleList().removeAt(index);
   fragSpec->ruleList().insert(index - 1, fragRule);
@@ -530,7 +530,7 @@ FragSpecDefDlg::moveDownFragRulePushButtonClicked()
 
   // Get the fragSpec to which the fragRule belongs.
   int index                   = m_ui.fragSpecListWidget->currentRow();
-  libmass::FragSpec *fragSpec = mp_list->at(index);
+  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
 
   // Get the index of the current fragRule item.
   index = m_ui.fragRuleListWidget->currentRow();
@@ -540,7 +540,7 @@ FragSpecDefDlg::moveDownFragRulePushButtonClicked()
     return;
 
   // Get the fragRule itself from the fragSpec.
-  libmass::FragRule *fragRule = fragSpec->ruleList().at(index);
+  libXpertMass::FragRule *fragRule = fragSpec->ruleList().at(index);
 
   fragSpec->ruleList().removeAt(index);
   fragSpec->ruleList().insert(index + 1, fragRule);
@@ -570,7 +570,7 @@ FragSpecDefDlg::applyFragSpecPushButtonClicked()
   // Get the index of the current fragSpec item.
   int index = m_ui.fragSpecListWidget->currentRow();
 
-  libmass::FragSpec *fragSpec = mp_list->at(index);
+  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
 
   // We do not want more than one fragSpec by the same name.
 
@@ -581,7 +581,7 @@ FragSpecDefDlg::applyFragSpecPushButtonClicked()
   // fragSpec is not the one that is current in the fragSpec list,
   // then we are making a double entry, which is not allowed.
 
-  int nameRes = libmass::FragSpec::isNameInList(editName, *mp_list);
+  int nameRes = libXpertMass::FragSpec::isNameInList(editName, *mp_list);
   if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
@@ -593,16 +593,16 @@ FragSpecDefDlg::applyFragSpecPushButtonClicked()
     }
 
   QString fragEndString = m_ui.fragEndComboBox->currentText();
-  libmass::FragEnd fragEnd;
+  libXpertMass::FragEnd fragEnd;
 
   if(fragEndString == "NE")
-    fragEnd = libmass::FRAG_END_NONE;
+    fragEnd = libXpertMass::FRAG_END_NONE;
   else if(fragEndString == "BE")
-    fragEnd = libmass::FRAG_END_BOTH;
+    fragEnd = libXpertMass::FRAG_END_BOTH;
   else if(fragEndString == "LE")
-    fragEnd = libmass::FRAG_END_LEFT;
+    fragEnd = libXpertMass::FRAG_END_LEFT;
   else if(fragEndString == "RE")
-    fragEnd = libmass::FRAG_END_RIGHT;
+    fragEnd = libXpertMass::FRAG_END_RIGHT;
   else
     {
       QMessageBox::warning(this,
@@ -615,9 +615,9 @@ FragSpecDefDlg::applyFragSpecPushButtonClicked()
 
   // At this point, validate the formula:
 
-  libmass::Formula formula(editFormula);
+  libXpertMass::Formula formula(editFormula);
 
-  libmass::IsotopicDataSPtr isotopic_data_sp =
+  libXpertMass::IsotopicDataSPtr isotopic_data_sp =
     msp_polChemDef->getIsotopicDataSPtr();
 
   if(!formula.validate(isotopic_data_sp))
@@ -719,13 +719,13 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
 
   // Get the fragSpec to which the fragRule belongs.
   int index                   = m_ui.fragSpecListWidget->currentRow();
-  libmass::FragSpec *fragSpec = mp_list->at(index);
+  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
 
   // Get the index of the current fragRule item.
   index = m_ui.fragRuleListWidget->currentRow();
 
   // Get the fragRule itself from the fragSpec.
-  libmass::FragRule *fragRule = fragSpec->ruleList().at(index);
+  libXpertMass::FragRule *fragRule = fragSpec->ruleList().at(index);
 
   QString editName    = m_ui.fragRuleNameLineEdit->text();
   QString editFormula = m_ui.fragRuleFormulaLineEdit->text();
@@ -738,7 +738,7 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
   // fragRule is not the one that is current in the fragRule list,
   // then we are making a double entry, which is not allowed.
 
-  int nameRes = libmass::FragRule::isNameInList(editName, fragSpec->ruleList());
+  int nameRes = libXpertMass::FragRule::isNameInList(editName, fragSpec->ruleList());
   if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
@@ -751,10 +751,10 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
 
   if(!prevCode.isEmpty())
     {
-      const QList<libmass::Monomer *> &monomerList =
+      const QList<libXpertMass::Monomer *> &monomerList =
         msp_polChemDef->monomerList();
 
-      if(libmass::Monomer::isCodeInList(prevCode, monomerList) == -1)
+      if(libXpertMass::Monomer::isCodeInList(prevCode, monomerList) == -1)
         {
           QMessageBox::warning(this,
                                tr("massXpert - Fragmentation definition"),
@@ -766,10 +766,10 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
 
   if(!currCode.isEmpty())
     {
-      const QList<libmass::Monomer *> &monomerList =
+      const QList<libXpertMass::Monomer *> &monomerList =
         msp_polChemDef->monomerList();
 
-      if(libmass::Monomer::isCodeInList(currCode, monomerList) == -1)
+      if(libXpertMass::Monomer::isCodeInList(currCode, monomerList) == -1)
         {
           QMessageBox::warning(this,
                                tr("massXpert - Fragmentation definition"),
@@ -781,10 +781,10 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
 
   if(!nextCode.isEmpty())
     {
-      const QList<libmass::Monomer *> &monomerList =
+      const QList<libXpertMass::Monomer *> &monomerList =
         msp_polChemDef->monomerList();
 
-      if(libmass::Monomer::isCodeInList(nextCode, monomerList) == -1)
+      if(libXpertMass::Monomer::isCodeInList(nextCode, monomerList) == -1)
         {
           QMessageBox::warning(this,
                                tr("massXpert - Fragmentation definition"),
@@ -794,9 +794,9 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
         }
     }
 
-  libmass::Formula formula(editFormula);
+  libXpertMass::Formula formula(editFormula);
 
-  libmass::IsotopicDataSPtr isotopic_data_sp =
+  libXpertMass::IsotopicDataSPtr isotopic_data_sp =
     msp_polChemDef->getIsotopicDataSPtr();
 
   if(!formula.validate(isotopic_data_sp))
@@ -858,7 +858,7 @@ FragSpecDefDlg::validatePushButtonClicked()
     {
       QListWidgetItem *item = m_ui.fragSpecListWidget->item(iter);
 
-      libmass::FragSpec *fragSpec = mp_list->at(iter);
+      libXpertMass::FragSpec *fragSpec = mp_list->at(iter);
 
       if(item->text() != fragSpec->name())
         errorList << QString(tr("\nFragmentation at index %1 has not "
@@ -910,7 +910,7 @@ FragSpecDefDlg::fragSpecListWidgetItemSelectionChanged()
   // Get the index of the current fragSpec.
   int index = m_ui.fragSpecListWidget->currentRow();
 
-  libmass::FragSpec *fragSpec = mp_list->at(index);
+  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
   Q_ASSERT(fragSpec);
 
   // Set the data of the fragSpec to their respective widgets.
@@ -921,7 +921,7 @@ FragSpecDefDlg::fragSpecListWidgetItemSelectionChanged()
 
   for(int iter = 0; iter < fragSpec->ruleList().size(); ++iter)
     {
-      libmass::FragRule *fragRule = fragSpec->ruleList().at(iter);
+      libXpertMass::FragRule *fragRule = fragSpec->ruleList().at(iter);
 
       m_ui.fragRuleListWidget->addItem(fragRule->name());
     }
@@ -953,7 +953,7 @@ FragSpecDefDlg::fragRuleListWidgetItemSelectionChanged()
   int index = m_ui.fragSpecListWidget->currentRow();
 
   // Find the fragRule object in the list of fragRules.
-  libmass::FragSpec *fragSpec = mp_list->at(index);
+  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
   Q_ASSERT(fragSpec);
 
   // Get the index of the current fragRule.
@@ -961,7 +961,7 @@ FragSpecDefDlg::fragRuleListWidgetItemSelectionChanged()
 
   // Get the fragRule that is currently selected from the fragSpec's list
   // of fragRules.
-  libmass::FragRule *fragRule = fragSpec->ruleList().at(index);
+  libXpertMass::FragRule *fragRule = fragSpec->ruleList().at(index);
   Q_ASSERT(fragRule);
 
   // Set the data of the fragRule to their respective widgets.
@@ -970,7 +970,7 @@ FragSpecDefDlg::fragRuleListWidgetItemSelectionChanged()
 
 
 void
-FragSpecDefDlg::updateFragSpecDetails(libmass::FragSpec *fragSpec)
+FragSpecDefDlg::updateFragSpecDetails(libXpertMass::FragSpec *fragSpec)
 {
   if(fragSpec)
     {
@@ -979,11 +979,11 @@ FragSpecDefDlg::updateFragSpecDetails(libmass::FragSpec *fragSpec)
 
       int index = 0;
 
-      if(fragSpec->fragEnd() == libmass::FRAG_END_NONE)
+      if(fragSpec->fragEnd() == libXpertMass::FRAG_END_NONE)
         index = m_ui.fragEndComboBox->findText("NE");
-      else if(fragSpec->fragEnd() == libmass::FRAG_END_LEFT)
+      else if(fragSpec->fragEnd() == libXpertMass::FRAG_END_LEFT)
         index = m_ui.fragEndComboBox->findText("LE");
-      else if(fragSpec->fragEnd() == libmass::FRAG_END_RIGHT)
+      else if(fragSpec->fragEnd() == libXpertMass::FRAG_END_RIGHT)
         index = m_ui.fragEndComboBox->findText("RE");
       m_ui.fragEndComboBox->setCurrentIndex(index);
       m_ui.monomerContributionSpinBox->setValue(
@@ -1003,7 +1003,7 @@ FragSpecDefDlg::updateFragSpecDetails(libmass::FragSpec *fragSpec)
 
 
 void
-FragSpecDefDlg::updateFragRuleDetails(libmass::FragRule *fragRule)
+FragSpecDefDlg::updateFragRuleDetails(libXpertMass::FragRule *fragRule)
 {
   if(fragRule)
     {
@@ -1061,4 +1061,4 @@ FragSpecDefDlg::validate()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
