@@ -40,7 +40,7 @@
 
 #include <pappsomspp/utils.h>
 
-#include <libmass/Oligomer.hpp>
+#include <libXpertMass/Oligomer.hpp>
 
 /////////////////////// Local includes
 #include "../nongui/globals.hpp"
@@ -51,7 +51,7 @@
 #include "FragmentOligomerTableViewMimeData.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -241,7 +241,7 @@ FragmentOligomerTableView::selectedOligomers(OligomerList *oligomerList,
       // the user of the list of oligomers to highlight regions in
       // the sequence editor.
 
-      libmass::NoDeletePointerProp *prop = new libmass::NoDeletePointerProp(
+      libXpertMass::NoDeletePointerProp *prop = new libXpertMass::NoDeletePointerProp(
         "SEQUENCE_EDITOR_WND", static_cast<void *>(mp_parentDlg->editorWnd()));
 
       new_oligomer_sp->appendProp(prop);
@@ -267,7 +267,7 @@ FragmentOligomerTableView::selectedOligomersAsPlainText(
   QString delimiter,
   bool withSequence,
   bool forXpertMiner,
-  libmass::MassType massType) const
+  libXpertMass::MassType massType) const
 {
   // Let's get all the currently selected oligomers in one list.
   OligomerList oligomerList;
@@ -294,29 +294,29 @@ FragmentOligomerTableView::selectedOligomersAsPlainText(
 
   while(!oligomerList.isEmpty())
     {
-      libmass::OligomerSPtr oligomer_sp = oligomerList.takeFirst();
+      libXpertMass::OligomerSPtr oligomer_sp = oligomerList.takeFirst();
 
       if(!forXpertMiner)
         *text +=
           QString("\n%1%2").arg(oligomer_sp->description()).arg(delimiter);
 
-      if(forXpertMiner && massType == libmass::MassType::MASS_AVG)
+      if(forXpertMiner && massType == libXpertMass::MassType::MASS_AVG)
         {
         }
       else
         {
           *text += QString("%1%2")
-                     .arg(oligomer_sp->monoString(libmass::OLIGOMER_DEC_PLACES))
+                     .arg(oligomer_sp->monoString(libXpertMass::OLIGOMER_DEC_PLACES))
                      .arg(delimiter);
         }
 
-      if(forXpertMiner && massType == libmass::MassType::MASS_MONO)
+      if(forXpertMiner && massType == libXpertMass::MassType::MASS_MONO)
         {
         }
       else
         {
           *text += QString("%1%2")
-                     .arg(oligomer_sp->avgString(libmass::OLIGOMER_DEC_PLACES))
+                     .arg(oligomer_sp->avgString(libXpertMass::OLIGOMER_DEC_PLACES))
                      .arg(delimiter);
         }
 
@@ -325,7 +325,7 @@ FragmentOligomerTableView::selectedOligomersAsPlainText(
       *text += QString("%1%2").arg(oligomer_sp->name()).arg(delimiter);
 
       *text += QString("%1%2")
-                 .arg(static_cast<libmass::CoordinateList *>(oligomer_sp.get())
+                 .arg(static_cast<libXpertMass::CoordinateList *>(oligomer_sp.get())
                         ->positionsAsText())
                  .arg(delimiter);
 
@@ -425,7 +425,7 @@ FragmentOligomerTableView::currentChanged(const QModelIndex &current,
   // tableView (that list actually belongs to the FragmentationDlg
   // instance.
 
-  libmass::OligomerSPtr oligomer_sp = mp_oligomerList->at(row);
+  libXpertMass::OligomerSPtr oligomer_sp = mp_oligomerList->at(row);
 
   // If the oligomers obtained with the fragmentation are old and
   // the sequence has been changed since the fragmentation, then the
@@ -466,7 +466,7 @@ FragmentOligomerTableView::currentChanged(const QModelIndex &current,
   // Get the mass calculation engine's options out of the oligomer,
   // so that we can display them correctly.
 
-  libmass::CalcOptions calcOptions = oligomer_sp->calcOptions();
+  libXpertMass::CalcOptions calcOptions = oligomer_sp->calcOptions();
 
   mp_parentDlg->updateFragmentationDetails(calcOptions);
 
@@ -491,7 +491,7 @@ FragmentOligomerTableView::itemActivated(const QModelIndex &index)
   // tableView (that list actually belongs to the FragmentationDlg
   // instance.
 
-  libmass::OligomerSPtr oligomer_sp = mp_oligomerList->at(row);
+  libXpertMass::OligomerSPtr oligomer_sp = mp_oligomerList->at(row);
 
   SequenceEditorWnd *editorWnd = mp_parentDlg->editorWnd();
 
@@ -530,14 +530,14 @@ FragmentOligomerTableView::itemActivated(const QModelIndex &index)
 void
 FragmentOligomerTableView::copyMono()
 {
-  return copyMassList(libmass::MassType::MASS_MONO);
+  return copyMassList(libXpertMass::MassType::MASS_MONO);
 }
 
 
 void
 FragmentOligomerTableView::copyAvg()
 {
-  return copyMassList(libmass::MassType::MASS_AVG);
+  return copyMassList(libXpertMass::MassType::MASS_AVG);
 }
 
 
@@ -569,12 +569,12 @@ FragmentOligomerTableView::copyMassList(int monoOrAvg)
       // qDebug() << __FILE__ << __LINE__
       //          << "sourceRow:" << sourceRow;
 
-      libmass::OligomerSPtr oligomer_sp = mp_oligomerList->at(sourceRow);
+      libXpertMass::OligomerSPtr oligomer_sp = mp_oligomerList->at(sourceRow);
 
-      if(monoOrAvg == libmass::MassType::MASS_MONO)
-        massList += oligomer_sp->monoString(libmass::OLIGOMER_DEC_PLACES);
-      else if(monoOrAvg == libmass::MassType::MASS_AVG)
-        massList += oligomer_sp->avgString(libmass::OLIGOMER_DEC_PLACES);
+      if(monoOrAvg == libXpertMass::MassType::MASS_MONO)
+        massList += oligomer_sp->monoString(libXpertMass::OLIGOMER_DEC_PLACES);
+      else if(monoOrAvg == libXpertMass::MassType::MASS_AVG)
+        massList += oligomer_sp->avgString(libXpertMass::OLIGOMER_DEC_PLACES);
       else
         qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
@@ -592,4 +592,4 @@ FragmentOligomerTableView::copyMassList(int monoOrAvg)
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
