@@ -40,13 +40,14 @@
 #include <pappsomspp/utils.h>
 
 /////////////////////// libmass includes
-#include <libmass/PolChemDefEntity.hpp>
-#include <libmass/IsotopicClusterGenerator.hpp>
-#include <libmass/IsotopicClusterShaper.hpp>
-#include <libmass/IsotopicData.hpp>
-#include <libmass/MassPeakShaper.hpp>
-#include <libmass/MassPeakShaperConfig.hpp>
-#include <libmassgui/ColorSelector.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
+#include <libXpertMass/IsotopicDataUserConfigHandler.hpp>
+#include <libXpertMass/IsotopicClusterGenerator.hpp>
+#include <libXpertMass/IsotopicClusterShaper.hpp>
+#include <libXpertMass/IsotopicData.hpp>
+#include <libXpertMass/MassPeakShaper.hpp>
+#include <libXpertMass/MassPeakShaperConfig.hpp>
+#include <libXpertMassGui/ColorSelector.hpp>
 
 
 /////////////////////// Local includes
@@ -55,7 +56,7 @@
 #include "FragmentationDlg.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -64,13 +65,13 @@ namespace massxpert
 
 FragmentationDlg::FragmentationDlg(
   SequenceEditorWnd *editorWnd,
-  libmass::Polymer *polymer,
-  const libmass::PolChemDefCstSPtr polChemDefCstSPtr,
+  libXpertMass::Polymer *polymer,
+  const libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr,
   const QString &configSettingsFilePath,
   const QString &applicationName,
   const QString &description,
-  const libmass::CalcOptions &calcOptions,
-  const libmass::IonizeRule *ionizeRule)
+  const libXpertMass::CalcOptions &calcOptions,
+  const libXpertMass::IonizeRule *ionizeRule)
   : AbstractSeqEdWndDependentDlg(editorWnd,
                                  polymer,
                                  polChemDefCstSPtr,
@@ -290,7 +291,7 @@ FragmentationDlg::initialize()
 bool
 FragmentationDlg::populateSelectedOligomerData()
 {
-  libmass::CoordinateList coordList;
+  libXpertMass::CoordinateList coordList;
 
   bool res = mp_editorWnd->mpa_editorGraphicsView->selectionIndices(&coordList);
 
@@ -317,7 +318,7 @@ FragmentationDlg::populateSelectedOligomerData()
 
   m_calcOptions.setCoordinateList(coordList);
 
-  libmass::Coordinates *coordinates = coordList.last();
+  libXpertMass::Coordinates *coordinates = coordList.last();
 
   m_ui.oligomerStartLabel->setText(QString().setNum(coordinates->start() + 1));
 
@@ -332,7 +333,7 @@ FragmentationDlg::populateFragSpecList()
 {
   for(int iter = 0; iter < mcsp_polChemDef->fragSpecList().size(); ++iter)
     {
-      libmass::FragSpec *fragSpec = mcsp_polChemDef->fragSpecList().at(iter);
+      libXpertMass::FragSpec *fragSpec = mcsp_polChemDef->fragSpecList().at(iter);
       Q_ASSERT(fragSpec);
 
       m_ui.fragmentationPatternListWidget->addItem(fragSpec->name());
@@ -385,14 +386,14 @@ FragmentationDlg::fragment()
 
   // We'll need to use the specifications in the polymer chemistry
   // definition... for each frag options object.
-  QList<libmass::FragSpec *> refList = mcsp_polChemDef->fragSpecList();
+  QList<libXpertMass::FragSpec *> refList = mcsp_polChemDef->fragSpecList();
 
   // We'll have to store all the fragOptions in a list:
   QList<FragOptions *> fragOptionList;
 
   // We'll need a fragmentation specification each time we iterate in
   // a new specification item below.
-  libmass::FragSpec fragSpec(mcsp_polChemDef, "NOT_SET");
+  libXpertMass::FragSpec fragSpec(mcsp_polChemDef, "NOT_SET");
 
   // Finally parse all the different fragmentation specification items
   // currently selected in the list widget.
@@ -412,7 +413,7 @@ FragmentationDlg::fragment()
 
           QString name = item->text();
 
-          int res = libmass::FragSpec::isNameInList(name, refList, &fragSpec);
+          int res = libXpertMass::FragSpec::isNameInList(name, refList, &fragSpec);
 
           if(res == -1)
             {
@@ -439,12 +440,12 @@ FragmentationDlg::fragment()
 
           if(!m_ui.decompositionsFormulaLineEdit->text().isEmpty())
             {
-              libmass::Formula formula(
+              libXpertMass::Formula formula(
                 m_ui.decompositionsFormulaLineEdit->text());
 
               // At this point, we should check if the formula is valid.
 
-              libmass::IsotopicDataCstSPtr isotopic_data_csp =
+              libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
                 mcsp_polChemDef->getIsotopicDataCstSPtr();
 
                 qDebug() << "Going to validate decomposition formula" << formula.toString();
@@ -466,7 +467,7 @@ FragmentationDlg::fragment()
           // We got the coordinates of the oligomer to fragment in the
           // mp_calcOptions from the sequence editor window.
 
-          libmass::Coordinates *coordinates =
+          libXpertMass::Coordinates *coordinates =
             m_calcOptions.coordinateList().last();
 
           fragOptions->setStartIndex(coordinates->start());
@@ -529,7 +530,7 @@ FragmentationDlg::fragment()
       delete mpa_fragmenter;
 
       QMessageBox::critical(this,
-                            tr("massXpert - libmass::Polymer Cleavage"),
+                            tr("massXpert - libXpertMass::Polymer Cleavage"),
                             tr("Failed to perform fragmentation."),
                             QMessageBox::Ok);
 
@@ -603,24 +604,24 @@ FragmentationDlg::fragment()
 
 void
 FragmentationDlg::updateFragmentationDetails(
-  const libmass::CalcOptions &calcOptions)
+  const libXpertMass::CalcOptions &calcOptions)
 {
-  if(calcOptions.monomerEntities() & libmass::MONOMER_CHEMENT_MODIF)
+  if(calcOptions.monomerEntities() & libXpertMass::MONOMER_CHEMENT_MODIF)
     m_ui.modificationsCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.modificationsCheckBox->setCheckState(Qt::Unchecked);
 
-  if(calcOptions.polymerEntities() & libmass::POLYMER_CHEMENT_LEFT_END_MODIF)
+  if(calcOptions.polymerEntities() & libXpertMass::POLYMER_CHEMENT_LEFT_END_MODIF)
     m_ui.leftModifCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.leftModifCheckBox->setCheckState(Qt::Unchecked);
 
-  if(calcOptions.polymerEntities() & libmass::POLYMER_CHEMENT_RIGHT_END_MODIF)
+  if(calcOptions.polymerEntities() & libXpertMass::POLYMER_CHEMENT_RIGHT_END_MODIF)
     m_ui.rightModifCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.rightModifCheckBox->setCheckState(Qt::Unchecked);
 
-  if(calcOptions.monomerEntities() & libmass::MONOMER_CHEMENT_CROSS_LINK)
+  if(calcOptions.monomerEntities() & libXpertMass::MONOMER_CHEMENT_CROSS_LINK)
     m_ui.crossLinksCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.crossLinksCheckBox->setCheckState(Qt::Unchecked);
@@ -838,7 +839,7 @@ FragmentationDlg::traceColorPushButtonClicked()
   QPushButton *colored_push_button = m_ui.colorSelectorPushButton;
 
   // Allow (true) the user to select a color that has been chosen already.
-  QColor color = libmassgui::ColorSelector::chooseColor(true);
+  QColor color = libXpertMassGui::ColorSelector::chooseColor(true);
 
   if(color.isValid())
     {
@@ -932,7 +933,7 @@ FragmentationDlg::configureMassPeakShaper()
 {
   if(mp_massPeakShaperConfigDlg == nullptr)
     {
-      mp_massPeakShaperConfigDlg = new libmassgui::MassPeakShaperConfigDlg(
+      mp_massPeakShaperConfigDlg = new libXpertMassGui::MassPeakShaperConfigDlg(
         this, m_applicationName, "Mass peak shaper configuration");
 
       if(mp_massPeakShaperConfigDlg == nullptr)
@@ -942,8 +943,8 @@ FragmentationDlg::configureMassPeakShaper()
   // The signal below is only emitted when checking parameters worked ok.
   connect(
     mp_massPeakShaperConfigDlg,
-    &libmassgui::MassPeakShaperConfigDlg::updatedMassPeakShaperConfigSignal,
-    [this](const libmass::MassPeakShaperConfig &config) {
+    &libXpertMassGui::MassPeakShaperConfigDlg::updatedMassPeakShaperConfigSignal,
+    [this](const libXpertMass::MassPeakShaperConfig &config) {
       m_massPeakShaperConfig = config;
 
       // qDebug().noquote() << "Our local copy of the config:"
@@ -973,16 +974,17 @@ FragmentationDlg::loadIsotopicDataFromFile()
       return false;
     }
 
-  QString error;
+  libXpertMass::IsotopicDataUserConfigHandler handler;
+  handler.loadData(file_name);
 
-  msp_isotopicData = libmass::loadIsotopicDataFromFile(file_name, error);
+  msp_isotopicData = handler.getIsotopicData();
 
-  if(msp_isotopicData == nullptr)
+  if(msp_isotopicData == nullptr || !msp_isotopicData->size())
     {
       QMessageBox::warning(
         this,
         QString("%1 - %2").arg(m_applicationName).arg(m_windowDescription),
-        error,
+       "Failed to load the isotopic data.",
         QMessageBox::Ok);
 
       return false;
@@ -1045,7 +1047,7 @@ FragmentationDlg::synthesizeMassSpectra()
   // want a non-const shared pointer!
 
   if(msp_isotopicData == nullptr)
-    msp_isotopicData = std::make_shared<libmass::IsotopicData>(
+    msp_isotopicData = std::make_shared<libXpertMass::IsotopicData>(
       *mp_editorWnd->polChemDefRendering()->getPolChemDef()->getIsotopicDataCstSPtr());
 
   if(msp_isotopicData == nullptr)
@@ -1055,12 +1057,12 @@ FragmentationDlg::synthesizeMassSpectra()
 
   // And now we can instantiate a cluster generator
 
-  libmass::IsotopicClusterGenerator isotopic_cluster_generator(
+  libXpertMass::IsotopicClusterGenerator isotopic_cluster_generator(
     msp_isotopicData);
 
   // Construct the formula/charge pairs needed for the isotopic cluster
   // calculations.
-  std::vector<libmass::FormulaChargePair> formula_charge_pairs;
+  std::vector<libXpertMass::FormulaChargePair> formula_charge_pairs;
 
   // For debugging purposes.
   // std::size_t oligomer_count = 0;
@@ -1083,7 +1085,7 @@ FragmentationDlg::synthesizeMassSpectra()
       // could end with something like (specifically with immonium ions that are
       // very small) CxHyNz-Ow
 
-      libmass::Formula formula(formula_text);
+      libXpertMass::Formula formula(formula_text);
 
       // We want to check the formula "fresh", store the symbol/count pairs and
       // reset (although not really needed since we have created the formula at
@@ -1102,7 +1104,7 @@ FragmentationDlg::synthesizeMassSpectra()
       // generator.
 
       formula_charge_pairs.push_back(
-        libmass::FormulaChargePair(formula_text, charge));
+        libXpertMass::FormulaChargePair(formula_text, charge));
 
       //++oligomer_count;
     }
@@ -1115,7 +1117,7 @@ FragmentationDlg::synthesizeMassSpectra()
   isotopic_cluster_generator.setFormulaChargePairs(formula_charge_pairs);
 
   isotopic_cluster_generator.setIsotopicDataType(
-    libmass::IsotopicDataType::LIBRARY_CONFIG);
+    libXpertMass::IsotopicDataType::LIBRARY_CONFIG);
 
   double cumulated_probabilities = m_ui.cumulatedProbsDoubleSpinBox->value();
   isotopic_cluster_generator.setMaxSummedProbability(cumulated_probabilities);
@@ -1130,7 +1132,7 @@ FragmentationDlg::synthesizeMassSpectra()
 
   // And now perform the work. For each formula/charge pair, the generator will
   // create an isotopic cluster shaped trace associated to the corresponding
-  // charge in a libmass::IsotopicClusterChargePair. All these pairs are stored
+  // charge in a libXpertMass::IsotopicClusterChargePair. All these pairs are stored
   // in a vector.
 
   count = isotopic_cluster_generator.run();
@@ -1151,7 +1153,7 @@ FragmentationDlg::synthesizeMassSpectra()
 
   // qDebug() << "The number of clusters generated:" << count;
 
-  std::vector<libmass::IsotopicClusterChargePair>
+  std::vector<libXpertMass::IsotopicClusterChargePair>
     isotopic_cluster_charge_pairs =
       isotopic_cluster_generator.getIsotopicClusterChargePairs();
 
@@ -1164,7 +1166,7 @@ FragmentationDlg::synthesizeMassSpectra()
 
   // Note how we ask a reference to the pair that is iterated into, otherwise we
   // would get a copy and we would lose the local charge modification.
-  for(libmass::IsotopicClusterChargePair &pair : isotopic_cluster_charge_pairs)
+  for(libXpertMass::IsotopicClusterChargePair &pair : isotopic_cluster_charge_pairs)
     pair.second = 1;
 
   qDebug();
@@ -1172,7 +1174,7 @@ FragmentationDlg::synthesizeMassSpectra()
   // Now instantiate the isotopic cluster shaper and set the clusters' data in
   // it.
 
-  libmass::IsotopicClusterShaper isotopic_cluster_shaper(
+  libXpertMass::IsotopicClusterShaper isotopic_cluster_shaper(
     isotopic_cluster_charge_pairs, m_massPeakShaperConfig);
 
   isotopic_cluster_shaper.setNormalizeIntensity(normalization_intensity);
@@ -1260,7 +1262,7 @@ FragmentationDlg::prepareResultsTxtString()
   //
   // Note that name and coords are optional.
   bool forXpertMiner         = false;
-  libmass::MassType massType = libmass::MassType::MASS_NONE;
+  libXpertMass::MassType massType = libXpertMass::MassType::MASS_NONE;
 
   forXpertMiner = m_ui.forXpertMinerCheckBox->isChecked();
 
@@ -1278,9 +1280,9 @@ FragmentationDlg::prepareResultsTxtString()
       // the mono or avg masses.
 
       if(m_ui.monoRadioButton->isChecked())
-        massType = libmass::MassType::MASS_MONO;
+        massType = libXpertMass::MassType::MASS_MONO;
       else
-        massType = libmass::MassType::MASS_AVG;
+        massType = libXpertMass::MassType::MASS_AVG;
     }
 
   bool withSequence = m_ui.withSequenceCheckBox->isChecked();
@@ -1360,4 +1362,4 @@ FragmentationDlg::selectResultsFile()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
