@@ -41,29 +41,29 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/PolChemDef.hpp>
-#include <libmass/Isotope.hpp>
-#include <libmass/IsotopicData.hpp>
-#include <libmass/IsotopicDataLibraryHandler.hpp>
-#include <libmass/IsotopicDataUserConfigHandler.hpp>
+#include <libXpertMass/PolChemDef.hpp>
+#include <libXpertMass/Isotope.hpp>
+#include <libXpertMass/IsotopicData.hpp>
+#include <libXpertMass/IsotopicDataLibraryHandler.hpp>
+#include <libXpertMass/IsotopicDataUserConfigHandler.hpp>
 
 
 /////////////////////// libmassgui includes
-#include <libmassgui/IsotopicDataTableViewModel.hpp>
+#include <libXpertMassGui/IsotopicDataTableViewModel.hpp>
 
 /////////////////////// Local includes
 #include "IsotopeDefDlg.hpp"
 #include "PolChemDefWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
 {
 
 
-IsotopeDefDlg::IsotopeDefDlg(libmass::PolChemDefSPtr polChemDefSPtr,
+IsotopeDefDlg::IsotopeDefDlg(libXpertMass::PolChemDefSPtr polChemDefSPtr,
                              PolChemDefWnd *polChemDefWnd,
                              const QString &settingsFilePath,
                              const QString &applicationName,
@@ -147,18 +147,18 @@ IsotopeDefDlg::initialize()
   connect(m_ui.insertIsotopeAbovePushButton,
           &QPushButton::clicked,
           mpa_isotopicDataTableViewModel,
-          &libmassgui::IsotopicDataTableViewModel::insertIsotopeRowAbove);
+          &libXpertMassGui::IsotopicDataTableViewModel::insertIsotopeRowAbove);
 
 
   connect(m_ui.insertIsotopeBelowPushButton,
           &QPushButton::clicked,
           mpa_isotopicDataTableViewModel,
-          &libmassgui::IsotopicDataTableViewModel::insertIsotopeRowBelow);
+          &libXpertMassGui::IsotopicDataTableViewModel::insertIsotopeRowBelow);
 
   connect(m_ui.removeSelectedPushButton,
           &QPushButton::clicked,
           mpa_isotopicDataTableViewModel,
-          &libmassgui::IsotopicDataTableViewModel::removeSelected);
+          &libXpertMassGui::IsotopicDataTableViewModel::removeSelected);
 
   connect(m_ui.validatePushButton,
           &QPushButton::clicked,
@@ -177,12 +177,12 @@ IsotopeDefDlg::initialize()
     m_ui.saveAsPushButton, &QPushButton::clicked, this, &IsotopeDefDlg::saveAs);
 
   connect(mpa_isotopicDataTableViewModel,
-          &libmassgui::IsotopicDataTableViewModel::modifiedSignal,
+          &libXpertMassGui::IsotopicDataTableViewModel::modifiedSignal,
           this,
           [this]() { setModified(); });
 
   // connect(mpa_isotopicDataTableViewModel,
-  //&libmassgui::IsotopicDataTableViewModel::newProbabilityDataSignal,
+  //&libXpertMassGui::IsotopicDataTableViewModel::newProbabilityDataSignal,
   // this,
   //&IsotopeDefDlg::newProbabilityDataSignal);
 
@@ -259,7 +259,7 @@ IsotopeDefDlg::loadData()
   // case that has to be user config handler, we do not want the library
   // handler.
 
-  libmass::IsotopicDataUserConfigHandler isotopic_data_handler(
+  libXpertMass::IsotopicDataUserConfigHandler isotopic_data_handler(
     msp_polChemDef->getIsotopicDataSPtr());
 
   if(!isotopic_data_handler.loadData(file_path))
@@ -300,7 +300,7 @@ IsotopeDefDlg::save()
   // We need to instantiate the proper isotopic data handler. In our present
   // case that can be user config handler, we do not need the library handler.
 
-  libmass::IsotopicDataUserConfigHandler isotopic_data_handler(
+  libXpertMass::IsotopicDataUserConfigHandler isotopic_data_handler(
     msp_polChemDef->getIsotopicDataSPtr());
 
   bool res = false;
@@ -347,7 +347,7 @@ IsotopeDefDlg::saveAs()
   // case that has to be user config handler, we do not want the library
   // handler.
 
-  libmass::IsotopicDataUserConfigHandler isotopic_data_handler(
+  libXpertMass::IsotopicDataUserConfigHandler isotopic_data_handler(
     msp_polChemDef->getIsotopicDataSPtr());
 
   // Provide the user with the opportunity to define a file name.
@@ -401,13 +401,13 @@ IsotopeDefDlg::setupIsotopicDataTableView()
     {
 
       msp_polChemDef->setIsotopicDataSPtr(
-        std::make_shared<libmass::IsotopicData>());
+        std::make_shared<libXpertMass::IsotopicData>());
 
       // Silently load the IsoSpec's isotopic data tables.  For this, we can can
       // allocate the proper handler but first we need to allocate the isotopic
       // data.
 
-      libmass::IsotopicDataLibraryHandler isotopic_data_handler(
+      libXpertMass::IsotopicDataLibraryHandler isotopic_data_handler(
         msp_polChemDef->getIsotopicDataSPtr());
 
       if(!isotopic_data_handler.loadData())
@@ -416,7 +416,7 @@ IsotopeDefDlg::setupIsotopicDataTableView()
 
   // Now we can link the data to the table view model.
 
-  mpa_isotopicDataTableViewModel = new libmassgui::IsotopicDataTableViewModel(
+  mpa_isotopicDataTableViewModel = new libXpertMassGui::IsotopicDataTableViewModel(
     this, msp_polChemDef->getIsotopicDataSPtr());
 
   m_ui.isotopicDataTableView->setModel(mpa_isotopicDataTableViewModel);
@@ -428,17 +428,17 @@ IsotopeDefDlg::setupIsotopicDataTableView()
   mpa_isotopicDataTableViewModel->setTableView(m_ui.isotopicDataTableView);
 
   connect(m_ui.isotopicDataTableView,
-          &libmassgui::IsotopicDataTableView::selectionChangedSignal,
+          &libXpertMassGui::IsotopicDataTableView::selectionChangedSignal,
           this,
           &IsotopeDefDlg::selectionChanged);
 
   connect(m_ui.isotopicDataTableView,
-          &libmassgui::IsotopicDataTableView::allSelectedIndicesSignal,
+          &libXpertMassGui::IsotopicDataTableView::allSelectedIndicesSignal,
           this,
           &IsotopeDefDlg::allSelectedIndices);
 
   connect(m_ui.isotopicDataTableView,
-          &libmassgui::IsotopicDataTableView::selectedRowsChangedSignal,
+          &libXpertMassGui::IsotopicDataTableView::selectedRowsChangedSignal,
           this,
           &IsotopeDefDlg::selectedRowsChanged);
 
@@ -559,15 +559,15 @@ IsotopeDefDlg::updateMassAndProbDetails(std::set<int> rows_set)
 
   // Compute the iterator range for the selected rows.
 
-  libmass::IsotopeCstIterator iter_begin =
+  libXpertMass::IsotopeCstIterator iter_begin =
     msp_polChemDef->getIsotopicDataSPtr()->getIsotopes().cbegin() +
     *rows_set.cbegin();
 
-  libmass::IsotopeCstIterator iter_end = iter_begin + rows_set.size();
+  libXpertMass::IsotopeCstIterator iter_end = iter_begin + rows_set.size();
 
   qDebug() << "Distance: " << std::distance(iter_begin, iter_end);
 
-  libmass::IsotopeCstIteratorPair iter_pair(iter_begin, iter_end);
+  libXpertMass::IsotopeCstIteratorPair iter_pair(iter_begin, iter_end);
 
   // Now actually ask the details.
   std::vector<QString> errors;
@@ -595,7 +595,7 @@ IsotopeDefDlg::updateMassAndProbDetails(std::set<int> rows_set)
     QString::number(cumulated_probabilities, 'f', 6));
 
   double mono_mass = msp_polChemDef->getIsotopicDataSPtr()->getMonoMass(
-    libmass::IsotopeCstIteratorPair(iter_begin, iter_end), errors);
+    libXpertMass::IsotopeCstIteratorPair(iter_begin, iter_end), errors);
 
   if(errors.size())
     {
@@ -619,7 +619,7 @@ IsotopeDefDlg::updateMassAndProbDetails(std::set<int> rows_set)
   m_ui.monoMassLineEdit->setText(QString::number(mono_mass, 'f', 12));
 
   double avg_mass = msp_polChemDef->getIsotopicDataSPtr()->computeAvgMass(
-    libmass::IsotopeCstIteratorPair(iter_begin, iter_end), errors);
+    libXpertMass::IsotopeCstIteratorPair(iter_begin, iter_end), errors);
 
   if(errors.size())
     {
@@ -645,4 +645,4 @@ IsotopeDefDlg::updateMassAndProbDetails(std::set<int> rows_set)
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
