@@ -44,8 +44,8 @@
 #include <QList>
 #include <QApplication>
 #include <QDebug>
-#include <libmass/PolChemDef.hpp>
-#include <libmass/PolChemDefEntity.hpp>
+#include <libXpertMass/PolChemDef.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
 
 
 /////////////////////// Local includes
@@ -55,7 +55,7 @@
 
 #include "MainWindow.hpp"
 
-#include "libmass/PolChemDefSpec.hpp"
+#include <libXpertMass/PolChemDefSpec.hpp>
 #include "../nongui/PolChemDefCatParser.hpp"
 
 #include "ConfigSettingsDlg.hpp"
@@ -69,7 +69,7 @@
 #include "../nongui/ConfigSetting.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -1070,21 +1070,21 @@ namespace massxpert
 
     settings.beginGroup("decimalPlacesOptions");
 
-    libmass::ATOM_DEC_PLACES = settings.value("ATOM_DEC_PLACES", 10).toInt();
+    libXpertMass::ATOM_DEC_PLACES = settings.value("ATOM_DEC_PLACES", 10).toInt();
     // qDebug() << __FILE__ << __LINE__
     // << "ATOM_DEC_PLACES" << ATOM_DEC_PLACES;
 
-    libmass::OLIGOMER_DEC_PLACES =
+    libXpertMass::OLIGOMER_DEC_PLACES =
       settings.value("OLIGOMER_DEC_PLACES", 5).toInt();
     // qDebug() << __FILE__ << __LINE__
     // << "OLIGOMER_DEC_PLACES" << OLIGOMER_DEC_PLACES;
 
-    libmass::POLYMER_DEC_PLACES =
+    libXpertMass::POLYMER_DEC_PLACES =
       settings.value("POLYMER_DEC_PLACES", 3).toInt();
     // qDebug() << __FILE__ << __LINE__
     // << "POLYMER_DEC_PLACES" << POLYMER_DEC_PLACES;
 
-    libmass::PH_PKA_DEC_PLACES = settings.value("PH_PKA_DEC_PLACES", 2).toInt();
+    libXpertMass::PH_PKA_DEC_PLACES = settings.value("PH_PKA_DEC_PLACES", 2).toInt();
     // qDebug() << __FILE__ << __LINE__
     // << "PH_PKA_DEC_PLACES" << PH_PKA_DEC_PLACES;
 
@@ -1100,24 +1100,24 @@ namespace massxpert
   }
 
 
-  QList<libmass::PolChemDefSpec *> *
+  QList<libXpertMass::PolChemDefSpec *> *
   MainWindow::polChemDefCatList()
   {
     return &m_polChemDefCatList;
   }
 
 
-  std::vector<libmass::PolChemDefCstSPtr>
+  std::vector<libXpertMass::PolChemDefCstSPtr>
   MainWindow::polChemDefList()
   {
     return m_polChemDefList;
   }
 
 
-  libmass::PolChemDefSpec *
+  libXpertMass::PolChemDefSpec *
   MainWindow::polChemDefSpecName(const QString &name)
   {
-    libmass::PolChemDefSpec *polChemDefSpec = 0;
+    libXpertMass::PolChemDefSpec *polChemDefSpec = 0;
 
     for(int iter = 0; iter < m_polChemDefCatList.size(); ++iter)
       {
@@ -1131,10 +1131,10 @@ namespace massxpert
   }
 
 
-  libmass::PolChemDefSpec *
+  libXpertMass::PolChemDefSpec *
   MainWindow::polChemDefSpecFilePath(const QString &filePath)
   {
-    libmass::PolChemDefSpec *polChemDefSpec = 0;
+    libXpertMass::PolChemDefSpec *polChemDefSpec = 0;
 
     for(int iter = 0; iter < m_polChemDefCatList.size(); ++iter)
       {
@@ -1148,15 +1148,15 @@ namespace massxpert
   }
 
 
-  libmass::PolChemDefCstSPtr
+  libXpertMass::PolChemDefCstSPtr
   MainWindow::polChemDefByName(const QString &name)
   {
-    libmass::PolChemDefCstSPtr polChemDefCstSPtr;
+    libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr;
 
-    std::vector<libmass::PolChemDefCstSPtr>::iterator it =
+    std::vector<libXpertMass::PolChemDefCstSPtr>::iterator it =
       find_if(m_polChemDefList.begin(),
               m_polChemDefList.end(),
-              [name](libmass::PolChemDefCstSPtr pcdsp) {
+              [name](libXpertMass::PolChemDefCstSPtr pcdsp) {
                 return pcdsp->name() == name;
               });
 
@@ -1170,7 +1170,7 @@ namespace massxpert
   void
   MainWindow::polChemDefCatStringList(QStringList &stringList)
   {
-    libmass::PolChemDefSpec *polChemDefSpec = 0;
+    libXpertMass::PolChemDefSpec *polChemDefSpec = 0;
 
     for(int iter = 0; iter < m_polChemDefCatList.size(); ++iter)
       {
@@ -1799,4 +1799,4 @@ namespace massxpert
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
