@@ -41,7 +41,7 @@
 #include "MassSearchDlg.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -49,13 +49,13 @@ namespace massxpert
 
 
 MassSearchDlg::MassSearchDlg(SequenceEditorWnd *editorWnd,
-                             libmass::Polymer *polymer,
-                             /* no libmass::PolChemDef **/
+                             libXpertMass::Polymer *polymer,
+                             /* no libXpertMass::PolChemDef **/
                              const QString &configSettingsFilePath,
                              const QString &applicationName,
                              const QString &description,
-                             const libmass::CalcOptions &calcOptions,
-                             libmass::IonizeRule *ionizeRule)
+                             const libXpertMass::CalcOptions &calcOptions,
+                             libXpertMass::IonizeRule *ionizeRule)
   : AbstractSeqEdWndDependentDlg(editorWnd,
                                  polymer,
                                  0, /*polChemDef*/
@@ -363,7 +363,7 @@ MassSearchDlg::updateSelectionData(bool fromSequenceEditor)
         {
           // Set the "selection" to be the whole sequence.
 
-          libmass::Coordinates coordinates(0, mp_polymer->size() - 1);
+          libXpertMass::Coordinates coordinates(0, mp_polymer->size() - 1);
           m_calcOptions.setCoordinateList(coordinates);
 
           m_ui.wholeSequenceRadioButton->setChecked(true);
@@ -380,7 +380,7 @@ MassSearchDlg::updateSelectionData(bool fromSequenceEditor)
   // sequence data directly from the sequence editor window. So get
   // all these coordinates !
 
-  libmass::CoordinateList coordList;
+  libXpertMass::CoordinateList coordList;
 
   bool res = mp_editorWnd->mpa_editorGraphicsView->selectionIndices(&coordList);
 
@@ -400,15 +400,15 @@ MassSearchDlg::updateSelectionData(bool fromSequenceEditor)
         }
       else
         {
-          libmass::Coordinates *coordinates = coordList.first();
+          libXpertMass::Coordinates *coordinates = coordList.first();
 
           if(coordinates->start() == coordinates->end())
             {
               // Construct a string with both the monomer code and
               // its position in the sequence.
 
-              libmass::Polymer *polymer = mp_editorWnd->polymer();
-              const libmass::Monomer *monomer =
+              libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
+              const libXpertMass::Monomer *monomer =
                 polymer->monomerList().at(coordinates->start());
 
               QString text = tr("%1 at pos. %2")
@@ -433,7 +433,7 @@ MassSearchDlg::updateSelectionData(bool fromSequenceEditor)
       // There is no selection, set the "selection" to be the
       // whole sequence.
 
-      libmass::Coordinates coordinates(0, mp_polymer->size() - 1);
+      libXpertMass::Coordinates coordinates(0, mp_polymer->size() - 1);
       m_calcOptions.setCoordinateList(coordinates);
 
       m_ui.wholeSequenceRadioButton->setChecked(true);
@@ -453,11 +453,11 @@ MassSearchDlg::checkTolerance(int type)
 
   QString text;
 
-  if(type & libmass::MassType::MASS_MONO)
+  if(type & libXpertMass::MassType::MASS_MONO)
     {
       text = m_ui.monoMassLineEdit->text();
     }
-  else if(type & libmass::MassType::MASS_AVG)
+  else if(type & libXpertMass::MassType::MASS_AVG)
     {
       text = m_ui.avgMassLineEdit->text();
     }
@@ -486,12 +486,12 @@ MassSearchDlg::calculateTolerance(double value, int type)
   QString text;
 
 
-  if(type & libmass::MassType::MASS_MONO)
+  if(type & libXpertMass::MassType::MASS_MONO)
     {
       index = m_ui.monoToleranceComboBox->currentIndex();
       text  = m_ui.monoMassLineEdit->text();
     }
-  else if(type & libmass::MassType::MASS_AVG)
+  else if(type & libXpertMass::MassType::MASS_AVG)
     {
       index = m_ui.avgToleranceComboBox->currentIndex();
       text  = m_ui.avgMassLineEdit->text();
@@ -509,7 +509,7 @@ MassSearchDlg::calculateTolerance(double value, int type)
     {
       // MASS_TOLERANCE_AMU
 
-      type &libmass::MassType::MASS_MONO ? m_monoTolerance = nominal
+      type &libXpertMass::MassType::MASS_MONO ? m_monoTolerance = nominal
                                          : m_avgTolerance  = nominal;
 
       return true;
@@ -518,7 +518,7 @@ MassSearchDlg::calculateTolerance(double value, int type)
     {
       // MASS_TOLERANCE_PCT
 
-      type &libmass::MassType::MASS_MONO
+      type &libXpertMass::MassType::MASS_MONO
         ? m_monoTolerance = nominal * (value / 100)
         : m_avgTolerance  = nominal * (value / 100);
 
@@ -528,7 +528,7 @@ MassSearchDlg::calculateTolerance(double value, int type)
     {
       // MASS_TOLERANCE_PPM
 
-      type &libmass::MassType::MASS_MONO
+      type &libXpertMass::MassType::MASS_MONO
         ? m_monoTolerance = nominal * (value / 1000000)
         : m_avgTolerance  = nominal * (value / 1000000);
 
@@ -544,14 +544,14 @@ MassSearchDlg::calculateTolerance(double value, int type)
 bool
 MassSearchDlg::parseMassText(int type)
 {
-  Q_ASSERT(type & libmass::MassType::MASS_MONO ||
-           type & libmass::MassType::MASS_AVG);
+  Q_ASSERT(type & libXpertMass::MassType::MASS_MONO ||
+           type & libXpertMass::MassType::MASS_AVG);
 
   QString text;
 
-  if(type & libmass::MassType::MASS_MONO)
+  if(type & libXpertMass::MassType::MASS_MONO)
     text = m_ui.monoMassTextEdit->toPlainText();
-  else if(type & libmass::MassType::MASS_AVG)
+  else if(type & libXpertMass::MassType::MASS_AVG)
     text = m_ui.avgMassTextEdit->toPlainText();
   else
     Q_ASSERT(0);
@@ -572,7 +572,7 @@ MassSearchDlg::parseMassText(int type)
           return false;
         }
 
-      if(type & libmass::MassType::MASS_MONO)
+      if(type & libXpertMass::MassType::MASS_MONO)
         m_monoMassesList.append(value);
       else
         m_avgMassesList.append(value);
@@ -584,26 +584,26 @@ MassSearchDlg::parseMassText(int type)
 
 bool
 MassSearchDlg::searchMass(double value,
-                          const libmass::Coordinates &coordinates,
+                          const libXpertMass::Coordinates &coordinates,
                           int type)
 {
-  //    libmass::CalcOptions localCalcOptions(*mp_calcOptions);
-  libmass::IonizeRule localIonizeRule(*mp_ionizeRule);
+  //    libXpertMass::CalcOptions localCalcOptions(*mp_calcOptions);
+  libXpertMass::IonizeRule localIonizeRule(*mp_ionizeRule);
 
   int count = 0;
   int cycle = 0;
 
-  Q_ASSERT(type & libmass::MassType::MASS_MONO ||
-           type & libmass::MassType::MASS_AVG);
+  Q_ASSERT(type & libXpertMass::MassType::MASS_MONO ||
+           type & libXpertMass::MassType::MASS_AVG);
 
   int startIndex = coordinates.start();
   int endIndex   = coordinates.end();
 
-  double maxValue = type & libmass::MassType::MASS_MONO
+  double maxValue = type & libXpertMass::MassType::MASS_MONO
                       ? value + m_monoTolerance
                       : value + m_avgTolerance;
 
-  double minValue = type & libmass::MassType::MASS_MONO
+  double minValue = type & libXpertMass::MassType::MASS_MONO
                       ? value - m_monoTolerance
                       : value - m_avgTolerance;
 
@@ -636,20 +636,20 @@ MassSearchDlg::searchMass(double value,
 
               localIonizeRule.setLevel(kter);
 
-              libmass::Oligomer oligomerTest(mp_polymer,
+              libXpertMass::Oligomer oligomerTest(mp_polymer,
                                              "NOT_SET" /*name*/,
                                              QString("") /*description*/,
                                              false /*modified*/,
-                                             libmass::Ponderable(),
+                                             libXpertMass::Ponderable(),
                                              localIonizeRule,
-                                             libmass::CalcOptions(),
+                                             libXpertMass::CalcOptions(),
                                              false,
                                              iter,
                                              iter + jter);
 
               oligomerTest.calculateMasses(&m_calcOptions);
 
-              double mz = type & libmass::MassType::MASS_MONO
+              double mz = type & libXpertMass::MassType::MASS_MONO
                             ? oligomerTest.mono()
                             : oligomerTest.avg();
 
@@ -668,8 +668,8 @@ MassSearchDlg::searchMass(double value,
 
               // At this point the oligomer has correct masses.
 
-              libmass::Oligomer *oligomerNew =
-                new libmass::Oligomer(oligomerTest);
+              libXpertMass::Oligomer *oligomerNew =
+                new libXpertMass::Oligomer(oligomerTest);
 
               ++count;
 
@@ -683,8 +683,8 @@ MassSearchDlg::searchMass(double value,
 
               // Set the searched mz in a prop.
 
-              libmass::DoubleProp *prop =
-                new libmass::DoubleProp("SEARCHED_MZ", value);
+              libXpertMass::DoubleProp *prop =
+                new libXpertMass::DoubleProp("SEARCHED_MZ", value);
 
               oligomerNew->appendProp(prop);
 
@@ -692,11 +692,11 @@ MassSearchDlg::searchMass(double value,
 
               double error = mz - value;
 
-              prop = new libmass::DoubleProp("ERROR_MZ", error);
+              prop = new libXpertMass::DoubleProp("ERROR_MZ", error);
 
               oligomerNew->appendProp(prop);
 
-              type &libmass::MassType::MASS_MONO
+              type &libXpertMass::MassType::MASS_MONO
                 ? mpa_monoOligomerTableViewModel->addOligomer(oligomerNew)
                 : mpa_avgOligomerTableViewModel->addOligomer(oligomerNew);
 
@@ -723,23 +723,23 @@ MassSearchDlg::searchMasses(int type)
   if(!mp_polymer->size())
     return false;
 
-  const libmass::CoordinateList &coordinateList =
+  const libXpertMass::CoordinateList &coordinateList =
     m_calcOptions.coordinateList();
 
-  if(type & libmass::MassType::MASS_MONO)
+  if(type & libXpertMass::MassType::MASS_MONO)
     {
       for(int iter = 0; iter < m_monoMassesList.size(); ++iter)
         {
           double value = m_monoMassesList.at(iter);
 
-          if(!calculateTolerance(value, libmass::MassType::MASS_MONO))
+          if(!calculateTolerance(value, libXpertMass::MassType::MASS_MONO))
             return false;
 
           for(int iter = 0; iter < coordinateList.size(); ++iter)
             {
               if(!searchMass(value,
                              *(coordinateList.at(iter)),
-                             libmass::MassType::MASS_MONO))
+                             libXpertMass::MassType::MASS_MONO))
                 return false;
 
               m_ui.massSearchProgressBar->setValue(++m_progressValue);
@@ -749,20 +749,20 @@ MassSearchDlg::searchMasses(int type)
             }
         }
     }
-  else if(type & libmass::MassType::MASS_AVG)
+  else if(type & libXpertMass::MassType::MASS_AVG)
     {
       for(int iter = 0; iter < m_avgMassesList.size(); ++iter)
         {
           double value = m_avgMassesList.at(iter);
 
-          if(!calculateTolerance(value, libmass::MassType::MASS_AVG))
+          if(!calculateTolerance(value, libXpertMass::MassType::MASS_AVG))
             return false;
 
           for(int iter = 0; iter < coordinateList.size(); ++iter)
             {
               if(!searchMass(value,
                              *(coordinateList.at(iter)),
-                             libmass::MassType::MASS_AVG))
+                             libXpertMass::MassType::MASS_AVG))
                 return false;
 
               m_ui.massSearchProgressBar->setValue(++m_progressValue);
@@ -800,10 +800,10 @@ MassSearchDlg::search()
 
   m_abort = false;
 
-  if(!parseMassText(libmass::MassType::MASS_MONO))
+  if(!parseMassText(libXpertMass::MassType::MASS_MONO))
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::Polymer Mass Search"),
+                           tr("massXpert - libXpertMass::Polymer Mass Search"),
                            tr("%1@%2\n"
                               "Failed to parse the masses to search for MONO.")
                              .arg(__FILE__)
@@ -813,10 +813,10 @@ MassSearchDlg::search()
       return;
     }
 
-  if(!parseMassText(libmass::MassType::MASS_AVG))
+  if(!parseMassText(libXpertMass::MassType::MASS_AVG))
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::Polymer Mass Search"),
+                           tr("massXpert - libXpertMass::Polymer Mass Search"),
                            tr("%1@%2\n"
                               "Failed to parse the masses to search for AVG.")
                              .arg(__FILE__)
@@ -828,7 +828,7 @@ MassSearchDlg::search()
 
   if(m_monoMassesList.size())
     {
-      if(!checkTolerance(libmass::MassType::MASS_MONO))
+      if(!checkTolerance(libXpertMass::MassType::MASS_MONO))
         {
           QMessageBox::information(this,
                                    tr("massxpert - Mass Search"),
@@ -840,7 +840,7 @@ MassSearchDlg::search()
 
   if(m_avgMassesList.size())
     {
-      if(!checkTolerance(libmass::MassType::MASS_AVG))
+      if(!checkTolerance(libXpertMass::MassType::MASS_AVG))
         {
           QMessageBox::information(this,
                                    tr("massxpert - Mass Search"),
@@ -859,13 +859,13 @@ MassSearchDlg::search()
   m_progressValue            = 0;
   m_ui.massSearchProgressBar->setRange(0, masses_to_search_count);
 
-  updateProgressDetails(libmass::MassType::MASS_MONO, true);
-  updateProgressDetails(libmass::MassType::MASS_AVG, true);
+  updateProgressDetails(libXpertMass::MassType::MASS_MONO, true);
+  updateProgressDetails(libXpertMass::MassType::MASS_AVG, true);
 
-  if(!searchMasses(libmass::MassType::MASS_MONO))
+  if(!searchMasses(libXpertMass::MassType::MASS_MONO))
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::Polymer Mass Search"),
+                           tr("massXpert - libXpertMass::Polymer Mass Search"),
                            tr("%1@%2\n"
                               "Failed to search for the MONO masses.")
                              .arg(__FILE__)
@@ -878,10 +878,10 @@ MassSearchDlg::search()
       return;
     }
 
-  if(!searchMasses(libmass::MassType::MASS_AVG))
+  if(!searchMasses(libXpertMass::MassType::MASS_AVG))
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::Polymer Mass Search"),
+                           tr("massXpert - libXpertMass::Polymer Mass Search"),
                            tr("%1@%2\n"
                               "Failed to search for the AVG masses.")
                              .arg(__FILE__)
@@ -948,7 +948,7 @@ MassSearchDlg::updateIonizationData()
 void
 MassSearchDlg::updateProgressDetails(int type,
                                      bool reset,
-                                     libmass::Oligomer *oligomer)
+                                     libXpertMass::Oligomer *oligomer)
 {
   if(reset)
     {
@@ -980,16 +980,16 @@ MassSearchDlg::updateProgressDetails(int type,
 
       m_ui.lastOligoCoordinatesLineEdit->setText(coordinates);
 
-      QString mass = oligomer->monoString(libmass::OLIGOMER_DEC_PLACES);
+      QString mass = oligomer->monoString(libXpertMass::OLIGOMER_DEC_PLACES);
       m_ui.lastOligoMonoMassLineEdit->setText(mass);
 
-      mass = oligomer->avgString(libmass::OLIGOMER_DEC_PLACES);
+      mass = oligomer->avgString(libXpertMass::OLIGOMER_DEC_PLACES);
       m_ui.lastOligoAvgMassLineEdit->setText(mass);
     }
 
   m_ui.currentMassLineEdit->setText(QString().setNum(m_currentMass, 'g', 10));
 
-  type &libmass::MassType::MASS_MONO
+  type &libXpertMass::MassType::MASS_MONO
     ? m_ui.lastOligoMassTypeLineEdit->setText(tr("MONO"))
     : m_ui.lastOligoMassTypeLineEdit->setText(tr("AVG"));
 
@@ -1003,19 +1003,19 @@ MassSearchDlg::updateProgressDetails(int type,
 
 
 void
-MassSearchDlg::updateMassSearchDetails(const libmass::CalcOptions &calcOptions)
+MassSearchDlg::updateMassSearchDetails(const libXpertMass::CalcOptions &calcOptions)
 {
-  if(calcOptions.monomerEntities() & libmass::MONOMER_CHEMENT_MODIF)
+  if(calcOptions.monomerEntities() & libXpertMass::MONOMER_CHEMENT_MODIF)
     m_ui.modificationsCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.modificationsCheckBox->setCheckState(Qt::Unchecked);
 
-  if(calcOptions.polymerEntities() & libmass::POLYMER_CHEMENT_LEFT_END_MODIF)
+  if(calcOptions.polymerEntities() & libXpertMass::POLYMER_CHEMENT_LEFT_END_MODIF)
     m_ui.leftModifCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.leftModifCheckBox->setCheckState(Qt::Unchecked);
 
-  if(calcOptions.polymerEntities() & libmass::POLYMER_CHEMENT_RIGHT_END_MODIF)
+  if(calcOptions.polymerEntities() & libXpertMass::POLYMER_CHEMENT_RIGHT_END_MODIF)
     m_ui.rightModifCheckBox->setCheckState(Qt::Checked);
   else
     m_ui.rightModifCheckBox->setCheckState(Qt::Unchecked);
@@ -1064,9 +1064,9 @@ MassSearchDlg::calculateFilterTolerance(double mass, int massType)
   // Get the tolerance that is in its lineEdit.
   QString text;
 
-  if(massType == libmass::MassType::MASS_MONO)
+  if(massType == libXpertMass::MassType::MASS_MONO)
     text = m_ui.monoFilterToleranceLineEdit->text();
-  else if(massType == libmass::MassType::MASS_AVG)
+  else if(massType == libXpertMass::MassType::MASS_AVG)
     text = m_ui.avgFilterToleranceLineEdit->text();
   else
     Q_ASSERT(0);
@@ -1091,9 +1091,9 @@ MassSearchDlg::calculateFilterTolerance(double mass, int massType)
   // What's the item currently selected in the comboBox?
   int index = 0;
 
-  if(massType == libmass::MassType::MASS_MONO)
+  if(massType == libXpertMass::MassType::MASS_MONO)
     index = m_ui.monoFilterToleranceComboBox->currentIndex();
-  else if(massType == libmass::MassType::MASS_AVG)
+  else if(massType == libXpertMass::MassType::MASS_AVG)
     index = m_ui.avgFilterToleranceComboBox->currentIndex();
   else
     Q_ASSERT(0);
@@ -1258,7 +1258,7 @@ MassSearchDlg::monoFilterError()
   // At this point, depending on the item that is currently selected
   // in the comboBox, we'll have to actually compute the tolerance.
 
-  if(!calculateFilterTolerance(mass, libmass::MassType::MASS_MONO))
+  if(!calculateFilterTolerance(mass, libXpertMass::MassType::MASS_MONO))
     return;
 
   mpa_monoProxyModel->setErrorFilter(mass);
@@ -1291,7 +1291,7 @@ MassSearchDlg::avgFilterError()
   // At this point, depending on the item that is currently selected
   // in the comboBox, we'll have to actually compute the tolerance.
 
-  if(!calculateFilterTolerance(mass, libmass::MassType::MASS_AVG))
+  if(!calculateFilterTolerance(mass, libXpertMass::MassType::MASS_AVG))
     return;
 
   mpa_avgProxyModel->setErrorFilter(mass);
@@ -1324,7 +1324,7 @@ MassSearchDlg::monoFilterMonoMass()
   // At this point, depending on the item that is currently selected
   // in the comboBox, we'll have to actually compute the tolerance.
 
-  if(!calculateFilterTolerance(mass, libmass::MassType::MASS_MONO))
+  if(!calculateFilterTolerance(mass, libXpertMass::MassType::MASS_MONO))
     return;
 
   mpa_monoProxyModel->setMonoFilter(mass);
@@ -1357,7 +1357,7 @@ MassSearchDlg::avgFilterMonoMass()
   // At this point, depending on the item that is currently selected
   // in the comboBox, we'll have to actually compute the tolerance.
 
-  if(!calculateFilterTolerance(mass, libmass::MassType::MASS_AVG))
+  if(!calculateFilterTolerance(mass, libXpertMass::MassType::MASS_AVG))
     return;
 
   mpa_avgProxyModel->setMonoFilter(mass);
@@ -1390,7 +1390,7 @@ MassSearchDlg::monoFilterAvgMass()
   // At this point, depending on the item that is currently selected
   // in the comboBox, we'll have to actually compute the tolerance.
 
-  if(!calculateFilterTolerance(mass, libmass::MassType::MASS_MONO))
+  if(!calculateFilterTolerance(mass, libXpertMass::MassType::MASS_MONO))
     return;
 
   mpa_monoProxyModel->setAvgFilter(mass);
@@ -1423,7 +1423,7 @@ MassSearchDlg::avgFilterAvgMass()
   // At this point, depending on the item that is currently selected
   // in the comboBox, we'll have to actually compute the tolerance.
 
-  if(!calculateFilterTolerance(mass, libmass::MassType::MASS_AVG))
+  if(!calculateFilterTolerance(mass, libXpertMass::MassType::MASS_AVG))
     return;
 
   mpa_avgProxyModel->setAvgFilter(mass);
@@ -1484,7 +1484,7 @@ MassSearchDlg::prepareResultsTxtString()
   //
   // Note that name and coords are optional.
   bool forXpertMiner         = false;
-  libmass::MassType massType = libmass::MassType::MASS_NONE;
+  libXpertMass::MassType massType = libXpertMass::MassType::MASS_NONE;
 
   forXpertMiner = m_ui.forXpertMinerCheckBox->isChecked();
 
@@ -1502,9 +1502,9 @@ MassSearchDlg::prepareResultsTxtString()
       // the mono or avg masses.
 
       if(m_ui.monoRadioButton->isChecked())
-        massType = libmass::MassType::MASS_MONO;
+        massType = libXpertMass::MassType::MASS_MONO;
       else
-        massType = libmass::MassType::MASS_AVG;
+        massType = libXpertMass::MassType::MASS_AVG;
     }
 
 
@@ -1645,4 +1645,4 @@ MassSearchDlg::selectResultsFile()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
