@@ -31,15 +31,15 @@
  */
 
 /////////////////////// libmass includes
-#include <libmass/Oligomer.hpp>
-#include <libmass/Prop.hpp>
+#include <libXpertMass/Oligomer.hpp>
+#include <libXpertMass/Prop.hpp>
 
 
 /////////////////////// Local includes
 #include "MassSearchOligomerTableViewModel.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -182,7 +182,7 @@ MassSearchOligomerTableViewModel::data(const QModelIndex &index, int role) const
       // row. Let's find the row first, so that we get to the proper
       // oligomer.
 
-      libmass::OligomerSPtr oligomer_sp = mp_oligomerList->at(row);
+      libXpertMass::OligomerSPtr oligomer_sp = mp_oligomerList->at(row);
 
       // Now see what's the column that is asked for. Prepare a
       // string that we'll feed with the right data before returning
@@ -195,14 +195,14 @@ MassSearchOligomerTableViewModel::data(const QModelIndex &index, int role) const
           // The searched m/z value is stored in a Prop. Get it
           // right away.
 
-          libmass::Prop *prop = oligomer_sp->prop("SEARCHED_MZ");
+          libXpertMass::Prop *prop = oligomer_sp->prop("SEARCHED_MZ");
 
           Q_ASSERT(prop);
 
           double value = 0;
 
           value = *static_cast<const double *>(prop->data());
-          valueString.setNum(value, 'f', libmass::OLIGOMER_DEC_PLACES);
+          valueString.setNum(value, 'f', libXpertMass::OLIGOMER_DEC_PLACES);
         }
       else if(column == MASS_SEARCH_OLIGO_NAME_COLUMN)
         {
@@ -219,22 +219,22 @@ MassSearchOligomerTableViewModel::data(const QModelIndex &index, int role) const
           // The error m/z value is stored in a Prop. Get it right
           // away.
 
-          libmass::DoubleProp *prop =
-            static_cast<libmass::DoubleProp *>(oligomer_sp->prop("ERROR_MZ"));
+          libXpertMass::DoubleProp *prop =
+            static_cast<libXpertMass::DoubleProp *>(oligomer_sp->prop("ERROR_MZ"));
           Q_ASSERT(prop);
 
           double value = 0;
 
           value = *static_cast<const double *>(prop->data());
-          valueString.setNum(value, 'f', libmass::OLIGOMER_DEC_PLACES);
+          valueString.setNum(value, 'f', libXpertMass::OLIGOMER_DEC_PLACES);
         }
       else if(column == MASS_SEARCH_OLIGO_MONO_COLUMN)
         {
-          valueString = oligomer_sp->monoString(libmass::OLIGOMER_DEC_PLACES);
+          valueString = oligomer_sp->monoString(libXpertMass::OLIGOMER_DEC_PLACES);
         }
       else if(column == MASS_SEARCH_OLIGO_AVG_COLUMN)
         {
-          valueString = oligomer_sp->avgString(libmass::OLIGOMER_DEC_PLACES);
+          valueString = oligomer_sp->avgString(libXpertMass::OLIGOMER_DEC_PLACES);
         }
       else if(column == MASS_SEARCH_OLIGO_MODIF_COLUMN)
         {
@@ -258,7 +258,7 @@ MassSearchOligomerTableViewModel::data(const QModelIndex &index, int role) const
 
 
 int
-MassSearchOligomerTableViewModel::addOligomer(libmass::Oligomer *oligomer)
+MassSearchOligomerTableViewModel::addOligomer(libXpertMass::Oligomer *oligomer)
 {
   if(!oligomer)
     qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
@@ -297,8 +297,8 @@ MassSearchOligomerTableViewModel::addOligomer(libmass::Oligomer *oligomer)
 
   for(int iter = 0; iter < oligomersToAdd; ++iter)
     {
-      libmass::OligomerSPtr oligomer_sp =
-        std::make_shared<libmass::Oligomer>(*oligomer);
+      libXpertMass::OligomerSPtr oligomer_sp =
+        std::make_shared<libXpertMass::Oligomer>(*oligomer);
 
       mp_oligomerList->append(oligomer_sp);
 
@@ -348,7 +348,7 @@ MassSearchOligomerTableViewModel::addOligomers(const OligomerList &oligomerList)
 
   for(int iter = 0; iter < oligomersToAdd; ++iter)
     {
-      libmass::OligomerSPtr oligomer_sp = oligomerList.at(iter);
+      libXpertMass::OligomerSPtr oligomer_sp = oligomerList.at(iter);
 
       mp_oligomerList->append(oligomer_sp);
 
@@ -420,7 +420,7 @@ MassSearchOligomerTableViewModel::removeOligomers(int firstIndex, int lastIndex)
 
   while(iter >= firstIdx)
     {
-      libmass::OligomerSPtr oligomer_sp = mp_oligomerList->takeAt(iter);
+      libXpertMass::OligomerSPtr oligomer_sp = mp_oligomerList->takeAt(iter);
 
       oligomer_sp.reset();
 
@@ -437,4 +437,4 @@ MassSearchOligomerTableViewModel::removeOligomers(int firstIndex, int lastIndex)
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
