@@ -37,15 +37,15 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/PolChemDefEntity.hpp>
-#include <libmass/CrossLink.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
+#include <libXpertMass/CrossLink.hpp>
 
 
 /////////////////////// Local includes
 #include "MonomerCrossLinkDlg.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -54,7 +54,7 @@ namespace massxpert
 
   MonomerCrossLinkDlg::MonomerCrossLinkDlg(SequenceEditorWnd *editorWnd,
                                            /* no polymer **/
-                                           /* no libmass::PolChemDef **/
+                                           /* no libXpertMass::PolChemDef **/
                                            const QString &settingsFilePath,
                                            const QString &applicationName,
                                            const QString &description)
@@ -175,7 +175,7 @@ namespace massxpert
   bool
   MonomerCrossLinkDlg::populateCrossLinkerList()
   {
-    libmass::PolChemDefCstSPtr polChemDefCstSPtr =
+    libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
       mp_editorWnd->polChemDefRendering()->getPolChemDef();
     Q_ASSERT(polChemDefCstSPtr);
 
@@ -185,7 +185,7 @@ namespace massxpert
     for(int iter = 0; iter < polChemDefCstSPtr->crossLinkerList().size();
         ++iter)
       {
-        libmass::CrossLinker *crossLinker =
+        libXpertMass::CrossLinker *crossLinker =
           polChemDefCstSPtr->crossLinkerList().at(iter);
         Q_ASSERT(crossLinker);
 
@@ -200,14 +200,14 @@ namespace massxpert
   MonomerCrossLinkDlg::populateCrossLinkedMonomerList()
   {
     // We'll need a pointer to the polymer sequence.
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     // First-off remove all the items.
     m_ui.crossLinkedMonomerListWidget->clear();
 
     for(int iter = 0; iter < polymer->crossLinkList().size(); ++iter)
       {
-        libmass::CrossLink *crossLink = polymer->crossLinkList().at(iter);
+        libXpertMass::CrossLink *crossLink = polymer->crossLinkList().at(iter);
         Q_ASSERT(crossLink);
 
         // For the currently iterated crossLink, iterate in the
@@ -216,7 +216,7 @@ namespace massxpert
 
         for(int jter = 0; jter < crossLink->monomerList()->size(); ++jter)
           {
-            const libmass::Monomer *monomer =
+            const libXpertMass::Monomer *monomer =
               crossLink->monomerList()->at(jter);
 
             int index = polymer->monomerIndex(monomer);
@@ -239,7 +239,7 @@ namespace massxpert
   MonomerCrossLinkDlg::populateCrossLinkList(bool all)
   {
     // We'll need a pointer to the polymer sequence.
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     // First-off remove all the items.
     m_ui.crossLinkListWidget->clear();
@@ -252,7 +252,7 @@ namespace massxpert
 
         for(int iter = 0; iter < polymer->crossLinkList().size(); ++iter)
           {
-            libmass::CrossLink *crossLink = polymer->crossLinkList().at(iter);
+            libXpertMass::CrossLink *crossLink = polymer->crossLinkList().at(iter);
             Q_ASSERT(crossLink);
 
             QString text = QString("%1/%2/%3")
@@ -324,14 +324,14 @@ namespace massxpert
         //       qDebug() << __FILE__ << __LINE__
         // 		<< "Monomer index is:" << index;
 
-        const libmass::Monomer *monomer = polymer->at(index);
+        const libXpertMass::Monomer *monomer = polymer->at(index);
 
         // At this point we have to find all the crosslinks that involve
         // the monomer.
 
         for(int iter = 0; iter < polymer->crossLinkList().size(); ++iter)
           {
-            libmass::CrossLink *crossLink = polymer->crossLinkList().at(iter);
+            libXpertMass::CrossLink *crossLink = polymer->crossLinkList().at(iter);
             Q_ASSERT(crossLink);
 
             if(crossLink->involvesMonomer(monomer) != -1)
@@ -374,11 +374,11 @@ namespace massxpert
 
     // Find the crosslinker object in the polymer chemistry definition.
 
-    libmass::PolChemDefCstSPtr polChemDefCstSPtr =
+    libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
       mp_editorWnd->polChemDefRendering()->getPolChemDef();
     Q_ASSERT(polChemDefCstSPtr);
 
-    libmass::CrossLinker crossLinker(polChemDefCstSPtr, "NOT_SET", "NOT_SET");
+    libXpertMass::CrossLinker crossLinker(polChemDefCstSPtr, "NOT_SET", "NOT_SET");
 
     if(!polChemDefCstSPtr->referenceCrossLinkerByName(name, &crossLinker))
       {
@@ -400,7 +400,7 @@ namespace massxpert
 
     for(int iter = 0; iter < crossLinker.modifList().size(); ++iter)
       {
-        libmass::Modif *modif = crossLinker.modifList().at(iter);
+        libXpertMass::Modif *modif = crossLinker.modifList().at(iter);
 
         m_ui.crossLinkModifListWidget->addItem(modif->name());
       }
@@ -457,7 +457,7 @@ namespace massxpert
     QListWidgetItem *item)
   {
     // We'll need a pointer to the polymer sequence.
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     QString text = item->text();
 
@@ -488,8 +488,8 @@ namespace massxpert
         return;
       }
 
-    libmass::Monomer *monomer =
-      reinterpret_cast<libmass::Monomer *>(pointerToCast);
+    libXpertMass::Monomer *monomer =
+      reinterpret_cast<libXpertMass::Monomer *>(pointerToCast);
 
     int index = polymer->monomerIndex(monomer);
 
@@ -517,7 +517,7 @@ namespace massxpert
   MonomerCrossLinkDlg::crossLinkListWidgetItemSelectionChanged()
   {
     // We'll need a pointer to the polymer sequence.
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     // When a crossLink is selected, then its data have to be displayed
     // in the details widgets.
@@ -585,8 +585,8 @@ namespace massxpert
         return;
       }
 
-    libmass::CrossLink *crossLink =
-      reinterpret_cast<libmass::CrossLink *>(pointerToCast);
+    libXpertMass::CrossLink *crossLink =
+      reinterpret_cast<libXpertMass::CrossLink *>(pointerToCast);
 
     // At this point, we can simply show all the details of the
     // crossLink.
@@ -595,13 +595,13 @@ namespace massxpert
     m_ui.crossLinkerNameLineEdit->setText(crossLink->name());
 
     // The modifications of the crossLinker(parent class of
-    // libmass::CrossLink).  Make sure we remove all the items in the
+    // libXpertMass::CrossLink).  Make sure we remove all the items in the
     // crossLinkModifListWidget !
     m_ui.crossLinkModifListWidget->clear();
 
     for(int iter = 0; iter < crossLink->modifList().size(); ++iter)
       {
-        libmass::Modif *modif = crossLink->modifList().at(iter);
+        libXpertMass::Modif *modif = crossLink->modifList().at(iter);
 
         m_ui.crossLinkModifListWidget->addItem(modif->name());
       }
@@ -615,7 +615,7 @@ namespace massxpert
 
     for(int iter = 0; iter < crossLink->monomerList()->size(); ++iter)
       {
-        const libmass::Monomer *monomer = crossLink->monomerList()->at(iter);
+        const libXpertMass::Monomer *monomer = crossLink->monomerList()->at(iter);
 
         int index = polymer->monomerIndex(monomer);
 
@@ -631,7 +631,7 @@ namespace massxpert
   MonomerCrossLinkDlg::crossLinkListWidgetItemActivated(QListWidgetItem *item)
   {
     // We'll need a pointer to the polymer sequence.
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     QString text = item->text();
 
@@ -659,14 +659,14 @@ namespace massxpert
                              .arg(__LINE__),
                            QMessageBox::Ok);
 
-    libmass::CrossLink *crossLink =
-      reinterpret_cast<libmass::CrossLink *>(pointerToCast);
+    libXpertMass::CrossLink *crossLink =
+      reinterpret_cast<libXpertMass::CrossLink *>(pointerToCast);
 
-    libmass::CoordinateList coordinateList;
+    libXpertMass::CoordinateList coordinateList;
 
     for(int iter = 0; iter < crossLink->monomerList()->size(); ++iter)
       {
-        const libmass::Monomer *monomer = crossLink->monomerList()->at(iter);
+        const libXpertMass::Monomer *monomer = crossLink->monomerList()->at(iter);
 
         int index = polymer->monomerIndex(monomer);
 
@@ -674,8 +674,8 @@ namespace massxpert
         QString itemText = QString("%1/%2").arg(monomer->code()).arg(index + 1);
 
 
-        libmass::Coordinates *coordinates =
-          new libmass::Coordinates(index, index);
+        libXpertMass::Coordinates *coordinates =
+          new libXpertMass::Coordinates(index, index);
         coordinateList.append(coordinates);
       }
 
@@ -702,7 +702,7 @@ namespace massxpert
 
   bool
   MonomerCrossLinkDlg::parseTargetMonomerString(
-    QList<const libmass::Monomer *> *monomerList)
+    QList<const libXpertMass::Monomer *> *monomerList)
   {
     Q_ASSERT(monomerList);
 
@@ -717,7 +717,7 @@ namespace massxpert
       return false;
 
     // We'll need a pointer to the polymer sequence.
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     // For each position, make sure that we can get a monomer pointer
     // for it.
@@ -746,7 +746,7 @@ namespace massxpert
             return false;
           }
 
-        const libmass::Monomer *monomer = polymer->at(index);
+        const libXpertMass::Monomer *monomer = polymer->at(index);
 
         monomerList->append(monomer);
       }
@@ -773,7 +773,7 @@ namespace massxpert
           return;
       }
 
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     // Get the crossLink currently selected.
     QList<QListWidgetItem *> selectedList =
@@ -785,9 +785,9 @@ namespace massxpert
     QString text = selectedList.at(0)->text();
     Q_ASSERT(!text.isEmpty());
 
-    // With the name of the cross-link get to the libmass::CrossLink proper.
+    // With the name of the cross-link get to the libXpertMass::CrossLink proper.
 
-    libmass::CrossLinker *crossLinker = new libmass::CrossLinker(
+    libXpertMass::CrossLinker *crossLinker = new libXpertMass::CrossLinker(
       polymer->getPolChemDefCstSPtr(), "NOT_SET", "NOT_SET");
 
     bool res = polymer->getPolChemDefCstSPtr()->referenceCrossLinkerByName(text, crossLinker);
@@ -814,7 +814,7 @@ namespace massxpert
     // indices(2 and 32 if string is "3;33") get to the pointers to the
     // monomers.
 
-    QList<const libmass::Monomer *> targetMonomerList;
+    QList<const libXpertMass::Monomer *> targetMonomerList;
 
     if(!parseTargetMonomerString(&targetMonomerList))
       return;
@@ -863,8 +863,8 @@ namespace massxpert
 
     QString comment = m_ui.crossLinkCommentLineEdit->text();
 
-    libmass::CrossLink *myCrossLink =
-      new libmass::CrossLink(*crossLinker, polymer, comment);
+    libXpertMass::CrossLink *myCrossLink =
+      new libXpertMass::CrossLink(*crossLinker, polymer, comment);
 
     // Now use the temporary list of monomer pointers that point to the
     // monomers to crossLink : we want to copy these monomer pointers
@@ -876,7 +876,7 @@ namespace massxpert
 
     for(int iter = 0; iter < targetMonomerList.size(); ++iter)
       {
-        const libmass::Monomer *monomer = targetMonomerList.at(iter);
+        const libXpertMass::Monomer *monomer = targetMonomerList.at(iter);
 
         myCrossLink->appendMonomer(monomer);
       }
@@ -907,7 +907,7 @@ namespace massxpert
 
     for(int iter = 0; iter < targetMonomerList.size(); ++iter)
       {
-        const libmass::Monomer *monomer = targetMonomerList.at(iter);
+        const libXpertMass::Monomer *monomer = targetMonomerList.at(iter);
 
         // Get the index in the polymer of the currently iterated
         // monomer.
@@ -949,7 +949,7 @@ namespace massxpert
           return;
       }
 
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     // The crossLinkListWidget is a single-selection list.
 
@@ -1011,8 +1011,8 @@ namespace massxpert
         return;
       }
 
-    libmass::CrossLink *crossLink =
-      reinterpret_cast<libmass::CrossLink *>(pointerToCast);
+    libXpertMass::CrossLink *crossLink =
+      reinterpret_cast<libXpertMass::CrossLink *>(pointerToCast);
 
     // For each monomer in the cross-link we have to uncrossLink the
     // vignette. Next, we'll destroy the cross-link from the polymer
@@ -1020,7 +1020,7 @@ namespace massxpert
 
     for(int iter = 0; iter < crossLink->monomerList()->size(); ++iter)
       {
-        const libmass::Monomer *monomer = crossLink->monomerList()->at(iter);
+        const libXpertMass::Monomer *monomer = crossLink->monomerList()->at(iter);
 
         // Get the index in the polymer of the currently iterated
         // monomer.
@@ -1073,7 +1073,7 @@ namespace massxpert
 
 
   void
-  MonomerCrossLinkDlg::crossLinkChangedSlot(libmass::Polymer *polymer)
+  MonomerCrossLinkDlg::crossLinkChangedSlot(libXpertMass::Polymer *polymer)
   {
     Q_ASSERT(polymer);
     Q_ASSERT(polymer == mp_editorWnd->polymer());
@@ -1092,4 +1092,4 @@ namespace massxpert
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
