@@ -37,7 +37,7 @@
 
 
 /////////////////////// libmass includes
-#include "libmass/PolChemDef.hpp"
+#include <libXpertMass/PolChemDef.hpp>
 
 
 /////////////////////// Local includes
@@ -45,14 +45,14 @@
 #include "PolChemDefWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
 {
 
 
-MonomerDefDlg::MonomerDefDlg(libmass::PolChemDefSPtr polChemDefSPtr,
+MonomerDefDlg::MonomerDefDlg(libXpertMass::PolChemDefSPtr polChemDefSPtr,
                              PolChemDefWnd *polChemDefWnd,
                              const QString &settingsFilePath,
                              const QString &applicationName,
@@ -132,7 +132,7 @@ MonomerDefDlg::initialize()
 
   for(int iter = 0; iter < mp_list->size(); ++iter)
     {
-      libmass::Monomer *monomer = mp_list->at(iter);
+      libXpertMass::Monomer *monomer = mp_list->at(iter);
 
       m_ui.monomerListWidget->addItem(monomer->name());
     }
@@ -217,7 +217,7 @@ MonomerDefDlg::addMonomerPushButtonClicked()
   // Returns -1 if the list is empty.
   int index = m_ui.monomerListWidget->currentRow();
 
-  libmass::Monomer *newMonomer = new libmass::Monomer(
+  libXpertMass::Monomer *newMonomer = new libXpertMass::Monomer(
     msp_polChemDef, tr("Type Name"), tr("Type Code"), tr("Type Formula"));
 
   mp_list->insert(index, newMonomer);
@@ -253,7 +253,7 @@ MonomerDefDlg::removeMonomerPushButtonClicked()
   QListWidgetItem *item = m_ui.monomerListWidget->takeItem(index);
   delete item;
 
-  libmass::Monomer *monomer = mp_list->takeAt(index);
+  libXpertMass::Monomer *monomer = mp_list->takeAt(index);
   Q_ASSERT(monomer);
   delete monomer;
 
@@ -358,7 +358,7 @@ MonomerDefDlg::applyMonomerPushButtonClicked()
   // Get the index of the current monomer item.
   int index = m_ui.monomerListWidget->currentRow();
 
-  libmass::Monomer *monomer = mp_list->at(index);
+  libXpertMass::Monomer *monomer = mp_list->at(index);
 
   // We do not want more than one monomer by the same name or the same
   // symbol.
@@ -375,21 +375,21 @@ MonomerDefDlg::applyMonomerPushButtonClicked()
   // and that monomer is not the one that is current in the monomer list,
   // then we are making a double entry, which is not allowed.
 
-  int nameRes = libmass::Monomer::isNameInList(editName, *mp_list);
+  int nameRes = libXpertMass::Monomer::isNameInList(editName, *mp_list);
   if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::Monomer definition"),
+                           tr("massXpert - libXpertMass::Monomer definition"),
                            tr("A monomer with same name exists already."),
                            QMessageBox::Ok);
       return;
     }
 
-  int codeRes = libmass::Monomer::isCodeInList(editCode, *mp_list);
+  int codeRes = libXpertMass::Monomer::isCodeInList(editCode, *mp_list);
   if(codeRes != -1 && codeRes != index)
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::Monomer definition"),
+                           tr("massXpert - libXpertMass::Monomer definition"),
                            tr("A monomer with same code exists already."),
                            QMessageBox::Ok);
       return;
@@ -397,15 +397,15 @@ MonomerDefDlg::applyMonomerPushButtonClicked()
 
   // At this point, validate the formula:
 
-  libmass::Formula formula(editFormula);
+  libXpertMass::Formula formula(editFormula);
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     msp_polChemDef->getIsotopicDataCstSPtr();
 
   if(!formula.validate(isotopic_data_csp))
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::Monomer definition"),
+                           tr("massXpert - libXpertMass::Monomer definition"),
                            tr("The formula failed to validate."),
                            QMessageBox::Ok);
       return;
@@ -447,7 +447,7 @@ MonomerDefDlg::validatePushButtonClicked()
            "not identical.\n"));
 
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::Monomer definition"),
+                           tr("massXpert - libXpertMass::Monomer definition"),
                            errorList.join("\n"),
                            QMessageBox::Ok);
       return false;
@@ -457,7 +457,7 @@ MonomerDefDlg::validatePushButtonClicked()
     {
       QListWidgetItem *item = m_ui.monomerListWidget->item(iter);
 
-      libmass::Monomer *monomer = mp_list->at(iter);
+      libXpertMass::Monomer *monomer = mp_list->at(iter);
 
       if(item->text() != monomer->name())
         errorList << QString(tr("\nMonomer at index %1 has not the same\n"
@@ -473,7 +473,7 @@ MonomerDefDlg::validatePushButtonClicked()
   if(errorList.size())
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::Monomer definition"),
+                           tr("massXpert - libXpertMass::Monomer definition"),
                            errorList.join("\n"),
                            QMessageBox::Ok);
       return false;
@@ -481,7 +481,7 @@ MonomerDefDlg::validatePushButtonClicked()
   else
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::Monomer definition"),
+                           tr("massXpert - libXpertMass::Monomer definition"),
                            ("Validation: success\n"),
                            QMessageBox::Ok);
     }
@@ -510,7 +510,7 @@ MonomerDefDlg::monomerListWidgetItemSelectionChanged()
   // test that the returned index is not -1.
   if(index >= 0)
     {
-      libmass::Monomer *monomer = mp_list->at(index);
+      libXpertMass::Monomer *monomer = mp_list->at(index);
       Q_ASSERT(monomer);
 
       //qDebug() << "Currently selected monomer:" << monomer->name();
@@ -548,7 +548,7 @@ MonomerDefDlg::codeLengthSpinBoxValueChanged(int value)
 
 
 void
-MonomerDefDlg::updateMonomerDetails(libmass::Monomer *monomer)
+MonomerDefDlg::updateMonomerDetails(libXpertMass::Monomer *monomer)
 {
   if(monomer)
     {
@@ -588,15 +588,15 @@ MonomerDefDlg::formulaLineEditTextChanged(const QString &string)
   // masses of the formula. If the computation failed, we set "Bad
   // formula" in the line edit widgets of the masses.
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     msp_polChemDef->getIsotopicDataCstSPtr();
 
 
-  libmass::Formula formula(string);
+  libXpertMass::Formula formula(string);
 
   //qDebug() << "Formula of the monomer:" << string;
 
-  libmass::Ponderable ponderable(0, 0);
+  libXpertMass::Ponderable ponderable(0, 0);
 
   if(!formula.accountMasses(isotopic_data_csp, &ponderable))
     {
@@ -607,9 +607,9 @@ MonomerDefDlg::formulaLineEditTextChanged(const QString &string)
     }
 
   m_ui.monoMassLineEdit->setText(
-    ponderable.monoString(libmass::ATOM_DEC_PLACES));
+    ponderable.monoString(libXpertMass::ATOM_DEC_PLACES));
 
-  m_ui.avgMassLineEdit->setText(ponderable.avgString(libmass::ATOM_DEC_PLACES));
+  m_ui.avgMassLineEdit->setText(ponderable.avgString(libXpertMass::ATOM_DEC_PLACES));
 }
 
 
@@ -627,7 +627,7 @@ MonomerDefDlg::calculateMassDifferences()
   if(!threshold && !ok)
     {
       QMessageBox::warning(this,
-                           tr("massXpert - libmass::Monomer definition"),
+                           tr("massXpert - libXpertMass::Monomer definition"),
                            tr("Threshold value is not valid"),
                            QMessageBox::Ok);
       return;
@@ -635,12 +635,12 @@ MonomerDefDlg::calculateMassDifferences()
 
   bool isMonoMass = m_ui.monoMassRadioButton->isChecked();
 
-  int monoOrAvg;
+  libXpertMass::MassType monoOrAvg;
 
   if(isMonoMass)
-    monoOrAvg = libmass::MassType::MASS_MONO;
+    monoOrAvg = libXpertMass::MassType::MASS_MONO;
   else
-    monoOrAvg = libmass::MassType::MASS_AVG;
+    monoOrAvg = libXpertMass::MassType::MASS_AVG;
 
   QStringList *diffList =
     msp_polChemDef->differenceBetweenMonomers(threshold, monoOrAvg);
@@ -649,7 +649,7 @@ MonomerDefDlg::calculateMassDifferences()
     return;
 
   QMessageBox::information(this,
-                           tr("massXpert - libmass::Monomer definition"),
+                           tr("massXpert - libXpertMass::Monomer definition"),
                            diffList->join("\n"),
                            QMessageBox::Ok);
 
@@ -661,4 +661,4 @@ MonomerDefDlg::calculateMassDifferences()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
