@@ -34,14 +34,14 @@
 /////////////////////// Qt includes
 #include <QMessageBox>
 #include <QSettings>
-#include <libmass/PolChemDefEntity.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
 
 
 /////////////////////// Local includes
 #include "MonomerModificationDlg.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -51,7 +51,7 @@ namespace massxpert
   MonomerModificationDlg::MonomerModificationDlg(
     SequenceEditorWnd *editorWnd,
     /* no polymer **/
-    /* no libmass::PolChemDef **/
+    /* no libXpertMass::PolChemDef **/
     const QString &settingsFilePath,
     const QString &applicationName,
     const QString &description)
@@ -151,13 +151,13 @@ namespace massxpert
   bool
   MonomerModificationDlg::populateAvailableModifList()
   {
-    libmass::PolChemDefCstSPtr polChemDefCstSPtr =
+    libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
       mp_editorWnd->polChemDefRendering()->getPolChemDef();
     Q_ASSERT(polChemDefCstSPtr);
 
     for(int iter = 0; iter < polChemDefCstSPtr->modifList().size(); ++iter)
       {
-        libmass::Modif *modif = polChemDefCstSPtr->modifList().at(iter);
+        libXpertMass::Modif *modif = polChemDefCstSPtr->modifList().at(iter);
         Q_ASSERT(modif);
 
         m_ui.availableModifListWidget->addItem(modif->name());
@@ -171,7 +171,7 @@ namespace massxpert
   MonomerModificationDlg::populateModifAndModifiedMonomerLists()
   {
     // We'll need a pointer to the polymer sequence.
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     m_ui.modifiedMonomerListWidget->clear();
     m_ui.modifListWidget->clear();
@@ -182,9 +182,9 @@ namespace massxpert
 
     for(int iter = 0; iter < polymer->size(); ++iter)
       {
-        const libmass::Monomer *monomer = polymer->at(iter);
+        const libXpertMass::Monomer *monomer = polymer->at(iter);
 
-        QList<libmass::Modif *> *list = monomer->modifList();
+        QList<libXpertMass::Modif *> *list = monomer->modifList();
 
         if(!list || list->isEmpty())
           continue;
@@ -202,7 +202,7 @@ namespace massxpert
 
         for(int jter = 0; jter < list->size(); ++jter)
           {
-            libmass::Modif *modif = list->at(jter);
+            libXpertMass::Modif *modif = list->at(jter);
 
             QString text = QString("%1/%2/%3/%4/%5")
                              .arg(modif->name())
@@ -228,7 +228,7 @@ namespace massxpert
   MonomerModificationDlg::populateModifiedMonomerList()
   {
     // We'll need a pointer to the polymer sequence.
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     m_ui.modifiedMonomerListWidget->clear();
 
@@ -238,9 +238,9 @@ namespace massxpert
 
     for(int iter = 0; iter < polymer->size(); ++iter)
       {
-        const libmass::Monomer *monomer = polymer->at(iter);
+        const libXpertMass::Monomer *monomer = polymer->at(iter);
 
-        QList<libmass::Modif *> *list = monomer->modifList();
+        QList<libXpertMass::Modif *> *list = monomer->modifList();
 
         if(!list || list->isEmpty())
           continue;
@@ -265,7 +265,7 @@ namespace massxpert
   MonomerModificationDlg::populateModifList(bool all)
   {
     // We'll need a pointer to the polymer sequence.
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     // First-off remove all the items.
     m_ui.modifListWidget->clear();
@@ -278,16 +278,16 @@ namespace massxpert
 
         for(int iter = 0; iter < polymer->size(); ++iter)
           {
-            const libmass::Monomer *monomer = polymer->at(iter);
+            const libXpertMass::Monomer *monomer = polymer->at(iter);
 
-            QList<libmass::Modif *> *modifList = monomer->modifList();
+            QList<libXpertMass::Modif *> *modifList = monomer->modifList();
 
             if(!modifList || modifList->isEmpty())
               continue;
 
             for(int jter = 0; jter < modifList->size(); ++jter)
               {
-                libmass::Modif *modif = modifList->at(jter);
+                libXpertMass::Modif *modif = modifList->at(jter);
 
                 QString text = QString("%1/%2/%3/%4/%5")
                                  .arg(modif->name())
@@ -361,8 +361,8 @@ namespace massxpert
             // The monomer(quintptr) pointer is the third string in the list.
             ok                        = false;
             quintptr pointerCastToInt = stringList.at(2).toLongLong(&ok, 10);
-            libmass::Monomer *monomer =
-              reinterpret_cast<libmass::Monomer *>(pointerCastToInt);
+            libXpertMass::Monomer *monomer =
+              reinterpret_cast<libXpertMass::Monomer *>(pointerCastToInt);
 
             // Sanity check, are we dealing with the same monomer now
             // compared to the one of which the item was displayed when
@@ -389,7 +389,7 @@ namespace massxpert
             // Iterate in the monomer's modifications and for each one
             // create a new item.
 
-            QList<libmass::Modif *> *modifList = monomer->modifList();
+            QList<libXpertMass::Modif *> *modifList = monomer->modifList();
 
             // It is not possible that the monomer has no modif,
             // otherwise how come would it be listed in the list of
@@ -399,7 +399,7 @@ namespace massxpert
 
             for(int jter = 0; jter < modifList->size(); ++jter)
               {
-                libmass::Modif *modif = modifList->at(jter);
+                libXpertMass::Modif *modif = modifList->at(jter);
 
                 QString text = QString("%1/%2/%3/%4/%5")
                                  .arg(modif->name())
@@ -424,13 +424,13 @@ namespace massxpert
   bool
   MonomerModificationDlg::populateMonomerList()
   {
-    libmass::PolChemDefCstSPtr polChemDefCstSPtr =
+    libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
       mp_editorWnd->polChemDefRendering()->getPolChemDef();
     Q_ASSERT(polChemDefCstSPtr);
 
     for(int iter = 0; iter < polChemDefCstSPtr->monomerList().size(); ++iter)
       {
-        libmass::Monomer *monomer = polChemDefCstSPtr->monomerList().at(iter);
+        libXpertMass::Monomer *monomer = polChemDefCstSPtr->monomerList().at(iter);
         Q_ASSERT(monomer);
 
         QString text = monomer->code() + '=' + monomer->name();
@@ -505,7 +505,7 @@ namespace massxpert
           }
         else
           {
-            libmass::Coordinates *coordinates = m_coordinateList.first();
+            libXpertMass::Coordinates *coordinates = m_coordinateList.first();
 
             if(coordinates->start() == coordinates->end())
               {
@@ -513,8 +513,8 @@ namespace massxpert
                 // Construct a string with both the monomer code and
                 // its position in the sequence.
 
-                libmass::Polymer *polymer = mp_editorWnd->polymer();
-                const libmass::Monomer *monomer =
+                libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
+                const libXpertMass::Monomer *monomer =
                   polymer->monomerList().at(coordinates->start());
 
                 QString text = tr("%1 at pos. %2")
@@ -538,7 +538,7 @@ namespace massxpert
   int
   MonomerModificationDlg::prepareIndicesList()
   {
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     m_indicesList.clear();
 
@@ -550,12 +550,12 @@ namespace massxpert
         if(!isSelectionPresent)
           return 0;
 
-        // Now, for each libmass::Coordinates in the CoordinateList, append the
+        // Now, for each libXpertMass::Coordinates in the CoordinateList, append the
         // indices...
 
         for(int iter = 0; iter < m_coordinateList.size(); ++iter)
           {
-            libmass::Coordinates *coordinates = m_coordinateList.at(iter);
+            libXpertMass::Coordinates *coordinates = m_coordinateList.at(iter);
 
             for(int iter = coordinates->start(); iter < coordinates->end() + 1;
                 ++iter)
@@ -571,7 +571,7 @@ namespace massxpert
         if(m_coordinateList.size() > 1)
           return 0;
 
-        libmass::Coordinates *coordinates = m_coordinateList.at(0);
+        libXpertMass::Coordinates *coordinates = m_coordinateList.at(0);
 
         if(coordinates->start() != coordinates->end())
           return 0;
@@ -580,7 +580,7 @@ namespace massxpert
 
         for(int iter = 0; iter < polymer->monomerList().size(); ++iter)
           {
-            const libmass::Monomer *monomer = polymer->monomerList().at(iter);
+            const libXpertMass::Monomer *monomer = polymer->monomerList().at(iter);
             Q_ASSERT(monomer);
 
             if(monomer->code() == code)
@@ -608,7 +608,7 @@ namespace massxpert
 
             for(int jter = 0; jter < polymer->monomerList().size(); ++jter)
               {
-                const libmass::Monomer *monomer =
+                const libXpertMass::Monomer *monomer =
                   polymer->monomerList().at(jter);
                 Q_ASSERT(monomer);
 
@@ -638,7 +638,7 @@ namespace massxpert
 
 
   bool
-  MonomerModificationDlg::parseModifDefinition(libmass::Modif *modif)
+  MonomerModificationDlg::parseModifDefinition(libXpertMass::Modif *modif)
   {
     Q_ASSERT(modif);
 
@@ -671,7 +671,7 @@ namespace massxpert
   {
     QStringList errorList;
 
-    libmass::Polymer *polymer = mp_editorWnd->polymer();
+    libXpertMass::Polymer *polymer = mp_editorWnd->polymer();
 
     // There are two ways to perform a modification: either select one
     // modification from the list of available modifications as defined
@@ -680,8 +680,8 @@ namespace massxpert
 
     QString text;
 
-    libmass::Modif *modif =
-      new libmass::Modif(polymer->getPolChemDefCstSPtr(), "NOT_SET", "NOT_SET");
+    libXpertMass::Modif *modif =
+      new libXpertMass::Modif(polymer->getPolChemDefCstSPtr(), "NOT_SET", "NOT_SET");
 
     if(m_ui.defineModifGroupBox->isChecked())
       {
@@ -741,7 +741,7 @@ namespace massxpert
       {
         int index = m_indicesList.at(iter);
 
-        const libmass::Monomer *monomer = polymer->monomerList().at(index);
+        const libXpertMass::Monomer *monomer = polymer->monomerList().at(index);
 
         // Append the position and code of the currently iterated
         // monomer. We will remove that string if the result is not
@@ -755,9 +755,9 @@ namespace massxpert
         // so we have to allocate one each time using the template
         // prepared above.
 
-        libmass::Modif *newModif = new libmass::Modif(*modif);
+        libXpertMass::Modif *newModif = new libXpertMass::Modif(*modif);
 
-        int ret = const_cast<libmass::Monomer *>(monomer)->modify(
+        int ret = const_cast<libXpertMass::Monomer *>(monomer)->modify(
           newModif, override, errorList);
 
         // The modification went ok, which means we can remove the last
@@ -846,8 +846,8 @@ namespace massxpert
 
         // The modif(quintptr) pointer is the third string in the list.
         quintptr pointerCastToInt = stringList.at(3).toLongLong(&ok, 10);
-        libmass::Modif *modif =
-          reinterpret_cast<libmass::Modif *>(pointerCastToInt);
+        libXpertMass::Modif *modif =
+          reinterpret_cast<libXpertMass::Modif *>(pointerCastToInt);
 
         // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
         //<< "modif ptr str:" << stringList.at(3)
@@ -857,8 +857,8 @@ namespace massxpert
         // list.
         ok               = false;
         pointerCastToInt = stringList.at(4).toLongLong(&ok, 10);
-        libmass::Monomer *monomer =
-          reinterpret_cast<libmass::Monomer *>(pointerCastToInt);
+        libXpertMass::Monomer *monomer =
+          reinterpret_cast<libXpertMass::Monomer *>(pointerCastToInt);
 
         // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
         //<< "monomer ptr str:" << stringList.at(4)
@@ -940,4 +940,4 @@ namespace massxpert
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
