@@ -40,9 +40,9 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/Oligomer.hpp>
-#include <libmass/PolChemDefEntity.hpp>
-#include <libmass/PolChemDef.hpp>
+#include <libXpertMass/Oligomer.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
+#include <libXpertMass/PolChemDef.hpp>
 
 
 /////////////////////// Local includes
@@ -50,7 +50,7 @@
 #include "MzCalculationTreeViewModel.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -59,10 +59,10 @@ namespace massxpert
 
 MzCalculationDlg::MzCalculationDlg(QWidget *parent,
                                    const QString &configSettingsFilePath,
-                                   libmass::PolChemDefCstSPtr polChemDefCstSPtr,
+                                   libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr,
                                    const QString &applicationName,
                                    const QString &description,
-                                   const libmass::IonizeRule *ionizeRule,
+                                   const libXpertMass::IonizeRule *ionizeRule,
                                    double mono,
                                    double avg)
   : QDialog(parent),
@@ -83,11 +83,11 @@ MzCalculationDlg::MzCalculationDlg(QWidget *parent,
 
   if(mono != 0)
     m_ui.monoLineEdit->setText(
-      QString("%1").arg(mono, 0, 'f', libmass::OLIGOMER_DEC_PLACES));
+      QString("%1").arg(mono, 0, 'f', libXpertMass::OLIGOMER_DEC_PLACES));
 
   if(avg != 0)
     m_ui.avgLineEdit->setText(
-      QString("%1").arg(avg, 0, 'f', libmass::OLIGOMER_DEC_PLACES));
+      QString("%1").arg(avg, 0, 'f', libXpertMass::OLIGOMER_DEC_PLACES));
 
   if(mono || avg)
     {
@@ -220,7 +220,7 @@ MzCalculationDlg::formulaCheckBoxToggled(bool checked)
 void
 MzCalculationDlg::calculate()
 {
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     mcsp_polChemDef->getIsotopicDataCstSPtr();
 
   // The calculation can be accomplished in two different manners:
@@ -233,7 +233,7 @@ MzCalculationDlg::calculate()
   // m/z line edit widgets.
   //
   // 2. Starting from mono and avg m/z values immediately. Uncheck
-  // the libmass::Formula check box in this case.
+  // the libXpertMass::Formula check box in this case.
 
   // First get all the data for the source ionizable.
 
@@ -243,7 +243,7 @@ MzCalculationDlg::calculate()
 
   // The source ionizeRule. Start with this because we'll need it right
   // away.
-  libmass::IonizeRule srcIonizeRule;
+  libXpertMass::IonizeRule srcIonizeRule;
   if(!getSrcIonizeRuleData(&srcIonizeRule))
     return;
 
@@ -270,7 +270,7 @@ MzCalculationDlg::calculate()
       // so do that work with the member formula:
 
       // We want to validate the formula and in the mean time construct
-      // the list of all the libmass::Isotope objects(first true), and since
+      // the list of all the libXpertMass::Isotope objects(first true), and since
       // the formula is reused we also ensure that that list is reset
       // (second true).
 
@@ -328,13 +328,13 @@ MzCalculationDlg::calculate()
 
       QString mz;
 
-      mz.setNum(monoMass, 'f', libmass::OLIGOMER_DEC_PLACES);
+      mz.setNum(monoMass, 'f', libXpertMass::OLIGOMER_DEC_PLACES);
       // qDebug() << __FILE__ << __LINE__
       //          << "monoMass:" << monoMass;
 
       m_ui.monoLineEdit->setText(mz);
 
-      mz.setNum(avgMass, 'f', libmass::OLIGOMER_DEC_PLACES);
+      mz.setNum(avgMass, 'f', libXpertMass::OLIGOMER_DEC_PLACES);
       // qDebug() << __FILE__ << __LINE__
       //          << "avgMass:" << avgMass;
 
@@ -346,16 +346,16 @@ MzCalculationDlg::calculate()
   // Whatever the way we get the mon/avg mz values, make a
   // ponderable with them.
 
-  std::unique_ptr<libmass::Ponderable> ponderable_up = std::make_unique<libmass::Ponderable>(getSourcePonderable());
+  std::unique_ptr<libXpertMass::Ponderable> ponderable_up = std::make_unique<libXpertMass::Ponderable>(getSourcePonderable());
 
   if(!ponderable_up)
     return;
 
-  // Create an libmass::Ionizable with empty masses but with proper
-  // IonizeRule. Note that we check if the libmass::IonizeRule has a non-0
+  // Create an libXpertMass::Ionizable with empty masses but with proper
+  // IonizeRule. Note that we check if the libXpertMass::IonizeRule has a non-0
   // level, in which case we tell so to the caller with a true
   // boolean.
-  libmass::Ionizable ionizable(mcsp_polChemDef,
+  libXpertMass::Ionizable ionizable(mcsp_polChemDef,
                                "NOT_SET",
                                *ponderable_up,
                                srcIonizeRule,
@@ -390,8 +390,8 @@ MzCalculationDlg::calculate()
 
   // The destination ionizeRule(note that the m_level member datum
   // is not set as it will be generated during the for loop later;
-  // this does not impede validation of the libmass::IonizeRule).
-  libmass::IonizeRule destIonizeRule;
+  // this does not impede validation of the libXpertMass::IonizeRule).
+  libXpertMass::IonizeRule destIonizeRule;
   if(!getDestIonizeRuleData(&destIonizeRule))
     return;
 
@@ -434,7 +434,7 @@ MzCalculationDlg::calculate()
 
       // qDebug() << "After ionization, the ionizable:" << ionizable.toString();
 
-      libmass::Ionizable *newIonizable = new libmass::Ionizable(ionizable);
+      libXpertMass::Ionizable *newIonizable = new libXpertMass::Ionizable(ionizable);
 
       mpa_mzTreeViewModel->addIonizable(newIonizable);
 
@@ -442,8 +442,8 @@ MzCalculationDlg::calculate()
       // wants to compute a spectrum to simulate the charge envelope
       // peaks.
 
-      libmass::OligomerSPtr oligomer_sp = std::make_shared<libmass::Oligomer>(
-        ionizable, libmass::CalcOptions(), -1, -1);
+      libXpertMass::OligomerSPtr oligomer_sp = std::make_shared<libXpertMass::Oligomer>(
+        ionizable, libXpertMass::CalcOptions(), -1, -1);
 
       // qDebug() << "oligomer->charge:" << oligomer->charge();
 
@@ -454,7 +454,7 @@ MzCalculationDlg::calculate()
 
       if(fromFormula)
         {
-          libmass::Formula newFormula(m_formula);
+          libXpertMass::Formula newFormula(m_formula);
 
           newFormula.accountFormula(destIonizeRule.formula(),
                                     isotopic_data_csp,
@@ -464,10 +464,10 @@ MzCalculationDlg::calculate()
           //          << newFormula.toString();
 
 
-          libmass::StringProp *prop = new libmass::StringProp(
+          libXpertMass::StringProp *prop = new libXpertMass::StringProp(
             "ELEMENTAL_COMPOSITION", newFormula.toString());
 
-          oligomer_sp->appendProp(static_cast<libmass::Prop *>(prop));
+          oligomer_sp->appendProp(static_cast<libXpertMass::Prop *>(prop));
         }
 
       m_oligomerList.append(oligomer_sp);
@@ -476,7 +476,7 @@ MzCalculationDlg::calculate()
 
 
 bool
-MzCalculationDlg::getSrcIonizeRuleData(libmass::IonizeRule *ionizeRule)
+MzCalculationDlg::getSrcIonizeRuleData(libXpertMass::IonizeRule *ionizeRule)
 {
   Q_ASSERT(ionizeRule);
 
@@ -484,7 +484,7 @@ MzCalculationDlg::getSrcIonizeRuleData(libmass::IonizeRule *ionizeRule)
   ionizeRule->setCharge(m_ui.srcIonizeRuleChargeSpinBox->value());
   ionizeRule->setLevel(m_ui.srcIonizeRuleLevelSpinBox->value());
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     mcsp_polChemDef->getIsotopicDataCstSPtr();
 
   if(!ionizeRule->validate(isotopic_data_csp))
@@ -505,7 +505,7 @@ MzCalculationDlg::getSrcIonizeRuleData(libmass::IonizeRule *ionizeRule)
 
 
 bool
-MzCalculationDlg::getDestIonizeRuleData(libmass::IonizeRule *ionizeRule)
+MzCalculationDlg::getDestIonizeRuleData(libXpertMass::IonizeRule *ionizeRule)
 {
   Q_ASSERT(ionizeRule);
 
@@ -515,7 +515,7 @@ MzCalculationDlg::getDestIonizeRuleData(libmass::IonizeRule *ionizeRule)
   // encompass more than one single value(see calculate()). Note
   // that if level is 0, this does not invalidate the ionizeRule.
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     mcsp_polChemDef->getIsotopicDataCstSPtr();
 
   if(!ionizeRule->validate(isotopic_data_csp))
@@ -535,7 +535,7 @@ MzCalculationDlg::getDestIonizeRuleData(libmass::IonizeRule *ionizeRule)
 }
 
 
-libmass::Ponderable
+libXpertMass::Ponderable
 MzCalculationDlg::getSourcePonderable()
 {
   QString text;
@@ -594,7 +594,7 @@ MzCalculationDlg::getSourcePonderable()
   // qDebug() << "We could gather masses:" << mono << "-" << avg;
 
   // At this point we can allocate the Ponderable:
-  return libmass::Ponderable(mono, avg);
+  return libXpertMass::Ponderable(mono, avg);
 }
 
 
@@ -716,7 +716,7 @@ MzCalculationDlg::prepareResultsTxtString()
         qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
       mzString += QObject::tr("Level: %1 -- ")
-                    .arg(value, 0, 'f', libmass::PH_PKA_DEC_PLACES);
+                    .arg(value, 0, 'f', libXpertMass::PH_PKA_DEC_PLACES);
 
       currentIndex = model->index(iter, MZ_CALC_MONO_COLUMN, QModelIndex());
       Q_ASSERT(currentIndex.isValid());
@@ -731,7 +731,7 @@ MzCalculationDlg::prepareResultsTxtString()
         qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
       mzString += QObject::tr("Mono: %1 -- ")
-                    .arg(value, 0, 'f', libmass::OLIGOMER_DEC_PLACES);
+                    .arg(value, 0, 'f', libXpertMass::OLIGOMER_DEC_PLACES);
 
       currentIndex = model->index(iter, MZ_CALC_AVG_COLUMN, QModelIndex());
       Q_ASSERT(currentIndex.isValid());
@@ -746,7 +746,7 @@ MzCalculationDlg::prepareResultsTxtString()
         qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
       mzString +=
-        QObject::tr("Avg: %1").arg(value, 0, 'f', libmass::OLIGOMER_DEC_PLACES);
+        QObject::tr("Avg: %1").arg(value, 0, 'f', libXpertMass::OLIGOMER_DEC_PLACES);
 
       mzString += ("\n");
     }
@@ -823,4 +823,4 @@ MzCalculationDlg::selectResultsFile()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
