@@ -38,19 +38,19 @@
 /////////////////////// Qt includes
 #include <QMainWindow>
 #include <QSortFilterProxyModel>
-#include <libmass/PolChemDefEntity.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
 
 
 /////////////////////// libmass includes
-#include <libmass/PolChemDef.hpp>
-#include <libmass/Ionizable.hpp>
+#include <libXpertMass/PolChemDef.hpp>
+#include <libXpertMass/Ionizable.hpp>
 
 /////////////////////// Local includes
 #include "ui_MzCalculationDlg.h"
 #include "MzCalculationTreeViewSortProxyModel.hpp"
 #include "../nongui/OligomerList.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -68,10 +68,10 @@ class MzCalculationDlg : public QDialog
   public:
   MzCalculationDlg(QWidget *,
                    const QString &configSettingsFilePath,
-                   const libmass::PolChemDefCstSPtr,
+                   const libXpertMass::PolChemDefCstSPtr,
                    const QString &applicationName,
                    const QString &description,
-                   const libmass::IonizeRule *,
+                   const libXpertMass::IonizeRule *,
                    double = 0,
                    double = 0);
 
@@ -79,10 +79,10 @@ class MzCalculationDlg : public QDialog
 
   void setupTreeView();
 
-  bool getSrcIonizeRuleData(libmass::IonizeRule *);
-  bool getDestIonizeRuleData(libmass::IonizeRule *);
+  bool getSrcIonizeRuleData(libXpertMass::IonizeRule *);
+  bool getDestIonizeRuleData(libXpertMass::IonizeRule *);
 
-  libmass::Ponderable getSourcePonderable();
+  libXpertMass::Ponderable getSourcePonderable();
 
   void freeIonizableList();
   void emptyIonizableList();
@@ -110,15 +110,15 @@ class MzCalculationDlg : public QDialog
 
   QString m_configSettingsFilePath;
 
-  libmass::PolChemDefCstSPtr mcsp_polChemDef;
+  libXpertMass::PolChemDefCstSPtr mcsp_polChemDef;
 
   OligomerList m_oligomerList;
 
-  libmass::Formula m_formula;
+  libXpertMass::Formula m_formula;
 
-  libmass::IonizeRule m_ionizeRule;
+  libXpertMass::IonizeRule m_ionizeRule;
 
-  QList<libmass::Ionizable *> m_ionizableList;
+  QList<libXpertMass::Ionizable *> m_ionizableList;
 
   MzCalculationTreeViewModel *mpa_mzTreeViewModel;
   MzCalculationTreeViewSortProxyModel *mpa_mzProxyModel;
@@ -128,7 +128,7 @@ class MzCalculationDlg : public QDialog
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
 #endif // MZ_CALCULATION_DLG_HPP
