@@ -36,13 +36,13 @@
 #include <QMouseEvent>
 #include <QHeaderView>
 #include <QMessageBox>
-#include <libmass/PolChemDefEntity.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
 
 /////////////////////// Local includes
 #include "MzLabInputOligomerTableView.hpp"
 #include "MzLabInputOligomerTableViewModel.hpp"
 
-#include "libmass/Oligomer.hpp"
+#include <libXpertMass/Oligomer.hpp>
 
 #include "MzLabInputOligomerTableViewDlg.hpp"
 
@@ -50,10 +50,10 @@
 #include "FragmentOligomerTableViewMimeData.hpp"
 #include "MassSearchOligomerTableViewMimeData.hpp"
 
-#include "libmass/Coordinates.hpp"
+#include <libXpertMass/Coordinates.hpp>
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -159,7 +159,7 @@ MzLabInputOligomerTableView::mousePressEvent(QMouseEvent *mouseEvent)
 }
 
 
-libmass::MassType
+libXpertMass::MassType
 MzLabInputOligomerTableView::pasteOrDropMassTypeCheck()
 {
   // Each time a new drop/paste happens, we have to perform some
@@ -169,10 +169,10 @@ MzLabInputOligomerTableView::pasteOrDropMassTypeCheck()
   // as the mass type for the parent dialog window. Ask what's being
   // currently checked (mono and avg are two checkboxes).
 
-  libmass::MassType previousMassType = mp_parentDlg->previousMassType();
-  libmass::MassType massType         = mp_parentDlg->massType();
+  libXpertMass::MassType previousMassType = mp_parentDlg->previousMassType();
+  libXpertMass::MassType massType         = mp_parentDlg->massType();
 
-  if(massType == libmass::MassType::MASS_NONE)
+  if(massType == libXpertMass::MassType::MASS_NONE)
     {
       // Ask the user to clearly indicate what is the mass type
       // required).
@@ -185,7 +185,7 @@ MzLabInputOligomerTableView::pasteOrDropMassTypeCheck()
   // Check if one drop already occurred in the past and if it was
   // with the same mass type as now. Otherwise alert the user.
 
-  if(previousMassType != libmass::MassType::MASS_NONE &&
+  if(previousMassType != libXpertMass::MassType::MASS_NONE &&
      previousMassType != massType)
     {
       int ret = QMessageBox::question(this,
@@ -197,7 +197,7 @@ MzLabInputOligomerTableView::pasteOrDropMassTypeCheck()
 
       if(ret == QMessageBox::No)
         {
-          return libmass::MassType::MASS_NONE;
+          return libXpertMass::MassType::MASS_NONE;
         }
     }
 
@@ -241,9 +241,9 @@ MzLabInputOligomerTableView::dragMoveEvent(QDragMoveEvent *event)
 void
 MzLabInputOligomerTableView::pasteEvent()
 {
-  libmass::MassType massType = pasteOrDropMassTypeCheck();
+  libXpertMass::MassType massType = pasteOrDropMassTypeCheck();
 
-  if(massType == libmass::MassType::MASS_NONE)
+  if(massType == libXpertMass::MassType::MASS_NONE)
     {
       // The user did not want to answer positively to our
       // question. Conservatory behaviour.
@@ -307,9 +307,9 @@ MzLabInputOligomerTableView::pasteEvent()
 void
 MzLabInputOligomerTableView::dropEvent(QDropEvent *event)
 {
-  libmass::MassType massType = pasteOrDropMassTypeCheck();
+  libXpertMass::MassType massType = pasteOrDropMassTypeCheck();
 
-  if(massType == libmass::MassType::MASS_NONE)
+  if(massType == libXpertMass::MassType::MASS_NONE)
     {
       // The user did not want to answer positively to our
       // question. Conservatory behaviour.
@@ -384,7 +384,7 @@ int
 MzLabInputOligomerTableView::testCleaveOligomerDataDropped(
   QDropEvent *event, OligomerList *oligomerList)
 {
-  libmass::PolChemDefCstSPtr polChemDefCstSPtr =
+  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
     mp_mzLabWnd->polChemDefCstSPtr();
 
   const CleaveOligomerTableViewMimeData *tableViewMimeData =
@@ -413,7 +413,7 @@ MzLabInputOligomerTableView::testCleaveOligomerDataDropped(
 
   for(int iter = 0; iter < oligomerList->size(); ++iter)
     {
-      libmass::OligomerSPtr oligomer_sp = oligomerList->at(iter);
+      libXpertMass::OligomerSPtr oligomer_sp = oligomerList->at(iter);
 
       oligomer_sp->setPolChemDefCstSPtr(polChemDefCstSPtr);
     }
@@ -426,7 +426,7 @@ int
 MzLabInputOligomerTableView::testMassSearchOligomerDataDropped(
   QDropEvent *event, OligomerList *oligomerList)
 {
-  libmass::PolChemDefCstSPtr polChemDefCstSPtr =
+  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
     mp_mzLabWnd->polChemDefCstSPtr();
 
   const MassSearchOligomerTableViewMimeData *tableViewMimeData =
@@ -456,7 +456,7 @@ MzLabInputOligomerTableView::testMassSearchOligomerDataDropped(
 
   for(int iter = 0; iter < oligomerList->size(); ++iter)
     {
-      libmass::OligomerSPtr oligomer_sp = oligomerList->at(iter);
+      libXpertMass::OligomerSPtr oligomer_sp = oligomerList->at(iter);
 
       oligomer_sp->setPolChemDefCstSPtr(polChemDefCstSPtr);
     }
@@ -509,7 +509,7 @@ MzLabInputOligomerTableView::testSimpleTextDataDroppedOrPasted(
 
       int stringListSize = stringList.size();
 
-      libmass::OligomerSPtr oligomer_sp = nullptr;
+      libXpertMass::OligomerSPtr oligomer_sp = nullptr;
 
       if(stringListSize == 0)
         {
@@ -584,15 +584,15 @@ MzLabInputOligomerTableView::testSimpleTextDataDropped(
 }
 
 
-libmass::OligomerSPtr
+libXpertMass::OligomerSPtr
 MzLabInputOligomerTableView::parseOnlyMassLine(QStringList &stringList)
 {
   // There is only the mass in the line.
 
-  libmass::PolChemDefCstSPtr polChemDefCstSPtr =
+  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
     mp_mzLabWnd->polChemDefCstSPtr();
 
-  libmass::IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
+  libXpertMass::IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
   int totalCharge                = ionizeRule.charge() * ionizeRule.level();
 
   bool ok     = false;
@@ -614,14 +614,14 @@ MzLabInputOligomerTableView::parseOnlyMassLine(QStringList &stringList)
   // Note that if the ionizeRule has a total charge
   //(charge() * level()), then we have to set this
   // oligomer to charged state(totalCharge ? true : false).
-  libmass::OligomerSPtr oligomer_sp =
-    std::make_shared<libmass::Oligomer>(polChemDefCstSPtr,
+  libXpertMass::OligomerSPtr oligomer_sp =
+    std::make_shared<libXpertMass::Oligomer>(polChemDefCstSPtr,
                                         "NOT_SET" /*name*/,
                                         QString("") /*description*/,
                                         false /*modified*/,
-                                        libmass::Ponderable(mass, mass),
+                                        libXpertMass::Ponderable(mass, mass),
                                         ionizeRule,
-                                        libmass::CalcOptions(),
+                                        libXpertMass::CalcOptions(),
                                         (totalCharge ? true : false),
                                         -1,
                                         -1);
@@ -638,15 +638,15 @@ MzLabInputOligomerTableView::parseOnlyMassLine(QStringList &stringList)
 }
 
 
-libmass::OligomerSPtr
+libXpertMass::OligomerSPtr
 MzLabInputOligomerTableView::parseMassAndChargeLine(QStringList &stringList)
 {
   // One mass, one charge.
 
-  libmass::PolChemDefCstSPtr polChemDefCstSPtr =
+  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
     mp_mzLabWnd->polChemDefCstSPtr();
 
-  libmass::IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
+  libXpertMass::IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
   int totalCharge                = ionizeRule.charge() * ionizeRule.level();
 
   bool ok     = false;
@@ -684,14 +684,14 @@ MzLabInputOligomerTableView::parseMassAndChargeLine(QStringList &stringList)
   // Note that if the ionizeRule has a total charge
   //(charge() * level()), then we have to set this
   // oligomer to charged state(totalCharge ? true : false).
-  libmass::OligomerSPtr oligomer_sp =
-    std::make_shared<libmass::Oligomer>(polChemDefCstSPtr,
+  libXpertMass::OligomerSPtr oligomer_sp =
+    std::make_shared<libXpertMass::Oligomer>(polChemDefCstSPtr,
                                         "NOT_SET" /*name*/,
                                         QString("") /*description*/,
                                         false /*modified*/,
-                                        libmass::Ponderable(mass, mass),
+                                        libXpertMass::Ponderable(mass, mass),
                                         ionizeRule,
-                                        libmass::CalcOptions(),
+                                        libXpertMass::CalcOptions(),
                                         (totalCharge ? true : false),
                                         -1,
                                         -1);
@@ -704,16 +704,16 @@ MzLabInputOligomerTableView::parseMassAndChargeLine(QStringList &stringList)
 }
 
 
-libmass::OligomerSPtr
+libXpertMass::OligomerSPtr
 MzLabInputOligomerTableView::parseFullLine(QStringList &stringList)
 {
   // One mass, one charge and even the name of the oligomer and of the
   // coordinates of that oligomer.
 
-  libmass::PolChemDefCstSPtr polChemDefCstSPtr =
+  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
     mp_mzLabWnd->polChemDefCstSPtr();
 
-  libmass::IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
+  libXpertMass::IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
   int totalCharge                = ionizeRule.charge() * ionizeRule.level();
 
   bool ok     = false;
@@ -785,14 +785,14 @@ MzLabInputOligomerTableView::parseFullLine(QStringList &stringList)
   // Note that if the ionizeRule has a total charge
   //(charge() * level()), then we have to set this
   // oligomer to charged state(totalCharge ? true : false).
-  libmass::OligomerSPtr oligomer_sp =
-    std::make_shared<libmass::Oligomer>(polChemDefCstSPtr,
+  libXpertMass::OligomerSPtr oligomer_sp =
+    std::make_shared<libXpertMass::Oligomer>(polChemDefCstSPtr,
                                         oligoName,
                                         QString("") /*description*/,
                                         false /*modified*/,
-                                        libmass::Ponderable(mass, mass),
+                                        libXpertMass::Ponderable(mass, mass),
                                         ionizeRule,
-                                        libmass::CalcOptions(),
+                                        libXpertMass::CalcOptions(),
                                         (totalCharge ? true : false),
                                         -1,
                                         -1);
@@ -961,7 +961,7 @@ MzLabInputOligomerTableView::itemActivated(const QModelIndex &index)
 
   int row = sourceIndex.row();
 
-  libmass::OligomerSPtr oligomer_sp = mp_oligomerList->at(row);
+  libXpertMass::OligomerSPtr oligomer_sp = mp_oligomerList->at(row);
 
   // We may have two situations here with the data in the table view
   //  coming
@@ -978,13 +978,13 @@ MzLabInputOligomerTableView::itemActivated(const QModelIndex &index)
 
   SequenceEditorWnd *editorWnd = 0;
 
-  const libmass::Polymer *polymer = oligomer_sp->polymer();
+  const libXpertMass::Polymer *polymer = oligomer_sp->polymer();
 
   if(polymer)
     {
       // There must be a pointer to the sequence editor window.
 
-      libmass::Prop *prop = const_cast<libmass::Oligomer *>(oligomer_sp.get())
+      libXpertMass::Prop *prop = const_cast<libXpertMass::Oligomer *>(oligomer_sp.get())
                               ->prop("SEQUENCE_EDITOR_WND");
 
       if(prop)
@@ -1013,16 +1013,16 @@ MzLabInputOligomerTableView::itemActivated(const QModelIndex &index)
       return;
     }
 
-  libmass::CoordinateList *coordinateList =
-    static_cast<libmass::CoordinateList *>(
-      const_cast<libmass::Oligomer *>(oligomer_sp.get()));
+  libXpertMass::CoordinateList *coordinateList =
+    static_cast<libXpertMass::CoordinateList *>(
+      const_cast<libXpertMass::Oligomer *>(oligomer_sp.get()));
 
   // Remove the previous selection, so that we can start fresh.
   editorWnd->mpa_editorGraphicsView->resetSelection();
 
   for(int iter = 0; iter < coordinateList->size(); ++iter)
     {
-      libmass::Coordinates *coordinates = coordinateList->at(iter);
+      libXpertMass::Coordinates *coordinates = coordinateList->at(iter);
 
       int start = coordinates->start();
       int end   = coordinates->end();
@@ -1057,4 +1057,4 @@ MzLabInputOligomerTableView::itemActivated(const QModelIndex &index)
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
