@@ -38,7 +38,7 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/Oligomer.hpp>
+#include <libXpertMass/Oligomer.hpp>
 
 
 /////////////////////// Local includes
@@ -46,7 +46,7 @@
 
 
 
-namespace msxps
+namespace MsXpS
 {
 
 	namespace massxpert
@@ -81,7 +81,7 @@ class MzLabInputOligomerTableView : public QTableView
   void dragEnterEvent(QDragEnterEvent *event);
   void dragMoveEvent(QDragMoveEvent *event);
   void dropEvent(QDropEvent *event);
-  libmass::MassType pasteOrDropMassTypeCheck();
+  libXpertMass::MassType pasteOrDropMassTypeCheck();
 
   public:
   MzLabInputOligomerTableView(QWidget *parent = 0);
@@ -104,9 +104,9 @@ class MzLabInputOligomerTableView : public QTableView
 
   QString *selectedDataAsPlainText();
 
-  libmass::OligomerSPtr parseOnlyMassLine(QStringList &);
-  libmass::OligomerSPtr parseMassAndChargeLine(QStringList &);
-  libmass::OligomerSPtr parseFullLine(QStringList &);
+  libXpertMass::OligomerSPtr parseOnlyMassLine(QStringList &);
+  libXpertMass::OligomerSPtr parseMassAndChargeLine(QStringList &);
+  libXpertMass::OligomerSPtr parseFullLine(QStringList &);
 
   public slots:
   void itemActivated(const QModelIndex &);
@@ -114,5 +114,5 @@ class MzLabInputOligomerTableView : public QTableView
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
 
