@@ -42,8 +42,8 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/Oligomer.hpp>
-#include <libmass/PolChemDefEntity.hpp>
+#include <libXpertMass/Oligomer.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
 
 
 /////////////////////// Local includes
@@ -53,7 +53,7 @@
 #include "ProgramWindow.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -61,7 +61,7 @@ namespace massxpert
 
 
 MzLabInputOligomerTableViewDlg::MzLabInputOligomerTableViewDlg(
-  QWidget *parent, QString name, libmass::MassType massType)
+  QWidget *parent, QString name, libXpertMass::MassType massType)
   : QDialog(parent), m_name(name), m_massType(massType)
 {
   Q_ASSERT(parent);
@@ -74,19 +74,19 @@ MzLabInputOligomerTableViewDlg::MzLabInputOligomerTableViewDlg(
   // Set the delimiter to '$'.
   m_ui.delimiterLineEdit->setText("$");
 
-  m_previousMassType = libmass::MassType::MASS_NONE;
+  m_previousMassType = libXpertMass::MassType::MASS_NONE;
 
   mpa_proxyModel             = 0;
   mpa_oligomerTableViewModel = 0;
 
   setupTableView();
 
-  if(m_massType == libmass::MassType::MASS_MONO)
+  if(m_massType == libXpertMass::MassType::MASS_MONO)
     {
       m_ui.monoCheckBox->setChecked(true);
       m_ui.avgCheckBox->setChecked(false);
     }
-  else if(m_massType == libmass::MassType::MASS_AVG)
+  else if(m_massType == libXpertMass::MassType::MASS_AVG)
     {
       m_ui.avgCheckBox->setChecked(true);
       m_ui.monoCheckBox->setChecked(false);
@@ -214,8 +214,8 @@ MzLabInputOligomerTableViewDlg::duplicateOligomerData(const OligomerList &list)
 
   for(int iter = 0; iter < size; ++iter)
     {
-      libmass::OligomerSPtr oligomer_sp =
-        std::make_shared<libmass::Oligomer>(*list.at(iter));
+      libXpertMass::OligomerSPtr oligomer_sp =
+        std::make_shared<libXpertMass::Oligomer>(*list.at(iter));
       mpa_oligomerTableViewModel->addOligomer(oligomer_sp);
     }
 
@@ -223,7 +223,7 @@ MzLabInputOligomerTableViewDlg::duplicateOligomerData(const OligomerList &list)
 }
 
 
-libmass::MassType
+libXpertMass::MassType
 MzLabInputOligomerTableViewDlg::massType()
 {
   //    qDebug() << __FILE__ << __LINE__ << "m_massType:" << m_massType;
@@ -231,7 +231,7 @@ MzLabInputOligomerTableViewDlg::massType()
 }
 
 
-libmass::MassType
+libXpertMass::MassType
 MzLabInputOligomerTableViewDlg::previousMassType()
 {
   return m_previousMassType;
@@ -239,13 +239,13 @@ MzLabInputOligomerTableViewDlg::previousMassType()
 
 
 void
-MzLabInputOligomerTableViewDlg::setPreviousMassType(libmass::MassType type)
+MzLabInputOligomerTableViewDlg::setPreviousMassType(libXpertMass::MassType type)
 {
   m_previousMassType = type;
 }
 
 
-libmass::MassType
+libXpertMass::MassType
 MzLabInputOligomerTableViewDlg::massTypeQuery()
 {
   // Ask the user what should be the mass type of this dialog window.
@@ -264,13 +264,13 @@ MzLabInputOligomerTableViewDlg::massTypeQuery()
 
   if(msgBox.clickedButton() == monoButton)
     {
-      m_massType = libmass::MassType::MASS_MONO;
+      m_massType = libXpertMass::MassType::MASS_MONO;
       m_ui.monoCheckBox->setCheckState(Qt::Checked);
       m_ui.avgCheckBox->setCheckState(Qt::Unchecked);
     }
   else if(msgBox.clickedButton() == avgButton)
     {
-      m_massType = libmass::MassType::MASS_AVG;
+      m_massType = libXpertMass::MassType::MASS_AVG;
       m_ui.avgCheckBox->setCheckState(Qt::Checked);
       m_ui.monoCheckBox->setCheckState(Qt::Unchecked);
     }
@@ -284,12 +284,12 @@ MzLabInputOligomerTableViewDlg::monoMassCheckBoxStateChanged(int state)
 {
   if(state == Qt::Checked)
     {
-      m_massType = libmass::MassType::MASS_MONO;
+      m_massType = libXpertMass::MassType::MASS_MONO;
       m_ui.avgCheckBox->setCheckState(Qt::Unchecked);
     }
   else
     {
-      m_massType = libmass::MassType::MASS_AVG;
+      m_massType = libXpertMass::MassType::MASS_AVG;
       m_ui.avgCheckBox->setCheckState(Qt::Checked);
     }
 }
@@ -300,30 +300,30 @@ MzLabInputOligomerTableViewDlg::avgMassCheckBoxStateChanged(int state)
 {
   if(state == Qt::Checked)
     {
-      m_massType = libmass::MassType::MASS_AVG;
+      m_massType = libXpertMass::MassType::MASS_AVG;
       m_ui.monoCheckBox->setCheckState(Qt::Unchecked);
     }
   else
     {
-      m_massType = libmass::MassType::MASS_MONO;
+      m_massType = libXpertMass::MassType::MASS_MONO;
       m_ui.monoCheckBox->setCheckState(Qt::Checked);
     }
 }
 
 
 void
-MzLabInputOligomerTableViewDlg::applyFormula(const libmass::Formula &formula,
+MzLabInputOligomerTableViewDlg::applyFormula(const libXpertMass::Formula &formula,
                                              bool inPlace)
 {
-  const libmass::PolChemDefCstSPtr polChemDefCstSPtr =
+  const libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
     mp_mzLabWnd->polChemDefCstSPtr();
 
   double mono = 0;
   double avg  = 0;
 
-  libmass::Formula local(formula);
+  libXpertMass::Formula local(formula);
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     polChemDefCstSPtr->getIsotopicDataCstSPtr();
 
   if(!local.accountMasses(isotopic_data_csp, &mono, &avg))
@@ -355,7 +355,7 @@ MzLabInputOligomerTableViewDlg::applyFormula(const libmass::Formula &formula,
 
           Q_ASSERT(index.isValid());
 
-          libmass::OligomerSPtr oligomer_sp = m_oligomerList.at(iter);
+          libXpertMass::OligomerSPtr oligomer_sp = m_oligomerList.at(iter);
 
           int result = 0;
 
@@ -367,7 +367,7 @@ MzLabInputOligomerTableViewDlg::applyFormula(const libmass::Formula &formula,
           // deionize() call, as we'll have to reionize the oligomer
           // after having incremented the mass.
 
-          if(m_massType == libmass::MassType::MASS_MONO)
+          if(m_massType == libXpertMass::MassType::MASS_MONO)
             {
               oligomer_sp->incrementMass(mono, m_massType);
 
@@ -403,7 +403,7 @@ MzLabInputOligomerTableViewDlg::applyFormula(const libmass::Formula &formula,
     {
       QString dlgName = m_name;
       dlgName.append(" + ( ");
-      dlgName.append(libmass::elideText(formula.toString()));
+      dlgName.append(libXpertMass::elideText(formula.toString()));
       dlgName.append(" )");
 
       MzLabInputOligomerTableViewDlg *dlg =
@@ -441,7 +441,7 @@ MzLabInputOligomerTableViewDlg::applyMass(double mass, bool inPlace)
             iter, MZ_LAB_INPUT_OLIGO_MASS_COLUMN);
           Q_ASSERT(index.isValid());
 
-          libmass::OligomerSPtr oligomer_sp = m_oligomerList.at(iter);
+          libXpertMass::OligomerSPtr oligomer_sp = m_oligomerList.at(iter);
 
           int result = 0;
 
@@ -453,7 +453,7 @@ MzLabInputOligomerTableViewDlg::applyMass(double mass, bool inPlace)
           // deionize() call, as we'll have to reionize the oligomer
           // after having incremented the mass.
 
-          if(m_massType == libmass::MassType::MASS_MONO)
+          if(m_massType == libXpertMass::MassType::MASS_MONO)
             {
               oligomer_sp->incrementMass(mass, m_massType);
 
@@ -488,10 +488,10 @@ MzLabInputOligomerTableViewDlg::applyMass(double mass, bool inPlace)
   else
     {
       QString massString;
-      massString.setNum(mass, 'f', libmass::OLIGOMER_DEC_PLACES);
+      massString.setNum(mass, 'f', libXpertMass::OLIGOMER_DEC_PLACES);
       QString dlgName = m_name;
       dlgName.append(" + ( ");
-      dlgName.append(libmass::elideText(massString));
+      dlgName.append(libXpertMass::elideText(massString));
       dlgName.append(" )");
 
       MzLabInputOligomerTableViewDlg *dlg =
@@ -539,7 +539,7 @@ MzLabInputOligomerTableViewDlg::applyThreshold(double threshold,
           if(!index.isValid())
             qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
-          libmass::OligomerSPtr oligomer_sp = m_oligomerList.at(count);
+          libXpertMass::OligomerSPtr oligomer_sp = m_oligomerList.at(count);
 
           if(onMz)
             {
@@ -587,7 +587,7 @@ MzLabInputOligomerTableViewDlg::applyThreshold(double threshold,
   else
     {
       QString thresholdString;
-      thresholdString.setNum(threshold, 'f', libmass::OLIGOMER_DEC_PLACES);
+      thresholdString.setNum(threshold, 'f', libXpertMass::OLIGOMER_DEC_PLACES);
       QString dlgName = m_name;
       dlgName.append(" + ");
       if(onMz)
@@ -595,7 +595,7 @@ MzLabInputOligomerTableViewDlg::applyThreshold(double threshold,
       else
         dlgName.append(tr("m threshold "));
       dlgName.append("( ");
-      dlgName.append(libmass::elideText(thresholdString));
+      dlgName.append(libXpertMass::elideText(thresholdString));
       dlgName.append(" )");
 
       MzLabInputOligomerTableViewDlg *dlg =
@@ -640,7 +640,7 @@ MzLabInputOligomerTableViewDlg::applyChargeIncrement(int increment,
             iter, MZ_LAB_INPUT_OLIGO_CHARGE_COLUMN);
           Q_ASSERT(chargeIndex.isValid());
 
-          libmass::OligomerSPtr oligomer_sp = m_oligomerList.at(iter);
+          libXpertMass::OligomerSPtr oligomer_sp = m_oligomerList.at(iter);
 
           int charge = 0;
 
@@ -683,7 +683,7 @@ MzLabInputOligomerTableViewDlg::applyChargeIncrement(int increment,
 
           // Update the mass value depending on the mass type.
 
-          if(m_massType == libmass::MassType::MASS_MONO)
+          if(m_massType == libXpertMass::MassType::MASS_MONO)
             {
               // Fake call to setData, because we want the model to
               // be updated with a call to dataChanged(index,
@@ -711,7 +711,7 @@ MzLabInputOligomerTableViewDlg::applyChargeIncrement(int increment,
       QString dlgName = m_name;
       dlgName.append(" + z ");
       dlgName.append("( ");
-      dlgName.append(libmass::elideText(incrementString));
+      dlgName.append(libXpertMass::elideText(incrementString));
       dlgName.append(" )");
 
       MzLabInputOligomerTableViewDlg *dlg =
@@ -732,14 +732,14 @@ MzLabInputOligomerTableViewDlg::applyChargeIncrement(int increment,
 
 void
 MzLabInputOligomerTableViewDlg::applyIonizeRule(
-  const libmass::IonizeRule &ionizeRule, bool inPlace)
+  const libXpertMass::IonizeRule &ionizeRule, bool inPlace)
 {
-  libmass::IonizeRule localIonizeRule = ionizeRule;
+  libXpertMass::IonizeRule localIonizeRule = ionizeRule;
 
-  libmass::PolChemDefCstSPtr polChemDefCstSPtr =
+  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
     mp_mzLabWnd->polChemDefCstSPtr();
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     polChemDefCstSPtr->getIsotopicDataCstSPtr();
 
   if(!localIonizeRule.validate(isotopic_data_csp))
@@ -774,7 +774,7 @@ MzLabInputOligomerTableViewDlg::applyIonizeRule(
             iter, MZ_LAB_INPUT_OLIGO_CHARGE_COLUMN);
           Q_ASSERT(chargeIndex.isValid());
 
-          libmass::OligomerSPtr oligomer_sp = m_oligomerList.at(iter);
+          libXpertMass::OligomerSPtr oligomer_sp = m_oligomerList.at(iter);
 
           // All we do is reionize the oligomer.
 
@@ -782,7 +782,7 @@ MzLabInputOligomerTableViewDlg::applyIonizeRule(
 
           // Update the mass value depending on the mass type.
 
-          if(m_massType == libmass::MassType::MASS_MONO)
+          if(m_massType == libXpertMass::MassType::MASS_MONO)
             {
               // Fake call to setData, because we want the model to
               // be updated with a call to dataChanged(index,
@@ -919,4 +919,4 @@ MzLabInputOligomerTableViewDlg::connectSeqEditorWnd(const QString &text)
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
