@@ -38,7 +38,7 @@
 #include <QSettings>
 
 /////////////////////// libmass includes
-#include <libmass/Oligomer.hpp>
+#include <libXpertMass/Oligomer.hpp>
 
 
 /////////////////////// Local includes
@@ -49,7 +49,7 @@
 #include "../nongui/OligomerPair.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -158,7 +158,7 @@ void
 MzLabMatchBasedActionsDlg::fillMolecularMassList(
   const OligomerList &oligomerList,
   QList<double> *listM,
-  libmass::MassType &massType)
+  libXpertMass::MassType &massType)
 {
   Q_ASSERT(listM);
 
@@ -166,7 +166,7 @@ MzLabMatchBasedActionsDlg::fillMolecularMassList(
 
   for(int iter = 0; iter < oligomerList.size(); ++iter)
     {
-      libmass::OligomerSPtr oligomer_sp = oligomerList.at(iter);
+      libXpertMass::OligomerSPtr oligomer_sp = oligomerList.at(iter);
       mass                              = oligomer_sp->molecularMass(massType);
 
       if(mass < 0)
@@ -229,8 +229,8 @@ MzLabMatchBasedActionsDlg::performMatchWorkPushButton()
 
   // The two lists might not have the same item count.
 
-  libmass::MassType massType1 = dlg1->massType();
-  libmass::MassType massType2 = dlg2->massType();
+  libXpertMass::MassType massType1 = dlg1->massType();
+  libXpertMass::MassType massType2 = dlg2->massType();
 
   if(massType1 != massType2)
     {
@@ -247,7 +247,7 @@ MzLabMatchBasedActionsDlg::performMatchWorkPushButton()
 
 
   // For clearness...
-  libmass::MassType massType = massType1;
+  libXpertMass::MassType massType = massType1;
 
   //    qDebug() << __FILE__ << __LINE__
   //             << "massType:" << massType;
@@ -409,4 +409,4 @@ MzLabMatchBasedActionsDlg::helpPushButton()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
