@@ -38,7 +38,7 @@
 #include <QMessageBox>
 
 /////////////////////// libmass includes
-#include <libmass/Oligomer.hpp>
+#include <libXpertMass/Oligomer.hpp>
 
 
 /////////////////////// Local includes
@@ -48,7 +48,7 @@
 #include "SequenceEditorWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -292,19 +292,19 @@ MzLabOutputOligomerTableView::itemActivated(const QModelIndex &index)
 
   // Which are the oligomers of the pair?
 
-  const libmass::OligomerSPtr oligomer1_sp = oligomerPair->oligomer1();
+  const libXpertMass::OligomerSPtr oligomer1_sp = oligomerPair->oligomer1();
   //     qDebug() << __FILE__ << __LINE__
   // 	     << oligomer1->name();
 
-  const libmass::OligomerSPtr oligomer2_sp = oligomerPair->oligomer2();
+  const libXpertMass::OligomerSPtr oligomer2_sp = oligomerPair->oligomer2();
 
   //     qDebug() << __FILE__ << __LINE__
   // 	     << oligomer2->name();
 
-  // Get the libmass::Polymer instance pointers for both oligomers.
+  // Get the libXpertMass::Polymer instance pointers for both oligomers.
 
-  const libmass::Polymer *polymer1 = oligomer1_sp->polymer();
-  const libmass::Polymer *polymer2 = oligomer2_sp->polymer();
+  const libXpertMass::Polymer *polymer1 = oligomer1_sp->polymer();
+  const libXpertMass::Polymer *polymer2 = oligomer2_sp->polymer();
 
   // If none of the oligomers have a pointer to a polymer, that
   // might mean that the data have been generated using a drag and
@@ -337,17 +337,17 @@ MzLabOutputOligomerTableView::itemActivated(const QModelIndex &index)
 
 void
 MzLabOutputOligomerTableView::provideEditorWindowFeedback(
-  const libmass::OligomerSPtr oligomer_sp)
+  const libXpertMass::OligomerSPtr oligomer_sp)
 {
   if(oligomer_sp == nullptr)
     qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
-  const libmass::Polymer *polymer = oligomer_sp->polymer();
+  const libXpertMass::Polymer *polymer = oligomer_sp->polymer();
 
   // Get the sequence editor window pointer out of the oligomer,
   // if it has one in the form of a NoDeletePointerProp.
 
-  libmass::Prop *prop = const_cast<libmass::Oligomer *>(oligomer_sp.get())
+  libXpertMass::Prop *prop = const_cast<libXpertMass::Oligomer *>(oligomer_sp.get())
                           ->prop("SEQUENCE_EDITOR_WND");
 
   if(!prop)
@@ -362,16 +362,16 @@ MzLabOutputOligomerTableView::provideEditorWindowFeedback(
   if(!editorWnd)
     return;
 
-  libmass::CoordinateList *coordinateList =
-    static_cast<libmass::CoordinateList *>(
-      const_cast<libmass::Oligomer *>(oligomer_sp.get()));
+  libXpertMass::CoordinateList *coordinateList =
+    static_cast<libXpertMass::CoordinateList *>(
+      const_cast<libXpertMass::Oligomer *>(oligomer_sp.get()));
 
   // Remove the previous selection, so that we can start fresh.
   editorWnd->mpa_editorGraphicsView->resetSelection();
 
   for(int iter = 0; iter < coordinateList->size(); ++iter)
     {
-      libmass::Coordinates *coordinates = coordinateList->at(iter);
+      libXpertMass::Coordinates *coordinates = coordinateList->at(iter);
 
       int start = coordinates->start();
       int end   = coordinates->end();
@@ -510,4 +510,4 @@ MzLabOutputOligomerTableView::duplicateSelectedOligomers(
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
