@@ -38,8 +38,8 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/IsotopicDataUserConfigHandler.hpp>
-#include <libmass/PolChemDef.hpp>
+#include <libXpertMass/IsotopicDataUserConfigHandler.hpp>
+#include <libXpertMass/PolChemDef.hpp>
 
 
 /////////////////////// Local includes
@@ -54,7 +54,7 @@
 #include "CrossLinkerDefDlg.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -74,7 +74,7 @@ PolChemDefWnd::PolChemDefWnd(ProgramWindow *parent,
   // polymer chemistry definition.
 
   // Allocate a brand new empty polymer chemistry definition.
-  msp_polChemDef = std::make_shared<libmass::PolChemDef>();
+  msp_polChemDef = std::make_shared<libXpertMass::PolChemDef>();
 
   if(!polChemDefFilePath.isEmpty())
     msp_polChemDef->setXmlDataFilePath(polChemDefFilePath);
@@ -228,7 +228,7 @@ PolChemDefWnd::initialize()
     {
       // We first need to load the isotopic data.
 
-      if(!libmass::PolChemDef::renderXmlPolChemDefFile(msp_polChemDef))
+      if(!libXpertMass::PolChemDef::renderXmlPolChemDefFile(msp_polChemDef))
         {
           QMessageBox::warning(
             this,
@@ -296,10 +296,10 @@ PolChemDefWnd::leftCapEditFinished()
       return;
     }
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     msp_polChemDef->getIsotopicDataCstSPtr();
 
-  libmass::Formula formula = libmass::Formula(m_ui.leftCapLineEdit->text());
+  libXpertMass::Formula formula = libXpertMass::Formula(m_ui.leftCapLineEdit->text());
 
   if(!formula.validate(isotopic_data_csp))
     {
@@ -332,10 +332,10 @@ PolChemDefWnd::rightCapEditFinished()
       return;
     }
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     msp_polChemDef->getIsotopicDataCstSPtr();
 
-  libmass::Formula formula = libmass::Formula(m_ui.rightCapLineEdit->text());
+  libXpertMass::Formula formula = libXpertMass::Formula(m_ui.rightCapLineEdit->text());
 
   if(!formula.validate(isotopic_data_csp))
     {
@@ -366,11 +366,11 @@ PolChemDefWnd::ionizeFormulaEditFinished()
   if(!checkIsotopicData())
     return;
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     msp_polChemDef->getIsotopicDataCstSPtr();
 
-  libmass::Formula formula =
-    libmass::Formula(m_ui.ionizeFormulaLineEdit->text());
+  libXpertMass::Formula formula =
+    libXpertMass::Formula(m_ui.ionizeFormulaLineEdit->text());
 
   if(!formula.validate(isotopic_data_csp))
     {
@@ -422,13 +422,13 @@ PolChemDefWnd::ionizeLevelChanged()
 bool
 PolChemDefWnd::setSingularData()
 {
-  libmass::Formula formula = msp_polChemDef->leftCap();
+  libXpertMass::Formula formula = msp_polChemDef->leftCap();
   m_ui.leftCapLineEdit->setText(formula.toString());
 
   formula = msp_polChemDef->rightCap();
   m_ui.rightCapLineEdit->setText(formula.toString());
 
-  libmass::IonizeRule ionizeRule = msp_polChemDef->ionizeRule();
+  libXpertMass::IonizeRule ionizeRule = msp_polChemDef->ionizeRule();
   formula                        = ionizeRule.formula();
   m_ui.ionizeFormulaLineEdit->setText(formula.toString());
 
@@ -442,7 +442,7 @@ PolChemDefWnd::setSingularData()
 bool
 PolChemDefWnd::checkIsotopicData()
 {
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     msp_polChemDef->getIsotopicDataCstSPtr();
 
   if(isotopic_data_csp->size() < 1)
@@ -721,7 +721,7 @@ PolChemDefWnd::validate()
   // We know we have isotopic data, check them before anything else because we'll
   // need them for almost all the other validations below.
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     msp_polChemDef->getIsotopicDataCstSPtr();
 
   // The validation of the isotopic data takes a vector of strings to store all
@@ -743,7 +743,7 @@ PolChemDefWnd::validate()
       ++total_error_count;
     }
 
-  libmass::Formula formula = msp_polChemDef->leftCap();
+  libXpertMass::Formula formula = msp_polChemDef->leftCap();
   if(!formula.validate(isotopic_data_csp))
     {
       errorList << QString(tr("Validation of left cap failed."));
@@ -757,7 +757,7 @@ PolChemDefWnd::validate()
       ++total_error_count;
     }
 
-  libmass::IonizeRule ionizeRule = msp_polChemDef->ionizeRule();
+  libXpertMass::IonizeRule ionizeRule = msp_polChemDef->ionizeRule();
   if(!ionizeRule.validate(isotopic_data_csp))
     {
       errorList << QString(tr("Validation of ionization rule failed."));
@@ -766,7 +766,7 @@ PolChemDefWnd::validate()
 
   for(int iter = 0; iter < msp_polChemDef->monomerList().size(); ++iter)
     {
-      libmass::Monomer *monomer = msp_polChemDef->monomerList().at(iter);
+      libXpertMass::Monomer *monomer = msp_polChemDef->monomerList().at(iter);
 
       if(!monomer->validate())
         {
@@ -778,7 +778,7 @@ PolChemDefWnd::validate()
 
   for(int iter = 0; iter < msp_polChemDef->modifList().size(); ++iter)
     {
-      libmass::Modif *modif = msp_polChemDef->modifList().at(iter);
+      libXpertMass::Modif *modif = msp_polChemDef->modifList().at(iter);
 
       if(!modif->validate())
         {
@@ -790,7 +790,7 @@ PolChemDefWnd::validate()
 
   for(int iter = 0; iter < msp_polChemDef->crossLinkerList().size(); ++iter)
     {
-      libmass::CrossLinker *crossLinker =
+      libXpertMass::CrossLinker *crossLinker =
         msp_polChemDef->crossLinkerList().at(iter);
 
       if(!crossLinker->validate())
@@ -803,7 +803,7 @@ PolChemDefWnd::validate()
 
   for(int iter = 0; iter < msp_polChemDef->cleaveSpecList().size(); ++iter)
     {
-      libmass::CleaveSpec *cleaveSpec =
+      libXpertMass::CleaveSpec *cleaveSpec =
         msp_polChemDef->cleaveSpecList().at(iter);
 
       if(!cleaveSpec->validate())
@@ -817,7 +817,7 @@ PolChemDefWnd::validate()
 
   for(int iter = 0; iter < msp_polChemDef->fragSpecList().size(); ++iter)
     {
-      libmass::FragSpec *fragSpec = msp_polChemDef->fragSpecList().at(iter);
+      libXpertMass::FragSpec *fragSpec = msp_polChemDef->fragSpecList().at(iter);
 
       if(!fragSpec->validate())
         {
@@ -984,7 +984,7 @@ PolChemDefWnd::save()
   // Now use the polymer chemistry definition save function.
 
   std::size_t isotope_count =
-    libmass::PolChemDef::writeIsotopicData(msp_polChemDef);
+    libXpertMass::PolChemDef::writeIsotopicData(msp_polChemDef);
 
   if(!isotope_count)
     {
@@ -1007,7 +1007,7 @@ PolChemDefWnd::save()
   // Now save the isotopic data using the right isotopic data handler, that is,
   // the user config handler that mimicks the library handler.
 
-  libmass::IsotopicDataUserConfigHandler isotopic_data_handler(
+  libXpertMass::IsotopicDataUserConfigHandler isotopic_data_handler(
     msp_polChemDef->getIsotopicDataSPtr());
 
   isotopic_data_handler.setFileName(isotopic_data_file_path);
@@ -1111,4 +1111,4 @@ PolChemDefWnd::saveAs()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
