@@ -32,7 +32,7 @@
 
 
 /////////////////////// Qt includes
-#include <MassDataClientServerConfigDlg.hpp>
+#include <libXpertMassGui/MassDataClientServerConfigDlg.hpp>
 #include <QSysInfo>
 #include <QString>
 #include <QtGui>
@@ -50,13 +50,13 @@
 
 /////////////////////// Local includes
 
-#include <libmass/PolChemDef.hpp>
-#include <libmass/PolChemDefEntity.hpp>
-#include <libmass/PolChemDefSpec.hpp>
-#include <libmass/MassDataClient.hpp>
-#include <libmass/MassDataServer.hpp>
-#include <libmass/MassDataCborBaseHandler.hpp>
-#include <libmass/MassDataCborMassSpectrumHandler.hpp>
+#include <libXpertMass/PolChemDef.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
+#include <libXpertMass/PolChemDefSpec.hpp>
+#include <libXpertMass/MassDataClient.hpp>
+#include <libXpertMass/MassDataServer.hpp>
+#include <libXpertMass/MassDataCborBaseHandler.hpp>
+#include <libXpertMass/MassDataCborMassSpectrumHandler.hpp>
 #include <pappsomspp/trace/trace.h>
 
 // For the install directory defines
@@ -76,7 +76,7 @@
 #include "../nongui/ConfigSetting.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -96,8 +96,8 @@ ProgramWindow::ProgramWindow(const QString &applicationName,
   setupConfigSettings();
   setupWindow();
 
-  // libmass::MassDataServer *mass_data_server_p =
-  // new libmass::MassDataServer(this);
+  // libXpertMass::MassDataServer *mass_data_server_p =
+  // new libXpertMass::MassDataServer(this);
 
   // if(!mass_data_server_p->listen())
   // qFatal("Could not start the server.");
@@ -114,8 +114,8 @@ ProgramWindow::ProgramWindow(const QString &applicationName,
 
   // qDebug() << "Now starting the client.";
 
-  // libmass::MassDataClient *mass_data_client_p =
-  // new libmass::MassDataClient(ip_address, port_number, this);
+  // libXpertMass::MassDataClient *mass_data_client_p =
+  // new libXpertMass::MassDataClient(ip_address, port_number, this);
 
   // qDebug() << "The client is:" << mass_data_client_p->getStatus();
 }
@@ -956,20 +956,20 @@ ProgramWindow::initializeDecimalPlacesOptions()
 
   settings.beginGroup("decimalPlacesOptions");
 
-  libmass::ATOM_DEC_PLACES = settings.value("ATOM_DEC_PLACES", 10).toInt();
+  libXpertMass::ATOM_DEC_PLACES = settings.value("ATOM_DEC_PLACES", 10).toInt();
   // qDebug() << __FILE__ << __LINE__
   // << "ATOM_DEC_PLACES" << ATOM_DEC_PLACES;
 
-  libmass::OLIGOMER_DEC_PLACES =
+  libXpertMass::OLIGOMER_DEC_PLACES =
     settings.value("OLIGOMER_DEC_PLACES", 5).toInt();
   // qDebug() << __FILE__ << __LINE__
   // << "OLIGOMER_DEC_PLACES" << OLIGOMER_DEC_PLACES;
 
-  libmass::POLYMER_DEC_PLACES = settings.value("POLYMER_DEC_PLACES", 3).toInt();
+  libXpertMass::POLYMER_DEC_PLACES = settings.value("POLYMER_DEC_PLACES", 3).toInt();
   // qDebug() << __FILE__ << __LINE__
   // << "POLYMER_DEC_PLACES" << POLYMER_DEC_PLACES;
 
-  libmass::PH_PKA_DEC_PLACES = settings.value("PH_PKA_DEC_PLACES", 2).toInt();
+  libXpertMass::PH_PKA_DEC_PLACES = settings.value("PH_PKA_DEC_PLACES", 2).toInt();
   // qDebug() << __FILE__ << __LINE__
   // << "PH_PKA_DEC_PLACES" << PH_PKA_DEC_PLACES;
 
@@ -985,24 +985,24 @@ ProgramWindow::setLastFocusedSeqEdWnd(SequenceEditorWnd *wnd)
 }
 
 
-QList<libmass::PolChemDefSpec *> *
+QList<libXpertMass::PolChemDefSpec *> *
 ProgramWindow::polChemDefCatList()
 {
   return &m_polChemDefCatList;
 }
 
 
-std::vector<libmass::PolChemDefCstSPtr>
+std::vector<libXpertMass::PolChemDefCstSPtr>
 ProgramWindow::polChemDefList()
 {
   return m_polChemDefList;
 }
 
 
-libmass::PolChemDefSpec *
+libXpertMass::PolChemDefSpec *
 ProgramWindow::polChemDefSpecName(const QString &name)
 {
-  libmass::PolChemDefSpec *polChemDefSpec = 0;
+  libXpertMass::PolChemDefSpec *polChemDefSpec = 0;
 
   for(int iter = 0; iter < m_polChemDefCatList.size(); ++iter)
     {
@@ -1016,10 +1016,10 @@ ProgramWindow::polChemDefSpecName(const QString &name)
 }
 
 
-libmass::PolChemDefSpec *
+libXpertMass::PolChemDefSpec *
 ProgramWindow::polChemDefSpecFilePath(const QString &filePath)
 {
-  libmass::PolChemDefSpec *polChemDefSpec = 0;
+  libXpertMass::PolChemDefSpec *polChemDefSpec = 0;
 
   for(int iter = 0; iter < m_polChemDefCatList.size(); ++iter)
     {
@@ -1033,15 +1033,15 @@ ProgramWindow::polChemDefSpecFilePath(const QString &filePath)
 }
 
 
-libmass::PolChemDefCstSPtr
+libXpertMass::PolChemDefCstSPtr
 ProgramWindow::polChemDefByName(const QString &name)
 {
-  libmass::PolChemDefCstSPtr polChemDefCstSPtr;
+  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr;
 
-  std::vector<libmass::PolChemDefCstSPtr>::iterator it = find_if(
+  std::vector<libXpertMass::PolChemDefCstSPtr>::iterator it = find_if(
     m_polChemDefList.begin(),
     m_polChemDefList.end(),
-    [name](libmass::PolChemDefCstSPtr pcdsp) { return pcdsp->name() == name; });
+    [name](libXpertMass::PolChemDefCstSPtr pcdsp) { return pcdsp->name() == name; });
 
   if(it != m_polChemDefList.end())
     return *it;
@@ -1053,7 +1053,7 @@ ProgramWindow::polChemDefByName(const QString &name)
 void
 ProgramWindow::polChemDefCatStringList(QStringList &stringList)
 {
-  libmass::PolChemDefSpec *polChemDefSpec = 0;
+  libXpertMass::PolChemDefSpec *polChemDefSpec = 0;
 
   for(int iter = 0; iter < m_polChemDefCatList.size(); ++iter)
     {
@@ -1253,7 +1253,7 @@ ProgramWindow::openSequence(const QString &fileName)
                  const QByteArray &color_byte_array,
                  pappso::TraceCstSPtr trace) {
             qDebug() << "Received a mass spectrum to be displayed.";
-            libmass::MassDataCborMassSpectrumHandler cbor_handler(this, *trace);
+            libXpertMass::MassDataCborMassSpectrumHandler cbor_handler(this, *trace);
             cbor_handler.setTitle(title);
             cbor_handler.setTraceColor(color_byte_array);
             QByteArray byte_array;
@@ -1514,7 +1514,7 @@ ProgramWindow::seqManip()
 void
 ProgramWindow::showIsotopicClusterShaperDlg()
 {
-  mp_isotopicClusterShaperDlg = new libmassgui::IsotopicClusterShaperDlg(
+  mp_isotopicClusterShaperDlg = new libXpertMassGui::IsotopicClusterShaperDlg(
     this, m_applicationName, "Isotopic cluster shaper");
 
   // When the isotopic cluster shaper has finished in the dialog window, the
@@ -1525,12 +1525,12 @@ ProgramWindow::showIsotopicClusterShaperDlg()
   // This is massXpert and we have no mass spectrum display functionality, so we
   // delegate that to some application who might be listening.
   connect(mp_isotopicClusterShaperDlg,
-          &libmassgui::IsotopicClusterShaperDlg::displayMassSpectrumSignal,
+          &libXpertMassGui::IsotopicClusterShaperDlg::displayMassSpectrumSignal,
           [this](const QString &title,
                  const QByteArray &color_byte_array,
                  pappso::TraceCstSPtr trace) {
             qDebug() << "Received a mass spectrum to be displayed.";
-            libmass::MassDataCborMassSpectrumHandler cbor_handler(this, *trace);
+            libXpertMass::MassDataCborMassSpectrumHandler cbor_handler(this, *trace);
             cbor_handler.setTitle(title);
             cbor_handler.setTraceColor(color_byte_array);
             QByteArray byte_array;
@@ -1550,18 +1550,18 @@ ProgramWindow::showIsotopicClusterShaperDlg()
 void
 ProgramWindow::showIsotopicClusterGeneratorDlg()
 {
-  mp_isotopicClusterGeneratorDlg = new libmassgui::IsotopicClusterGeneratorDlg(
+  mp_isotopicClusterGeneratorDlg = new libXpertMassGui::IsotopicClusterGeneratorDlg(
     this, m_applicationName, "Isotopic cluster generator");
 
   // This is massXpert and we have no mass spectrum display functionality, so we
   // delegate that to some application who might be listening.
   connect(mp_isotopicClusterGeneratorDlg,
-          &libmassgui::IsotopicClusterGeneratorDlg::displayMassSpectrumSignal,
+          &libXpertMassGui::IsotopicClusterGeneratorDlg::displayMassSpectrumSignal,
           [this](const QString &title,
                  const QByteArray &color_byte_array,
                  pappso::TraceCstSPtr trace) {
             qDebug() << "Received a mass spectrum to be displayed.";
-            libmass::MassDataCborMassSpectrumHandler cbor_handler(this, *trace);
+            libXpertMass::MassDataCborMassSpectrumHandler cbor_handler(this, *trace);
             cbor_handler.setTitle(title);
             cbor_handler.setTraceColor(color_byte_array);
             QByteArray byte_array;
@@ -1679,29 +1679,29 @@ ProgramWindow::createActions()
       {
 
         mp_clientServerConfigDlg =
-          new libmassgui::MassDataClientServerConfigDlg(
+          new libXpertMassGui::MassDataClientServerConfigDlg(
             this, m_applicationName, "Client-server configuration");
 
         // At this point, make the connections with the signals provided by the
         // configuration dialog window.
 
         connect(mp_clientServerConfigDlg,
-                &libmassgui::MassDataClientServerConfigDlg::startServerSignal,
+                &libXpertMassGui::MassDataClientServerConfigDlg::startServerSignal,
                 this,
                 &ProgramWindow::startServer);
 
         connect(mp_clientServerConfigDlg,
-                &libmassgui::MassDataClientServerConfigDlg::stopServerSignal,
+                &libXpertMassGui::MassDataClientServerConfigDlg::stopServerSignal,
                 this,
                 &ProgramWindow::stopServer);
 
         connect(mp_clientServerConfigDlg,
-                &libmassgui::MassDataClientServerConfigDlg::startClientSignal,
+                &libXpertMassGui::MassDataClientServerConfigDlg::startClientSignal,
                 this,
                 &ProgramWindow::startClient);
 
         connect(mp_clientServerConfigDlg,
-                &libmassgui::MassDataClientServerConfigDlg::stopClientSignal,
+                &libXpertMassGui::MassDataClientServerConfigDlg::stopClientSignal,
                 this,
                 &ProgramWindow::stopClient);
       }
@@ -1838,7 +1838,7 @@ ProgramWindow::startServer()
   if(mpa_massDataServer != nullptr)
     return true;
 
-  mpa_massDataServer = new libmass::MassDataServer(this);
+  mpa_massDataServer = new libXpertMass::MassDataServer(this);
 
   if(mpa_massDataServer != nullptr)
     {
@@ -1879,8 +1879,8 @@ ProgramWindow::startServer()
 
   int port_number    = mpa_massDataServer->serverPort();
 
-  libmassgui::MassDataClientServerConfigDlg *sender_p =
-    static_cast<libmassgui::MassDataClientServerConfigDlg *>(QObject::sender());
+  libXpertMassGui::MassDataClientServerConfigDlg *sender_p =
+    static_cast<libXpertMassGui::MassDataClientServerConfigDlg *>(QObject::sender());
 
   sender_p->updateClientConfigurationData(ip_address, port_number);
 
@@ -1909,7 +1909,7 @@ ProgramWindow::startClient(const QString &ip_address,
   if(mpa_massDataClient != nullptr)
     delete mpa_massDataClient;
 
-  mpa_massDataClient = new libmass::MassDataClient(
+  mpa_massDataClient = new libXpertMass::MassDataClient(
     ip_address, port_number, connection_frequency, this);
 
   if(mpa_massDataClient != nullptr)
@@ -1918,7 +1918,7 @@ ProgramWindow::startClient(const QString &ip_address,
       // dialog display the errors.
 
       connect(mpa_massDataClient,
-              &libmass::MassDataClient::reportErrorSignal,
+              &libXpertMass::MassDataClient::reportErrorSignal,
               [this](const QString &error) {
                 qDebug();
                 if(mp_clientServerConfigDlg)
@@ -1926,7 +1926,7 @@ ProgramWindow::startClient(const QString &ip_address,
               });
 
       connect(mpa_massDataClient,
-              &libmass::MassDataClient::newDataSignal,
+              &libXpertMass::MassDataClient::newDataSignal,
               [&](const QByteArray &byte_array) {
                 qDebug() << "Received new data of size:" << byte_array.size();
 
@@ -1934,7 +1934,7 @@ ProgramWindow::startClient(const QString &ip_address,
               });
 
       connect(mpa_massDataClient,
-              &libmass::MassDataClient::hostFoundSignal,
+              &libXpertMass::MassDataClient::hostFoundSignal,
               [this]() {
                 if(mp_clientServerConfigDlg)
                   mp_clientServerConfigDlg->message("The remote host was found",
@@ -1942,7 +1942,7 @@ ProgramWindow::startClient(const QString &ip_address,
               });
 
       connect(mpa_massDataClient,
-              &libmass::MassDataClient::connectedSignal,
+              &libXpertMass::MassDataClient::connectedSignal,
               [this]() {
                 if(mp_clientServerConfigDlg)
                   mp_clientServerConfigDlg->message(
@@ -1974,18 +1974,18 @@ ProgramWindow::dispatchReceivedData(const QByteArray &byte_array)
   // determine what kind of data it contains. Depending on the data type, the
   // data are dispatched to the proper window.
 
-  libmass::MassDataType mass_data_type =
-    libmass::MassDataCborBaseHandler::readMassDataType(byte_array);
+  libXpertMass::MassDataType mass_data_type =
+    libXpertMass::MassDataCborBaseHandler::readMassDataType(byte_array);
 
   qDebug() << "Mass data type:" << (int)mass_data_type;
 
-  if(mass_data_type == libmass::MassDataType::UNSET)
+  if(mass_data_type == libXpertMass::MassDataType::UNSET)
     {
-      qDebug() << "The mass data type is libmass::MassDataType::UNSET";
+      qDebug() << "The mass data type is libXpertMass::MassDataType::UNSET";
     }
-  else if(mass_data_type == libmass::MassDataType::MASS_SPECTRUM)
+  else if(mass_data_type == libXpertMass::MassDataType::MASS_SPECTRUM)
     {
-      qDebug() << "The mass data type is libmass::MassDataType::MASS_SPECTRUM";
+      qDebug() << "The mass data type is libXpertMass::MassDataType::MASS_SPECTRUM";
 
       // FIXME
       //<sequence editor window>->handleReceivedData(byte_array);
@@ -2013,4 +2013,4 @@ ProgramWindow::massDataToBeServed(const QByteArray &byte_array)
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
