@@ -35,23 +35,23 @@
 
 
 /////////////////////// Qt includes
-#include <libmass/MassDataClient.hpp>
+#include <libXpertMass/MassDataClient.hpp>
 #include <QMainWindow>
 #include <QDir>
 #include <QStringList>
 
 
 /////////////////////// libmass includes
-#include <libmass/PolChemDef.hpp>
-#include <libmass/PolChemDefSpec.hpp>
-#include <libmass/MassDataServer.hpp>
-#include <libmass/MassDataClient.hpp>
+#include <libXpertMass/PolChemDef.hpp>
+#include <libXpertMass/PolChemDefSpec.hpp>
+#include <libXpertMass/MassDataServer.hpp>
+#include <libXpertMass/MassDataClient.hpp>
 
 
 /////////////////////// libmassgui includes
-#include <libmassgui/MassDataClientServerConfigDlg.hpp>
-#include <libmassgui/IsotopicClusterGeneratorDlg.hpp>
-#include <libmassgui/IsotopicClusterShaperDlg.hpp>
+#include <libXpertMassGui/MassDataClientServerConfigDlg.hpp>
+#include <libXpertMassGui/IsotopicClusterGeneratorDlg.hpp>
+#include <libXpertMassGui/IsotopicClusterShaperDlg.hpp>
 
 
 /////////////////////// local includes
@@ -65,7 +65,7 @@ class QMenu;
 class QTextEdit;
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -93,14 +93,14 @@ class ProgramWindow : public QMainWindow
 
   void setLastFocusedSeqEdWnd(SequenceEditorWnd *);
 
-  QList<libmass::PolChemDefSpec *> *polChemDefCatList();
-  libmass::PolChemDefSpec *polChemDefSpecName(const QString &);
-  libmass::PolChemDefSpec *polChemDefSpecFilePath(const QString &);
+  QList<libXpertMass::PolChemDefSpec *> *polChemDefCatList();
+  libXpertMass::PolChemDefSpec *polChemDefSpecName(const QString &);
+  libXpertMass::PolChemDefSpec *polChemDefSpecFilePath(const QString &);
 
   void polChemDefCatStringList(QStringList &stringList);
 
-  std::vector<libmass::PolChemDefCstSPtr> polChemDefList();
-  libmass::PolChemDefCstSPtr polChemDefByName(const QString &name);
+  std::vector<libXpertMass::PolChemDefCstSPtr> polChemDefList();
+  libXpertMass::PolChemDefCstSPtr polChemDefByName(const QString &name);
 
   bool isSequenceEditorWnd(SequenceEditorWnd *) const;
 
@@ -152,14 +152,14 @@ class ProgramWindow : public QMainWindow
   // List of all the polymer chemistry definition specifications that
   // were created during parsing of all the different catalogue files
   // on the system.
-  QList<libmass::PolChemDefSpec *> m_polChemDefCatList;
+  QList<libXpertMass::PolChemDefSpec *> m_polChemDefCatList;
 
   // List of all the polymer chemistry definitions that are loaded in
   // memory and usable to load polymer sequences.
-  std::vector<libmass::PolChemDefCstSPtr> m_polChemDefList;
+  std::vector<libXpertMass::PolChemDefCstSPtr> m_polChemDefList;
 
-  libmass::MassDataClient *mpa_massDataClient = nullptr;
-  libmass::MassDataServer *mpa_massDataServer = nullptr;
+  libXpertMass::MassDataClient *mpa_massDataClient = nullptr;
+  libXpertMass::MassDataServer *mpa_massDataServer = nullptr;
 
   QMenu *mp_fileMenu;
 
@@ -196,11 +196,11 @@ class ProgramWindow : public QMainWindow
   QAction *mp_aboutAct;
   QAction *mp_aboutQtAct;
 
-  libmassgui::IsotopicClusterGeneratorDlg *mp_isotopicClusterGeneratorDlg =
+  libXpertMassGui::IsotopicClusterGeneratorDlg *mp_isotopicClusterGeneratorDlg =
     nullptr;
-  libmassgui::IsotopicClusterShaperDlg *mp_isotopicClusterShaperDlg = nullptr;
+  libXpertMassGui::IsotopicClusterShaperDlg *mp_isotopicClusterShaperDlg = nullptr;
 
-  libmassgui::MassDataClientServerConfigDlg *mp_clientServerConfigDlg = nullptr;
+  libXpertMassGui::MassDataClientServerConfigDlg *mp_clientServerConfigDlg = nullptr;
 
   void addToMenu(QObject *, const QStringList &, QMenu *, const char *);
 
@@ -229,5 +229,5 @@ class ProgramWindow : public QMainWindow
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
 
