@@ -41,7 +41,7 @@
 #include "SeqToolsDlg.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -684,4 +684,4 @@ namespace massxpert
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
