@@ -43,9 +43,9 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/PolChemDef.hpp>
-#include <libmass/Coordinates.hpp>
-#include <libmass/CrossLink.hpp>
+#include <libXpertMass/PolChemDef.hpp>
+#include <libXpertMass/Coordinates.hpp>
+#include <libXpertMass/CrossLink.hpp>
 
 
 /////////////////////// Local includes
@@ -55,7 +55,7 @@
 #include "ChemEntVignetteRenderer.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -149,7 +149,7 @@ SequenceEditorGraphicsView::leftMargin()
 
 
 void
-SequenceEditorGraphicsView::setPolymer(libmass::Polymer *polymer)
+SequenceEditorGraphicsView::setPolymer(libXpertMass::Polymer *polymer)
 {
   Q_ASSERT(polymer);
 
@@ -157,7 +157,7 @@ SequenceEditorGraphicsView::setPolymer(libmass::Polymer *polymer)
 }
 
 
-const libmass::Polymer *
+const libXpertMass::Polymer *
 SequenceEditorGraphicsView::polymer() const
 {
   return mp_polymer;
@@ -518,7 +518,7 @@ SequenceEditorGraphicsView::setSelection(int start,
 
 void
 SequenceEditorGraphicsView::setSelection(
-  const libmass::Coordinates &coordinates,
+  const libXpertMass::Coordinates &coordinates,
   bool multiRegionSelection,
   bool multiSelectionRegion)
 {
@@ -531,13 +531,13 @@ SequenceEditorGraphicsView::setSelection(
 
 void
 SequenceEditorGraphicsView::setSelection(
-  const libmass::CoordinateList &coordinateList,
+  const libXpertMass::CoordinateList &coordinateList,
   bool multiRegionSelection,
   bool multiSelectionRegion)
 {
   for(int iter = 0; iter < coordinateList.size(); ++iter)
     {
-      libmass::Coordinates *coordinates = coordinateList.at(iter);
+      libXpertMass::Coordinates *coordinates = coordinateList.at(iter);
 
       setSelection(coordinates->start(),
                    coordinates->end(),
@@ -589,7 +589,7 @@ SequenceEditorGraphicsView::resetMultiSelectionRegionsButFirstSelection()
 
 
 bool
-SequenceEditorGraphicsView::selectionIndices(libmass::CoordinateList *coordList)
+SequenceEditorGraphicsView::selectionIndices(libXpertMass::CoordinateList *coordList)
 {
   // The coordList should be empty. If not we empty it right away.
 
@@ -606,21 +606,21 @@ SequenceEditorGraphicsView::selectionIndices(libmass::CoordinateList *coordList)
   if(!res)
     {
       // There is no real selection, thus, all we have to do is
-      // construct a fake libmass::Coordinates with the pseudo-selection,
+      // construct a fake libXpertMass::Coordinates with the pseudo-selection,
       // that is a pseudo-region from start to last clicked
       // vignette. Remember, however, that the lastClickedVignette
       // index is one monomer vignette right of the actual vignette
       //(because the selection mark drawing functions require
       // this).
-      libmass::Coordinates *coordinates =
-        new libmass::Coordinates(0, lastClickedVignette() - 1);
+      libXpertMass::Coordinates *coordinates =
+        new libXpertMass::Coordinates(0, lastClickedVignette() - 1);
 
       if(coordList)
         coordList->append(coordinates);
     }
 
   // However, return the real result so that caller knows if there
-  // was a real selection or if the returned libmass::Coordinates instance is
+  // was a real selection or if the returned libXpertMass::Coordinates instance is
   // for the pseudo-selection from start of sequence to the last
   // clicked vignette.
 
@@ -790,7 +790,7 @@ SequenceEditorGraphicsView::positionCursor(
 
 
 ChemEntVignette *
-SequenceEditorGraphicsView::renderVignette(const libmass::Monomer &monomer)
+SequenceEditorGraphicsView::renderVignette(const libXpertMass::Monomer &monomer)
 {
   ChemEntVignetteRenderer *monomerRenderer = 0;
   ChemEntVignetteRenderer *modifRenderer   = 0;
@@ -846,7 +846,7 @@ SequenceEditorGraphicsView::renderVignette(const libmass::Monomer &monomer)
       // Iterate in the list of modifications...
       for(int iter = 0; iter < monomer.modifList()->size(); ++iter)
         {
-          libmass::Modif *modif = monomer.modifList()->at(iter);
+          libXpertMass::Modif *modif = monomer.modifList()->at(iter);
 
           QString modifName = modif->name();
 
@@ -901,7 +901,7 @@ SequenceEditorGraphicsView::renderVignette(const libmass::Monomer &monomer)
 
 
 bool
-SequenceEditorGraphicsView::modifyVignetteAt(int index, libmass::Modif *modif)
+SequenceEditorGraphicsView::modifyVignetteAt(int index, libXpertMass::Modif *modif)
 {
   Q_ASSERT(mp_polymer);
   PolChemDefRendering *polChemDefRendering =
@@ -958,7 +958,7 @@ SequenceEditorGraphicsView::modifyVignetteAt(int index, libmass::Modif *modif)
 
 
 bool
-SequenceEditorGraphicsView::unmodifyVignetteAt(int index, libmass::Modif *modif)
+SequenceEditorGraphicsView::unmodifyVignetteAt(int index, libXpertMass::Modif *modif)
 {
   Q_ASSERT(modif);
 
@@ -989,7 +989,7 @@ SequenceEditorGraphicsView::unmodifyVignetteAt(int index, libmass::Modif *modif)
 
 bool
 SequenceEditorGraphicsView::crossLinkVignetteAt(
-  int index, libmass::CrossLinker *crossLinker)
+  int index, libXpertMass::CrossLinker *crossLinker)
 {
   Q_ASSERT(mp_polymer);
   PolChemDefRendering *polChemDefRendering =
@@ -1041,7 +1041,7 @@ SequenceEditorGraphicsView::crossLinkVignetteAt(
 
 bool
 SequenceEditorGraphicsView::uncrossLinkVignetteAt(
-  int index, libmass::CrossLinker *crossLinker)
+  int index, libXpertMass::CrossLinker *crossLinker)
 {
   Q_ASSERT(crossLinker);
 
@@ -1107,7 +1107,7 @@ SequenceEditorGraphicsView::renderVignettes()
     {
       mp_editorWnd->progressBar()->setValue(iter + 1);
 
-      const libmass::Monomer *monomer = mp_polymer->monomerList().at(iter);
+      const libXpertMass::Monomer *monomer = mp_polymer->monomerList().at(iter);
 
       if(monomer == nullptr)
         qFatal("Monomer pointer cannot be nullptr.");
@@ -1133,17 +1133,17 @@ SequenceEditorGraphicsView::renderVignettes()
   // sequence... We know the polymer sequence has the list of
   // crossLinks.
 
-  const libmass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
+  const libXpertMass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
 
   for(int iter = 0; iter < crossLinkList.size(); ++iter)
     {
-      libmass::CrossLink *crossLink = crossLinkList.at(iter);
+      libXpertMass::CrossLink *crossLink = crossLinkList.at(iter);
 
       // For each monomer in the cross-link, make a vignette.
 
       for(int jter = 0; jter < crossLink->monomerList()->size(); ++jter)
         {
-          const libmass::Monomer *monomer = crossLink->monomerList()->at(jter);
+          const libXpertMass::Monomer *monomer = crossLink->monomerList()->at(jter);
 
           int index = mp_polymer->monomerIndex(monomer);
 
@@ -1448,7 +1448,7 @@ SequenceEditorGraphicsView::updateSequence()
 // POLYMER SEQUENCE-MODIFYING FUNCTIONS ///////////////////////////////
 int
 SequenceEditorGraphicsView::insertMonomerAtPoint(
-  const libmass::Monomer *monomer, bool freeze)
+  const libXpertMass::Monomer *monomer, bool freeze)
 {
   Q_ASSERT(monomer);
 
@@ -1461,7 +1461,7 @@ SequenceEditorGraphicsView::insertMonomerAtPoint(
 
 
 int
-SequenceEditorGraphicsView::insertMonomerAt(const libmass::Monomer *monomer,
+SequenceEditorGraphicsView::insertMonomerAt(const libXpertMass::Monomer *monomer,
                                             int index,
                                             bool freeze)
 {
@@ -1511,7 +1511,7 @@ SequenceEditorGraphicsView::insertMonomerAt(const libmass::Monomer *monomer,
 
 
 int
-SequenceEditorGraphicsView::insertSequenceAtPoint(libmass::Sequence &sequence)
+SequenceEditorGraphicsView::insertSequenceAtPoint(libXpertMass::Sequence &sequence)
 {
   bool freeze = sequence.monomerList().size() > 10 ? true : false;
   int count   = 0;
@@ -1520,8 +1520,8 @@ SequenceEditorGraphicsView::insertSequenceAtPoint(libmass::Sequence &sequence)
     {
       // Reuse the monomer, we take it out of the list and we use it
       // to put into the sequence.
-      const libmass::Monomer *monomer =
-        const_cast<QList<const libmass::Monomer *> &>(sequence.monomerList())
+      const libXpertMass::Monomer *monomer =
+        const_cast<QList<const libXpertMass::Monomer *> &>(sequence.monomerList())
           .takeFirst();
 
       insertMonomerAtPoint(monomer, freeze);
@@ -1572,13 +1572,13 @@ SequenceEditorGraphicsView::prepareMonomerRemovalAt(int index)
   //     qDebug() << __FILE__ << __LINE__ << "Going to call at() with value"
   // 	      << index;
 
-  const libmass::Monomer *monomer = mp_polymer->at(index);
+  const libXpertMass::Monomer *monomer = mp_polymer->at(index);
 
   //     qDebug() << __FILE__ << __LINE__
   // 	      << "prepareMonomerRemovalAt:" << index
   // 	      << "Monomer is:" << monomer->name();
 
-  const libmass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
+  const libXpertMass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
 
   QList<int> theList;
 
@@ -1594,7 +1594,7 @@ SequenceEditorGraphicsView::prepareMonomerRemovalAt(int index)
 
   for(int iter = 0; iter < theList.size(); ++iter)
     {
-      libmass::CrossLink *crossLink = crossLinkList.at(theList.at(iter));
+      libXpertMass::CrossLink *crossLink = crossLinkList.at(theList.at(iter));
 
       // 	qDebug() << __FILE__ << __LINE__
       // 		  << "Monomer is involved in cross-link:" << crossLink->name()
@@ -1602,7 +1602,7 @@ SequenceEditorGraphicsView::prepareMonomerRemovalAt(int index)
 
       for(int jter = 0; jter < crossLink->monomerList()->size(); ++jter)
         {
-          const libmass::Monomer *iterMonomer =
+          const libXpertMass::Monomer *iterMonomer =
             crossLink->monomerList()->at(jter);
 
           int monomerIndex = mp_polymer->monomerIndex(iterMonomer);
@@ -1682,14 +1682,14 @@ SequenceEditorGraphicsView::removeSelectedOligomer()
   // selection mode. However, just to make sure, we use the lastly
   // selected region.
 
-  libmass::CoordinateList coordList;
+  libXpertMass::CoordinateList coordList;
 
   bool selectionPresent = selectionIndices(&coordList);
 
   if(!selectionPresent)
     return 0;
 
-  libmass::Coordinates *coord = coordList.last();
+  libXpertMass::Coordinates *coord = coordList.last();
 
   return removeSequenceRegion(coord->start(), coord->end());
 }
@@ -2106,4 +2106,4 @@ SequenceEditorGraphicsView::mouseMoveEvent(QMouseEvent *event)
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
