@@ -41,16 +41,16 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/CrossLinker.hpp>
-#include <libmass/Coordinates.hpp>
-#include <libmass/Polymer.hpp>
+#include <libXpertMass/CrossLinker.hpp>
+#include <libXpertMass/Coordinates.hpp>
+#include <libXpertMass/Polymer.hpp>
 
 
 /////////////////////// Local includes
 #include "ChemEntVignette.hpp"
 #include "SequenceSelection.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -92,7 +92,7 @@ class SequenceEditorGraphicsView : public QGraphicsView
   // parent instance into which this graphics view packed. Usually
   // that is the SequenceEditorWnd sequence editor window were
   // this view is the m_editorView member.
-  libmass::Polymer *mp_polymer;
+  libXpertMass::Polymer *mp_polymer;
   SequenceEditorWnd *mp_editorWnd;
   MonomerCodeEvaluator *mpa_monomerCodeEvaluator;
 
@@ -205,8 +205,8 @@ class SequenceEditorGraphicsView : public QGraphicsView
 
   int lastClickedVignette();
 
-  void setPolymer(libmass::Polymer *);
-  const libmass::Polymer *polymer() const;
+  void setPolymer(libXpertMass::Polymer *);
+  const libXpertMass::Polymer *polymer() const;
 
   void setEditorWnd(SequenceEditorWnd *);
 
@@ -220,15 +220,15 @@ class SequenceEditorGraphicsView : public QGraphicsView
   int vignetteIndex(const QPointF &);
   QPointF vignetteLocation(int, MxtCardinalDirection = NORTH_WEST);
 
-  void setSelection(const libmass::Coordinates &coordinates, bool, bool);
-  void setSelection(const libmass::CoordinateList &, bool, bool);
+  void setSelection(const libXpertMass::Coordinates &coordinates, bool, bool);
+  void setSelection(const libXpertMass::CoordinateList &, bool, bool);
   void setSelection(int start, int end, bool, bool);
 
   void resetSelection();
   void resetSelectionButLastRegion();
   void resetMultiSelectionRegionsButFirstSelection();
 
-  bool selectionIndices(libmass::CoordinateList * = 0);
+  bool selectionIndices(libXpertMass::CoordinateList * = 0);
 
   void setOngoingMouseMultiSelection(bool);
 
@@ -244,13 +244,13 @@ class SequenceEditorGraphicsView : public QGraphicsView
   bool positionCursor(const RegionSelection &,
                       MxtCursorLinePosition = START_OF_LINE);
 
-  ChemEntVignette *renderVignette(const libmass::Monomer &);
+  ChemEntVignette *renderVignette(const libXpertMass::Monomer &);
 
-  bool modifyVignetteAt(int, libmass::Modif *);
-  bool unmodifyVignetteAt(int, libmass::Modif *);
+  bool modifyVignetteAt(int, libXpertMass::Modif *);
+  bool unmodifyVignetteAt(int, libXpertMass::Modif *);
 
-  bool crossLinkVignetteAt(int, libmass::CrossLinker *);
-  bool uncrossLinkVignetteAt(int, libmass::CrossLinker *);
+  bool crossLinkVignetteAt(int, libXpertMass::CrossLinker *);
+  bool uncrossLinkVignetteAt(int, libXpertMass::CrossLinker *);
   bool removeVignetteAt(int);
   bool renderVignettes();
   bool scaleVignette(ChemEntVignette *);
@@ -262,9 +262,9 @@ class SequenceEditorGraphicsView : public QGraphicsView
   bool updateSequence();
 
   // POLYMER SEQUENCE-MODIFYING FUNCTIONS ///////////////////////////////
-  int insertMonomerAt(const libmass::Monomer *, int, bool = false);
-  int insertMonomerAtPoint(const libmass::Monomer *, bool = false);
-  int insertSequenceAtPoint(libmass::Sequence &);
+  int insertMonomerAt(const libXpertMass::Monomer *, int, bool = false);
+  int insertMonomerAtPoint(const libXpertMass::Monomer *, bool = false);
+  int insertSequenceAtPoint(libXpertMass::Sequence &);
 
   int removeMonomerAt(int, bool = false);
   bool prepareMonomerRemovalAt(int);
@@ -281,7 +281,7 @@ class SequenceEditorGraphicsView : public QGraphicsView
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
 #endif // SEQUENCE_EDITOR_GRAPHICS_VIEW_HPP
