@@ -35,7 +35,7 @@
 #include "SequenceEditorGraphicsViewKeySequenceHandling.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -325,7 +325,7 @@ namespace massxpert
   void
   SequenceEditorGraphicsView::MoveToStartOfDocument(QKeyEvent *event)
   {
-    if(selectionIndices(static_cast<libmass::CoordinateList *>(0)))
+    if(selectionIndices(static_cast<libXpertMass::CoordinateList *>(0)))
       resetSelection();
 
     if(m_lastClickedVignette <= 0)
@@ -354,7 +354,7 @@ namespace massxpert
   void
   SequenceEditorGraphicsView::MoveToEndOfDocument(QKeyEvent *event)
   {
-    if(selectionIndices(static_cast<libmass::CoordinateList *>(0)))
+    if(selectionIndices(static_cast<libXpertMass::CoordinateList *>(0)))
       resetSelection();
 
     if(m_lastClickedVignette >= mp_polymer->size())
@@ -1021,4 +1021,4 @@ namespace massxpert
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
