@@ -31,7 +31,7 @@
  */
 
 
-namespace msxps
+namespace MsXpS
 {
 
 	namespace massxpert
@@ -136,7 +136,7 @@ QString gpl(
   "  To \"propagate\" a work means to do anything with it that, without\n"
   "permission, would make you directly or secondarily liable for\n"
   "infringement under applicable copyright law, except executing it on a\n"
-  "computer or modifying a private copy.  libmass::Propagation includes copying,\n"
+  "computer or modifying a private copy.  libXpertMass::Propagation includes copying,\n"
   "distribution (with or without modification), making available to the\n"
   "public, and in some countries other activities as well.\n"
   "\n"
@@ -249,7 +249,7 @@ QString gpl(
   "  You may charge any price or no price for each copy that you convey,\n"
   "and you may offer support or warranty protection for a fee.\n"
   "\n"
-  "  5. Conveying libmass::Modified Source Versions.\n"
+  "  5. Conveying libXpertMass::Modified Source Versions.\n"
   "\n"
   "  You may convey a work based on the Program, or the modifications to\n"
   "produce it from the Program, in the form of source code under the\n"
@@ -779,4 +779,4 @@ QString gplLegalDisclaimerLiabilitySections(
 
 	} // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
