@@ -32,9 +32,9 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/Oligomer.hpp>
-#include <libmass/PolChemDef.hpp>
-#include <libmass/PolChemDefEntity.hpp>
+#include <libXpertMass/Oligomer.hpp>
+#include <libXpertMass/PolChemDef.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
 
 
 /////////////////////// Local includes
@@ -42,18 +42,18 @@
 
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
 {
 
 
-Cleaver::Cleaver(libmass::Polymer *polymer,
-                 const libmass::PolChemDefCstSPtr polChemDefCstSPtr,
+Cleaver::Cleaver(libXpertMass::Polymer *polymer,
+                 const libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr,
                  const CleaveOptions &cleaveOptions,
-                 const libmass::CalcOptions &calcOptions,
-                 const libmass::IonizeRule &ionizeRule)
+                 const libXpertMass::CalcOptions &calcOptions,
+                 const libXpertMass::IonizeRule &ionizeRule)
   : mp_polymer(polymer),
     mcsp_polChemDef(polChemDefCstSPtr),
     m_cleaveOptions(cleaveOptions),
@@ -190,7 +190,7 @@ Cleaver::cleave(bool reset)
 int
 Cleaver::fillIndexLists()
 {
-  QList<libmass::CleaveMotif *> *motifList = m_cleaveOptions.motifList();
+  QList<libXpertMass::CleaveMotif *> *motifList = m_cleaveOptions.motifList();
 
   while(m_cleaveIndexList.size())
     m_cleaveIndexList.removeFirst();
@@ -201,15 +201,15 @@ Cleaver::fillIndexLists()
   // The cleavage might be performed on a selected portion of a sequence only,
   // not necessarily on the whole polymer sequence.
 
-  libmass::CoordinateList coordinateList = m_calcOptions.coordinateList();
-  libmass::Coordinates *coordinates      = coordinateList.first();
+  libXpertMass::CoordinateList coordinateList = m_calcOptions.coordinateList();
+  libXpertMass::Coordinates *coordinates      = coordinateList.first();
 
   int startIndex = coordinates->start();
   int endIndex   = coordinates->end();
 
   for(int iter = 0; iter < motifList->size(); ++iter)
     {
-      libmass::CleaveMotif *cleaveMotif = motifList->at(iter);
+      libXpertMass::CleaveMotif *cleaveMotif = motifList->at(iter);
       Q_ASSERT(cleaveMotif);
 
       int index = startIndex - 1;
@@ -316,7 +316,7 @@ Cleaver::removeDuplicatesCleavage()
 
 
 int
-Cleaver::findCleaveMotif(libmass::CleaveMotif &cleaveMotif,
+Cleaver::findCleaveMotif(libXpertMass::CleaveMotif &cleaveMotif,
                          int startIndex,
                          int endIndex)
 {
@@ -324,7 +324,7 @@ Cleaver::findCleaveMotif(libmass::CleaveMotif &cleaveMotif,
 
   int firstIndex = 0;
 
-  QList<const libmass::Monomer *> monomerList = mp_polymer->monomerList();
+  QList<const libXpertMass::Monomer *> monomerList = mp_polymer->monomerList();
   const QStringList &codeList                 = cleaveMotif.codeList();
 
 
@@ -372,7 +372,7 @@ Cleaver::findCleaveMotif(libmass::CleaveMotif &cleaveMotif,
 
   while(iterIndex < endIndex)
     {
-      const libmass::Monomer *monomer = monomerList.at(iterIndex);
+      const libXpertMass::Monomer *monomer = monomerList.at(iterIndex);
 
       if(monomer->code() != firstCode)
         {
@@ -436,38 +436,38 @@ Cleaver::findCleaveMotif(libmass::CleaveMotif &cleaveMotif,
 
 
 bool
-Cleaver::accountCleaveRule(libmass::CleaveRule *cleaveRule,
+Cleaver::accountCleaveRule(libXpertMass::CleaveRule *cleaveRule,
                            CleaveOligomer *oligomer)
 {
   Q_ASSERT(cleaveRule);
   Q_ASSERT(oligomer);
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     oligomer->polymer()->getPolChemDefCstSPtr()->getIsotopicDataCstSPtr();
 
-  // For each libmass::Coordinates element in the oligomer, we have to ensure
+  // For each libXpertMass::Coordinates element in the oligomer, we have to ensure
   // we apply the formula(s) that is/are required.
 
   int coordinatesCount =
-    static_cast<libmass::CoordinateList *>(oligomer)->size();
+    static_cast<libXpertMass::CoordinateList *>(oligomer)->size();
 
   //     qDebug() << __FILE__ << __LINE__
   // 	      << "Coordinates count:" << coordinatesCount;
 
   for(int iter = 0; iter < coordinatesCount; ++iter)
     {
-      libmass::Coordinates *coordinates =
-        static_cast<libmass::CoordinateList *>(oligomer)->at(iter);
+      libXpertMass::Coordinates *coordinates =
+        static_cast<libXpertMass::CoordinateList *>(oligomer)->at(iter);
 
       if(!cleaveRule->leftCode().isEmpty())
         {
           // The formula has to be there.
 
-          libmass::Formula ruleFormula = cleaveRule->leftFormula();
+          libXpertMass::Formula ruleFormula = cleaveRule->leftFormula();
           Q_ASSERT(!ruleFormula.toString().isEmpty());
 
           // What is the monomer at the left end of current oligomer ?
-          const libmass::Monomer &monomer = oligomer->atLeftEnd();
+          const libXpertMass::Monomer &monomer = oligomer->atLeftEnd();
 
           if(monomer.code() == cleaveRule->leftCode())
             {
@@ -498,11 +498,11 @@ Cleaver::accountCleaveRule(libmass::CleaveRule *cleaveRule,
         {
           // The formula has to be there.
 
-          libmass::Formula ruleFormula = cleaveRule->rightFormula();
+          libXpertMass::Formula ruleFormula = cleaveRule->rightFormula();
           Q_ASSERT(!ruleFormula.toString().isEmpty());
 
           // What is the monomer at the right end of current oligomer ?
-          const libmass::Monomer &monomer = oligomer->atRightEnd();
+          const libXpertMass::Monomer &monomer = oligomer->atRightEnd();
 
           if(monomer.code() == cleaveRule->rightCode())
             {
@@ -548,7 +548,7 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
   OligomerList partialOligomerList;
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     mcsp_polChemDef->getIsotopicDataCstSPtr();
 
   // The cleavage might be performed on a selected portion of a sequence only,
@@ -556,8 +556,8 @@ Cleaver::cleavePartial(int partialCleavageValue)
   // because when we create oligomer we'll have to set the coordinates of the
   // monomers correctly.
 
-  libmass::CoordinateList coordinateList = m_calcOptions.coordinateList();
-  libmass::Coordinates *coordinates      = coordinateList.first();
+  libXpertMass::CoordinateList coordinateList = m_calcOptions.coordinateList();
+  libXpertMass::Coordinates *coordinates      = coordinateList.first();
 
   int startIndex = coordinates->start();
   int endIndex   = coordinates->end();
@@ -609,20 +609,20 @@ Cleaver::cleavePartial(int partialCleavageValue)
         name,
         m_cleaveOptions.name(),
         mp_polymer->hasModifiedMonomer(leftIndex, rightIndex),
-        libmass::Ponderable(),
+        libXpertMass::Ponderable(),
         leftIndex,
         rightIndex,
         partialCleavageValue,
         m_calcOptions);
 
       // The CleaveOligomer cannot compute its own elemental composition,
-      // contrary to libmass::Oligomer.
+      // contrary to libXpertMass::Oligomer.
 
       // Use the shared pointer to the CleaveOligomer to access the base class
       // function that works by using calcoptions to compute the formula of the
       // oligomer.
       QString elemental_composition =
-        oligomer_sp.get()->libmass::Oligomer::elementalComposition();
+        oligomer_sp.get()->libXpertMass::Oligomer::elementalComposition();
 
       // And now use that elemental composition to set it in the CleaveOligomer.
 
@@ -669,20 +669,20 @@ Cleaver::cleavePartial(int partialCleavageValue)
     name,
     m_cleaveOptions.name(),
     mp_polymer->hasModifiedMonomer(leftIndex, rightIndex),
-    libmass::Ponderable(),
+    libXpertMass::Ponderable(),
     leftIndex,
     rightIndex,
     partialCleavageValue,
     m_calcOptions);
 
   // The CleaveOligomer cannot compute its own elemental composition,
-  // contrary to libmass::Oligomer.
+  // contrary to libXpertMass::Oligomer.
 
   // Use the shared pointer to the CleaveOligomer to access the base class
   // function that works by using calcoptions to compute the formula of the
   // oligomer.
   QString elemental_composition =
-    oligomer_sp.get()->libmass::Oligomer::elementalComposition();
+    oligomer_sp.get()->libXpertMass::Oligomer::elementalComposition();
 
   // And now use that elemental composition to set it in the CleaveOligomer.
 
@@ -703,7 +703,7 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
   if(!partialCleavageValue)
     {
-      if(m_calcOptions.monomerEntities() & libmass::MONOMER_CHEMENT_CROSS_LINK)
+      if(m_calcOptions.monomerEntities() & libXpertMass::MONOMER_CHEMENT_CROSS_LINK)
         {
           if(analyzeCrossLinks(&partialOligomerList) == -1)
             {
@@ -725,7 +725,7 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
   while(partialOligomerList.size())
     {
-      libmass::OligomerSPtr iter_oligomer_sp = partialOligomerList.takeFirst();
+      libXpertMass::OligomerSPtr iter_oligomer_sp = partialOligomerList.takeFirst();
 
       CleaveOligomer *iter_oligomer_p =
         dynamic_cast<CleaveOligomer *>(iter_oligomer_sp.get());
@@ -748,7 +748,7 @@ Cleaver::cleavePartial(int partialCleavageValue)
           //  we have to ionize the oligomer only after we have
           //  completed the determination of its atomic composition.
 
-          libmass::CleaveRule *cleaveRule =
+          libXpertMass::CleaveRule *cleaveRule =
             m_cleaveOptions.ruleList()->at(jter);
 
           // qDebug() << __FILE__ << __LINE__
@@ -774,7 +774,7 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
       int startIonizeLevel = m_cleaveOptions.startIonizeLevel();
       int endIonizeLevel   = m_cleaveOptions.endIonizeLevel() + 1;
-      libmass::IonizeRule ionizeRule(m_ionizeRule);
+      libXpertMass::IonizeRule ionizeRule(m_ionizeRule);
 
       for(int kter = startIonizeLevel; kter < endIonizeLevel; ++kter)
         {
@@ -843,9 +843,9 @@ Cleaver::cleavePartial(int partialCleavageValue)
 
       //// Elemental formula
       // QString *text = new QString(iter_oligomer_sp->elementalComposition());
-      // libmass::StringProp *prop =
-      // new libmass::StringProp("ELEMENTAL_COMPOSITION", text);
-      // iter_oligomer_sp->appendProp(static_cast<libmass::Prop *>(prop));
+      // libXpertMass::StringProp *prop =
+      // new libXpertMass::StringProp("ELEMENTAL_COMPOSITION", text);
+      // iter_oligomer_sp->appendProp(static_cast<libXpertMass::Prop *>(prop));
 
       mp_oligomerList->append(iter_oligomer_sp);
     }
@@ -869,16 +869,16 @@ Cleaver::analyzeCrossLinks(OligomerList *oligomerList)
   // serve as a seed to pull-down all the oligomers cross-linked to
   // it.
 
-  const libmass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
+  const libXpertMass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
 
   for(int iter = 0; iter < crossLinkList.size(); ++iter)
     {
-      libmass::CrossLink *crossLink = crossLinkList.at(iter);
+      libXpertMass::CrossLink *crossLink = crossLinkList.at(iter);
 
       // With that crossLink, find an oligomer that encompasses the
       // first monomer of the cross-link.
 
-      const libmass::Monomer *firstMonomer = crossLink->firstMonomer();
+      const libXpertMass::Monomer *firstMonomer = crossLink->firstMonomer();
 
       Q_ASSERT(firstMonomer);
 
@@ -886,7 +886,7 @@ Cleaver::analyzeCrossLinks(OligomerList *oligomerList)
 
       int foundIndex = 0;
 
-      libmass::OligomerSPtr first_oligomer_sp =
+      libXpertMass::OligomerSPtr first_oligomer_sp =
         oligomerList->findOligomerEncompassing(firstMonomer, &foundIndex);
 
       if(first_oligomer_sp)
@@ -921,13 +921,13 @@ Cleaver::analyzeCrossLinks(OligomerList *oligomerList)
   // for the partial cleavage. All we have to do is move all the
   // crossLinked oligomers from the crossLinkedOligomerList to
   // oligomerList. While doing so make sure that the m_calcOptions
-  // datum has correct libmass::CoordinateList data, as these data will be
+  // datum has correct libXpertMass::CoordinateList data, as these data will be
   // required later, typically to calculate the elemental formula of
   // the oligomer.
 
   while(crossLinkedOligomerList.size())
     {
-      libmass::OligomerSPtr oligomer_sp = crossLinkedOligomerList.takeAt(0);
+      libXpertMass::OligomerSPtr oligomer_sp = crossLinkedOligomerList.takeAt(0);
 
       oligomer_sp->updateCalcOptions();
 
@@ -944,13 +944,13 @@ Cleaver::analyzeCrossLinks(OligomerList *oligomerList)
 
 
 int
-Cleaver::analyzeCrossLinkedOligomer(libmass::OligomerSPtr oligomer_sp,
+Cleaver::analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr oligomer_sp,
                                     OligomerList *oligomerList)
 {
   Q_ASSERT(oligomer_sp);
   Q_ASSERT(oligomerList);
 
-  const libmass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
+  const libXpertMass::CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
 
   OligomerList clearanceOligomerList;
 
@@ -969,7 +969,7 @@ Cleaver::analyzeCrossLinkedOligomer(libmass::OligomerSPtr oligomer_sp,
   for(int iter = oligomer_sp->startIndex(); iter < oligomer_sp->endIndex() + 1;
       ++iter)
     {
-      const libmass::Monomer *monomer = mp_polymer->at(iter);
+      const libXpertMass::Monomer *monomer = mp_polymer->at(iter);
 
       // What crossLinks do involve this monomer ?
 
@@ -987,7 +987,7 @@ Cleaver::analyzeCrossLinkedOligomer(libmass::OligomerSPtr oligomer_sp,
 
           foreach(index, crossLinkIndices)
             {
-              libmass::CrossLink *crossLink = crossLinkList.at(index);
+              libXpertMass::CrossLink *crossLink = crossLinkList.at(index);
 
               // 	      qDebug() << __FILE__ << __LINE__
               // 			<< crossLink->name();
@@ -1021,7 +1021,7 @@ Cleaver::analyzeCrossLinkedOligomer(libmass::OligomerSPtr oligomer_sp,
                   //	    << "oligomer's list of cross-links.";
                 }
 
-              const libmass::Monomer *iterMonomer = 0;
+              const libXpertMass::Monomer *iterMonomer = 0;
 
               foreach(iterMonomer, *(crossLink->monomerList()))
                 {
@@ -1030,7 +1030,7 @@ Cleaver::analyzeCrossLinkedOligomer(libmass::OligomerSPtr oligomer_sp,
 
                   int foundIndex = 0;
 
-                  libmass::OligomerSPtr found_oligomer_sp =
+                  libXpertMass::OligomerSPtr found_oligomer_sp =
                     oligomerList->findOligomerEncompassing(iterMonomer,
                                                            &foundIndex);
 
@@ -1081,13 +1081,13 @@ Cleaver::analyzeCrossLinkedOligomer(libmass::OligomerSPtr oligomer_sp,
 
   while(clearanceOligomerList.size())
     {
-      libmass::OligomerSPtr iter_oligomer_sp = clearanceOligomerList.first();
+      libXpertMass::OligomerSPtr iter_oligomer_sp = clearanceOligomerList.first();
 
       for(int iter = iter_oligomer_sp->startIndex();
           iter < iter_oligomer_sp->endIndex() + 1;
           ++iter)
         {
-          const libmass::Monomer *monomer = mp_polymer->at(iter);
+          const libXpertMass::Monomer *monomer = mp_polymer->at(iter);
 
           // 	  qDebug() << __FILE__ << __LINE__
           // 		    << monomer->name();
@@ -1108,7 +1108,7 @@ Cleaver::analyzeCrossLinkedOligomer(libmass::OligomerSPtr oligomer_sp,
 
               foreach(index, crossLinkIndices)
                 {
-                  libmass::CrossLink *crossLink = crossLinkList.at(index);
+                  libXpertMass::CrossLink *crossLink = crossLinkList.at(index);
 
                   // 		  qDebug() << __FILE__ << __LINE__
                   // 			    << crossLink->name();
@@ -1142,7 +1142,7 @@ Cleaver::analyzeCrossLinkedOligomer(libmass::OligomerSPtr oligomer_sp,
                       // << "oligomer's list of cross-links.";
                     }
 
-                  const libmass::Monomer *iterMonomer = 0;
+                  const libXpertMass::Monomer *iterMonomer = 0;
 
                   foreach(iterMonomer, *(crossLink->monomerList()))
                     {
@@ -1151,7 +1151,7 @@ Cleaver::analyzeCrossLinkedOligomer(libmass::OligomerSPtr oligomer_sp,
 
                       int foundIndex = 0;
 
-                      libmass::OligomerSPtr found_oligomer_sp =
+                      libXpertMass::OligomerSPtr found_oligomer_sp =
                         oligomerList->findOligomerEncompassing(iterMonomer,
                                                                &foundIndex);
 
@@ -1213,7 +1213,7 @@ Cleaver::analyzeCrossLinkedOligomer(libmass::OligomerSPtr oligomer_sp,
   //       oligomer->crossLinkList()->at(iter)->name();
 
 
-  return static_cast<libmass::CoordinateList *>(oligomer_sp.get())->size();
+  return static_cast<libXpertMass::CoordinateList *>(oligomer_sp.get())->size();
 }
 
 
@@ -1226,4 +1226,4 @@ Cleaver::emptyOligomerList()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
