@@ -37,12 +37,12 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/Oligomer.hpp>
-#include <libmass/PolChemDefEntity.hpp>
-#include <libmass/CleaveSpec.hpp>
-#include <libmass/CalcOptions.hpp>
-#include <libmass/Polymer.hpp>
-#include <libmass/IonizeRule.hpp>
+#include <libXpertMass/Oligomer.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
+#include <libXpertMass/CleaveSpec.hpp>
+#include <libXpertMass/CalcOptions.hpp>
+#include <libXpertMass/Polymer.hpp>
+#include <libXpertMass/IonizeRule.hpp>
 
 
 /////////////////////// Local includes
@@ -51,7 +51,7 @@
 #include "OligomerList.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -61,11 +61,11 @@ namespace massxpert
   class Cleaver
   {
     public:
-    Cleaver(libmass::Polymer *,
-            const libmass::PolChemDefCstSPtr,
+    Cleaver(libXpertMass::Polymer *,
+            const libXpertMass::PolChemDefCstSPtr,
             const CleaveOptions &,
-            const libmass::CalcOptions &,
-            const libmass::IonizeRule &);
+            const libXpertMass::CalcOptions &,
+            const libXpertMass::IonizeRule &);
 
     Cleaver(const Cleaver &);
     ~Cleaver();
@@ -78,23 +78,23 @@ namespace massxpert
 
     QString cleaveAgentName() const;
     int analyzeCrossLinks(OligomerList *);
-    int analyzeCrossLinkedOligomer(libmass::OligomerSPtr, OligomerList *);
+    int analyzeCrossLinkedOligomer(libXpertMass::OligomerSPtr, OligomerList *);
 
     int fillIndexLists();
     int resolveCleavageNoCleavage();
     int removeDuplicatesCleavage();
 
-    int findCleaveMotif(libmass::CleaveMotif &, int, int);
-    bool accountCleaveRule(libmass::CleaveRule *, CleaveOligomer *);
+    int findCleaveMotif(libXpertMass::CleaveMotif &, int, int);
+    bool accountCleaveRule(libXpertMass::CleaveRule *, CleaveOligomer *);
 
     void emptyOligomerList();
 
     private:
-    libmass::Polymer *mp_polymer;
-    const libmass::PolChemDefCstSPtr mcsp_polChemDef;
+    libXpertMass::Polymer *mp_polymer;
+    const libXpertMass::PolChemDefCstSPtr mcsp_polChemDef;
     CleaveOptions m_cleaveOptions;
-    libmass::CalcOptions m_calcOptions;
-    libmass::IonizeRule m_ionizeRule;
+    libXpertMass::CalcOptions m_calcOptions;
+    libXpertMass::IonizeRule m_ionizeRule;
 
     QList<int> m_cleaveIndexList;
     QList<int> m_noCleaveIndexList;
@@ -105,7 +105,7 @@ namespace massxpert
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
 #endif // CLEAVER_HPP
