@@ -36,8 +36,8 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/PolChemDef.hpp>
-#include <libmass/PolChemDefEntity.hpp>
+#include <libXpertMass/PolChemDef.hpp>
+#include <libXpertMass/PolChemDefEntity.hpp>
 
 
 /////////////////////// Local includes
@@ -46,18 +46,18 @@
 #include "FragmentOligomer.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
 {
 
 
-Fragmenter::Fragmenter(libmass::Polymer *polymer,
-                       libmass::PolChemDefCstSPtr polChemDefCstSPtr,
+Fragmenter::Fragmenter(libXpertMass::Polymer *polymer,
+                       libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr,
                        const QList<FragOptions *> &fragOptionList,
-                       const libmass::CalcOptions &calcOptions,
-                       const libmass::IonizeRule &ionizeRule)
+                       const libXpertMass::CalcOptions &calcOptions,
+                       const libXpertMass::IonizeRule &ionizeRule)
   : mp_polymer(polymer),
     mcsp_polChemDef(polChemDefCstSPtr),
     m_calcOptions(calcOptions),
@@ -157,7 +157,7 @@ Fragmenter::fragment()
   // has asked that these cross-linked be taken into account during
   // the fragmentation.
 
-  if(m_calcOptions.monomerEntities() & libmass::MONOMER_CHEMENT_CROSS_LINK)
+  if(m_calcOptions.monomerEntities() & libXpertMass::MONOMER_CHEMENT_CROSS_LINK)
     {
       // qDebug() << __FILE__ << __LINE__
       //          << "Fragmentation calculations take "
@@ -256,7 +256,7 @@ Fragmenter::fragment()
               CrossLinkedRegion *region = new CrossLinkedRegion(first, last);
 
               // Get the cross-links for the region.
-              QList<libmass::CrossLink *> crossLinkList;
+              QList<libXpertMass::CrossLink *> crossLinkList;
 
               partials = 0;
 
@@ -296,7 +296,7 @@ Fragmenter::fragment()
       CrossLinkedRegion *region = new CrossLinkedRegion(first, last);
 
       // Get the cross-links for the region.
-      QList<libmass::CrossLink *> crossLinkList;
+      QList<libXpertMass::CrossLink *> crossLinkList;
 
       partials = 0;
 
@@ -337,17 +337,17 @@ Fragmenter::fragment()
     {
       FragOptions *fragOptions = m_fragOptionList.at(iter);
 
-      if(fragOptions->fragEnd() == libmass::FRAG_END_NONE)
+      if(fragOptions->fragEnd() == libXpertMass::FRAG_END_NONE)
         {
           if(fragmentEndNone(*fragOptions) == -1)
             return false;
         }
-      else if(fragOptions->fragEnd() == libmass::FRAG_END_LEFT)
+      else if(fragOptions->fragEnd() == libXpertMass::FRAG_END_LEFT)
         {
           if(fragmentEndLeft(*fragOptions) == -1)
             return false;
         }
-      else if(fragOptions->fragEnd() == libmass::FRAG_END_RIGHT)
+      else if(fragOptions->fragEnd() == libXpertMass::FRAG_END_RIGHT)
         {
           if(fragmentEndRight(*fragOptions) == -1)
             return false;
@@ -367,13 +367,13 @@ Fragmenter::fragmentEndNone(FragOptions &fragOptions)
   // like in the proteinaceous world we have the immonium ions.
 
   // We will need the isotopic data throughout all of this function.
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     mcsp_polChemDef->getIsotopicDataCstSPtr();
 
   int count = 0;
 
-  libmass::CalcOptions localOptions = m_calcOptions;
-  localOptions.setCapping(libmass::CAP_NONE);
+  libXpertMass::CalcOptions localOptions = m_calcOptions;
+  localOptions.setCapping(libXpertMass::CAP_NONE);
 
   for(int iter = fragOptions.startIndex(); iter < fragOptions.endIndex() + 1;
       ++iter)
@@ -394,7 +394,7 @@ Fragmenter::fragmentEndNone(FragOptions &fragOptions)
       // moment we try to create a "template" oligomer with the ionization rule
       // set but with the ionization level set to 0.
 
-      libmass::IonizeRule ionizeRule(m_ionizeRule);
+      libXpertMass::IonizeRule ionizeRule(m_ionizeRule);
       ionizeRule.setLevel(0);
 
       // Allocate a FragmentOligomer in which we'll update each time the formulj
@@ -404,7 +404,7 @@ Fragmenter::fragmentEndNone(FragOptions &fragOptions)
         "NOT_SET",
         fragOptions.name() /*fragSpec.m_name*/,
         mp_polymer->hasModifiedMonomer(iter, iter),
-        libmass::Ponderable(),
+        libXpertMass::Ponderable(),
         ionizeRule,
         localOptions,
         false /*isIonized*/,
@@ -427,7 +427,7 @@ Fragmenter::fragmentEndNone(FragOptions &fragOptions)
       // might interfere with the mass of the fragment. So we pass
       // an invalid ionizeRule object(upon creation, an ionize rule
       // is invalid).
-      libmass::IonizeRule rule;
+      libXpertMass::IonizeRule rule;
 
       if(!oligomer1_sp->calculateMasses(&localOptions, &rule))
         {
@@ -440,7 +440,7 @@ Fragmenter::fragmentEndNone(FragOptions &fragOptions)
       // Ask the monomer to actually compute its formula either by taking into
       // account the modifications or not depending on the calculation options
       // below.
-      libmass::Formula monomer_formula =
+      libXpertMass::Formula monomer_formula =
         mp_polymer->at(iter)->calculateFormula(m_calcOptions.monomerEntities());
 
       oligomer1_sp->m_formula.accountFormula(monomer_formula.toString(),
@@ -477,13 +477,13 @@ Fragmenter::fragmentEndNone(FragOptions &fragOptions)
       // away. This is implemented in massXpert with the ability to
       // tell the fragmenter that upon fragmentation the mass of the
       // monomer is to be removed. The skeleton mass is then added
-      // to the formula of the fragmentation pattern (libmass::FragSpec).
+      // to the formula of the fragmentation pattern (libXpertMass::FragSpec).
 
       int monomerContrib = fragOptions.monomerContribution();
 
       if(monomerContrib)
         {
-          const libmass::Monomer *monomer = mp_polymer->at(iter);
+          const libXpertMass::Monomer *monomer = mp_polymer->at(iter);
 
           QString formula = monomer->formula();
 
@@ -505,7 +505,7 @@ Fragmenter::fragmentEndNone(FragOptions &fragOptions)
 
       // At this point we should check if the fragmentation
       // specification includes fragmentation rules that apply to this
-      // fragment. FragOptions is derived from libmass::FragSpec.
+      // fragment. FragOptions is derived from libXpertMass::FragSpec.
 
       for(int jter = 0; jter < fragOptions.ruleList().size(); ++jter)
         {
@@ -515,13 +515,13 @@ Fragmenter::fragmentEndNone(FragOptions &fragOptions)
           // fact that the user might want to calculate fragment m/z
           // with z>1.
 
-          libmass::FragRule *fragRule = fragOptions.ruleList().at(jter);
+          libXpertMass::FragRule *fragRule = fragOptions.ruleList().at(jter);
 
           // This round is not for real accounting, but only to check of the
           // currently iterated frag rule should be accounted for (see the true
           // that indicates this call is only for checking).
           if(!accountFragRule(
-               fragRule, true, iter, libmass::FRAG_END_NONE, nullptr))
+               fragRule, true, iter, libXpertMass::FRAG_END_NONE, nullptr))
             continue;
 
           // This is why we first check above if the frag rule was to be
@@ -534,7 +534,7 @@ Fragmenter::fragmentEndNone(FragOptions &fragOptions)
           if(!accountFragRule(fragRule,
                               false,
                               iter,
-                              libmass::FRAG_END_NONE,
+                              libXpertMass::FRAG_END_NONE,
                               oligomer2_sp.get()))
             {
               oligomer1_sp.reset();
@@ -751,7 +751,7 @@ Fragmenter::fragmentEndNone(FragOptions &fragOptions)
 
           while(!ionizeLevelOligomerList->isEmpty())
             {
-              libmass::OligomerSPtr iter_oligomer_sp =
+              libXpertMass::OligomerSPtr iter_oligomer_sp =
                 ionizeLevelOligomerList->takeFirst();
 
               mp_oligomerList->append(iter_oligomer_sp);
@@ -793,18 +793,18 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
 
   // qDebug() << "FragOptions:" << fragOptions.toString();
 
-  static libmass::Ponderable ponderable;
+  static libXpertMass::Ponderable ponderable;
   ponderable.clearMasses();
 
   // Formula to hold the summative result of accounting all of the residues
   // making the residual chain of the fragmentation ion product. Thus, this
   // formula is to be increment at the beginning of each for loop iteration
   // below.
-  static libmass::Formula residue_chain_formula;
+  static libXpertMass::Formula residue_chain_formula;
   residue_chain_formula.clear();
 
   // We will need the isotopic data throughout all of this function.
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     mcsp_polChemDef->getIsotopicDataCstSPtr();
 
 
@@ -850,7 +850,7 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
       bool fragRuleApplied = false;
 
       // Get a pointer to the polymer's monomer at index iter.
-      const libmass::Monomer *monomer = mp_polymer->at(iter);
+      const libXpertMass::Monomer *monomer = mp_polymer->at(iter);
 
       // qDebug() << "Before accounting for monomer" << monomer->code()
       //<< "of formula, the residue_chain_formula: "
@@ -870,7 +870,7 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
       // Ask the monomer to actually compute its formula either by taking into
       // account the modifications or not depending on the calculation options
       // below.
-      libmass::Formula monomer_formula =
+      libXpertMass::Formula monomer_formula =
         monomer->calculateFormula(m_calcOptions.monomerEntities());
 
       //qDebug() << "Before accounting for monomer formula:"
@@ -907,7 +907,7 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
               // ... if so, iterate in the list of cross-links that
               // is stored in the CrossLinkedRegion...
 
-              const QList<libmass::CrossLink *> &crossLinkList =
+              const QList<libXpertMass::CrossLink *> &crossLinkList =
                 region->crossLinkList();
 
               for(int kter = 0; kter < crossLinkList.size(); ++kter)
@@ -915,7 +915,7 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
                   // ... and for each cross-link, account its mass
                   // in the fragment (that is, ponderable)...
 
-                  libmass::CrossLink *crossLink = crossLinkList.at(kter);
+                  libXpertMass::CrossLink *crossLink = crossLinkList.at(kter);
 
                   crossLink->accountMasses(&ponderable, 1);
 
@@ -938,9 +938,9 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
       // residual-chain-only formula. The new formula will get updated each time
       // a new aspect of the fragmentation chemistry will be accounted for.
 
-      libmass::Ponderable ponderableTemp(ponderable);
+      libXpertMass::Ponderable ponderableTemp(ponderable);
 
-      libmass::Formula frag_chemistry_formula(residue_chain_formula);
+      libXpertMass::Formula frag_chemistry_formula(residue_chain_formula);
 
       // FragOptions is a FragSpec that holds the formula that makes a fragment
       // out of an oligomer.
@@ -963,7 +963,7 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
 
       // Account for the left cap since we are dealing with fragments that
       // retain the left end.
-      libmass::Formula formula = mcsp_polChemDef->leftCap();
+      libXpertMass::Formula formula = mcsp_polChemDef->leftCap();
 
       formula.accountMasses(isotopic_data_csp, &ponderableTemp, 1);
 
@@ -975,12 +975,12 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
       //<< frag_chemistry_formula.toString();
 
       if(m_calcOptions.polymerEntities() &
-           libmass::POLYMER_CHEMENT_LEFT_END_MODIF &&
+           libXpertMass::POLYMER_CHEMENT_LEFT_END_MODIF &&
          !fragOptions.startIndex())
         {
-          libmass::Polymer::accountEndModifMasses(
+          libXpertMass::Polymer::accountEndModifMasses(
             mp_polymer,
-            libmass::POLYMER_CHEMENT_LEFT_END_MODIF,
+            libXpertMass::POLYMER_CHEMENT_LEFT_END_MODIF,
             &ponderableTemp);
 
           frag_chemistry_formula.accountFormula(
@@ -992,7 +992,7 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
         }
 
       // The polymer chemistry definition defines a formula for the
-      // libmass::FragSpec that yields a fragment oligomer having no charge: in
+      // libXpertMass::FragSpec that yields a fragment oligomer having no charge: in
       // a neutral state.
 
       // We create an oligomer which is not ionized(false) but that
@@ -1015,10 +1015,10 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
       // oligomer as naked as possible. We'll dress it with formulas as we go.
       // Naked here means just account for the monomers (that its the monomers
       // and not the monomers along with the end caps, the charge and so on).
-      libmass::CalcOptions localOptions = m_calcOptions;
-      localOptions.setCapping(libmass::CAP_NONE);
+      libXpertMass::CalcOptions localOptions = m_calcOptions;
+      localOptions.setCapping(libXpertMass::CAP_NONE);
 
-      libmass::IonizeRule ionizeRule(m_ionizeRule);
+      libXpertMass::IonizeRule ionizeRule(m_ionizeRule);
       ionizeRule.setLevel(0);
 
       // Create a fragmentation oligomer by constructing it with the
@@ -1058,7 +1058,7 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
 
       if(monomerContrib)
         {
-          const libmass::Monomer *monomer = mp_polymer->at(iter);
+          const libXpertMass::Monomer *monomer = mp_polymer->at(iter);
 
           if(!monomer->accountMasses(
                &oligomer1_sp->rmono(), &oligomer1_sp->ravg(), monomerContrib))
@@ -1087,13 +1087,13 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
           // that the user might want to calculate fragment m/z with
           // z>1.
 
-          libmass::FragRule *fragRule = fragOptions.ruleList().at(jter);
+          libXpertMass::FragRule *fragRule = fragOptions.ruleList().at(jter);
 
           // This round is not for real accounting, but only to check of the
           // currently iterated frag rule should be accounted for (see the true
           // that indicates this call is only for checking).
           if(!accountFragRule(
-               fragRule, true, iter, libmass::FRAG_END_LEFT, nullptr))
+               fragRule, true, iter, libXpertMass::FRAG_END_LEFT, nullptr))
             continue;
 
           // This is why we first check above if the frag rule was to be
@@ -1106,7 +1106,7 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
           if(!accountFragRule(fragRule,
                               false,
                               iter,
-                              libmass::FRAG_END_LEFT,
+                              libXpertMass::FRAG_END_LEFT,
                               oligomer2_sp.get()))
             {
               oligomer1_sp.reset();
@@ -1328,7 +1328,7 @@ Fragmenter::fragmentEndLeft(FragOptions &fragOptions)
 
           while(!ionizeLevelOligomerList->isEmpty())
             {
-              libmass::OligomerSPtr iter_oligomer_sp =
+              libXpertMass::OligomerSPtr iter_oligomer_sp =
                 ionizeLevelOligomerList->takeFirst();
 
               mp_oligomerList->append(iter_oligomer_sp);
@@ -1370,17 +1370,17 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
 
   // qDebug() << "FragOptions:" << fragOptions.toString();
 
-  static libmass::Ponderable ponderable;
+  static libXpertMass::Ponderable ponderable;
   ponderable.clearMasses();
 
   // Formula to hold the summative result of accounting all of the chemical
   // entities making the oligomers. This formula is used for the moment, while
   // no FragmentOligomer has been allocated yet.
-  static libmass::Formula residue_chain_formula;
+  static libXpertMass::Formula residue_chain_formula;
   residue_chain_formula.clear();
 
   // We will need the isotopic data throughout all of this function.
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     mcsp_polChemDef->getIsotopicDataCstSPtr();
 
 
@@ -1426,7 +1426,7 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
       bool fragRuleApplied = false;
 
       // Get a pointer to the polymer's monomer at index iter.
-      const libmass::Monomer *monomer = mp_polymer->at(iter);
+      const libXpertMass::Monomer *monomer = mp_polymer->at(iter);
 
       // qDebug() << "Before accounting for monomer" << monomer->code()
       //<< "of formula, the residue_chain_formula: "
@@ -1447,7 +1447,7 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
       // Ask the monomer to actually compute its formula either by taking into
       // account the modifications or not depending on the calculation options
       // below.
-      libmass::Formula monomer_formula =
+      libXpertMass::Formula monomer_formula =
         monomer->calculateFormula(m_calcOptions.monomerEntities());
 
       //qDebug() << "Before accounting for monomer formula:"
@@ -1484,7 +1484,7 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
               // ... if so, iterate in the list of cross-links that
               // is stored in the CrossLinkedRegion...
 
-              const QList<libmass::CrossLink *> &crossLinkList =
+              const QList<libXpertMass::CrossLink *> &crossLinkList =
                 region->crossLinkList();
 
               for(int kter = 0; kter < crossLinkList.size(); ++kter)
@@ -1492,7 +1492,7 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
                   // ... and for each cross-link, account its mass
                   // in the fragment (that is, ponderable)...
 
-                  libmass::CrossLink *crossLink = crossLinkList.at(kter);
+                  libXpertMass::CrossLink *crossLink = crossLinkList.at(kter);
 
                   crossLink->accountMasses(&ponderable, 1);
 
@@ -1515,9 +1515,9 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
       // residual-chain-only formula. The new formula will get updated each time
       // a new aspect of the fragmentation chemistry will be accounted for.
 
-      libmass::Ponderable ponderableTemp(ponderable);
+      libXpertMass::Ponderable ponderableTemp(ponderable);
 
-      libmass::Formula frag_chemistry_formula(residue_chain_formula);
+      libXpertMass::Formula frag_chemistry_formula(residue_chain_formula);
 
       // FragOptions is a FragSpec that holds the formula that makes a fragment
       // out of an oligomer.
@@ -1540,7 +1540,7 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
 
       // Account for the right cap since we are dealing with fragments that
       // retain the right end.
-      libmass::Formula formula = mcsp_polChemDef->rightCap();
+      libXpertMass::Formula formula = mcsp_polChemDef->rightCap();
 
       formula.accountMasses(isotopic_data_csp, &ponderableTemp, 1);
 
@@ -1552,12 +1552,12 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
       //<< frag_chemistry_formula.toString();
 
       if(m_calcOptions.polymerEntities() &
-           libmass::POLYMER_CHEMENT_RIGHT_END_MODIF &&
+           libXpertMass::POLYMER_CHEMENT_RIGHT_END_MODIF &&
          fragOptions.endIndex() == mp_polymer->size() - 1)
         {
-          libmass::Polymer::accountEndModifMasses(
+          libXpertMass::Polymer::accountEndModifMasses(
             mp_polymer,
-            libmass::POLYMER_CHEMENT_RIGHT_END_MODIF,
+            libXpertMass::POLYMER_CHEMENT_RIGHT_END_MODIF,
             &ponderableTemp);
 
           frag_chemistry_formula.accountFormula(
@@ -1569,7 +1569,7 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
         }
 
       // The polymer chemistry definition defines a formula for the
-      // libmass::FragSpec that yields a fragment oligomer having no charge: in
+      // libXpertMass::FragSpec that yields a fragment oligomer having no charge: in
       // a neutral state.
 
       // We create an oligomer which is not ionized(false) but that
@@ -1592,10 +1592,10 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
       // oligomer as naked as possible. We'll dress it with formulas as we go.
       // Naked here means just account for the monomers (that its the monomers
       // and not the monomers along with the end caps, the charge and so on).
-      libmass::CalcOptions localOptions = m_calcOptions;
-      localOptions.setCapping(libmass::CAP_NONE);
+      libXpertMass::CalcOptions localOptions = m_calcOptions;
+      localOptions.setCapping(libXpertMass::CAP_NONE);
 
-      libmass::IonizeRule ionizeRule(m_ionizeRule);
+      libXpertMass::IonizeRule ionizeRule(m_ionizeRule);
       ionizeRule.setLevel(0);
 
       // Create a fragmentation oligomer by constructing it with the
@@ -1635,7 +1635,7 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
 
       if(monomerContrib)
         {
-          const libmass::Monomer *monomer = mp_polymer->at(iter);
+          const libXpertMass::Monomer *monomer = mp_polymer->at(iter);
 
           if(!monomer->accountMasses(
                &oligomer1_sp->rmono(), &oligomer1_sp->ravg(), monomerContrib))
@@ -1664,12 +1664,12 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
           // that the user might want to calculate fragment m/z with
           // z>1.
 
-          libmass::FragRule *fragRule = fragOptions.ruleList().at(jter);
+          libXpertMass::FragRule *fragRule = fragOptions.ruleList().at(jter);
 
           // This round is not for real accounting, but only to check of the
           // currently iterated frag rule should be accounted for (see the true
           // that indicates this call is only for checking).
-          if(!accountFragRule(fragRule, true, iter, libmass::FRAG_END_RIGHT, 0))
+          if(!accountFragRule(fragRule, true, iter, libXpertMass::FRAG_END_RIGHT, 0))
             continue;
 
           // This is why we first check above if the frag rule was to be
@@ -1682,7 +1682,7 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
           if(!accountFragRule(fragRule,
                               false,
                               iter,
-                              libmass::FRAG_END_RIGHT,
+                              libXpertMass::FRAG_END_RIGHT,
                               oligomer2_sp.get()))
             {
               oligomer1_sp.reset();
@@ -1904,7 +1904,7 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
 
           while(!ionizeLevelOligomerList->isEmpty())
             {
-              libmass::OligomerSPtr iter_oligomer_sp =
+              libXpertMass::OligomerSPtr iter_oligomer_sp =
                 ionizeLevelOligomerList->takeFirst();
 
               mp_oligomerList->append(iter_oligomer_sp);
@@ -1939,16 +1939,16 @@ Fragmenter::fragmentEndRight(FragOptions &fragOptions)
 
 
 bool
-Fragmenter::accountFragRule(libmass::FragRule *fragRule,
+Fragmenter::accountFragRule(libXpertMass::FragRule *fragRule,
                             bool onlyCheck,
                             int index,
                             int fragEnd,
-                            libmass::Ponderable *ponderable)
+                            libXpertMass::Ponderable *ponderable)
 {
-  const libmass::Monomer *prevMonomer = 0;
-  const libmass::Monomer *nextMonomer = 0;
+  const libXpertMass::Monomer *prevMonomer = 0;
+  const libXpertMass::Monomer *nextMonomer = 0;
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     mcsp_polChemDef->getIsotopicDataCstSPtr();
 
   Q_ASSERT(fragRule);
@@ -1957,7 +1957,7 @@ Fragmenter::accountFragRule(libmass::FragRule *fragRule,
     Q_ASSERT(ponderable);
 
 
-  const libmass::Monomer *monomer = mp_polymer->at(index);
+  const libXpertMass::Monomer *monomer = mp_polymer->at(index);
 
   if(!fragRule->currCode().isEmpty())
     if(fragRule->currCode() != monomer->code())
@@ -1965,7 +1965,7 @@ Fragmenter::accountFragRule(libmass::FragRule *fragRule,
 
   if(!fragRule->prevCode().isEmpty() && !fragRule->nextCode().isEmpty())
     {
-      if(fragEnd & libmass::FRAG_END_LEFT || fragEnd & libmass::FRAG_END_NONE)
+      if(fragEnd & libXpertMass::FRAG_END_LEFT || fragEnd & libXpertMass::FRAG_END_NONE)
         {
           if(!index)
             // There cannot be any prevCode since we are at index ==
@@ -1986,7 +1986,7 @@ Fragmenter::accountFragRule(libmass::FragRule *fragRule,
 
           nextMonomer = mp_polymer->at(index + 1);
         }
-      else if(fragEnd & libmass::FRAG_END_RIGHT)
+      else if(fragEnd & libXpertMass::FRAG_END_RIGHT)
         {
           if(!index)
             // There cannot be any nextCode since currCode is the last
@@ -2040,7 +2040,7 @@ Fragmenter::accountFragRule(libmass::FragRule *fragRule,
   //   !fragRule->nextCode().isEmpty())
   else if(!fragRule->prevCode().isEmpty())
     {
-      if(fragEnd & libmass::FRAG_END_LEFT || fragEnd & libmass::FRAG_END_NONE)
+      if(fragEnd & libXpertMass::FRAG_END_LEFT || fragEnd & libXpertMass::FRAG_END_NONE)
         {
           if(!index)
             // There cannot be any prevCode since currCode is already
@@ -2052,7 +2052,7 @@ Fragmenter::accountFragRule(libmass::FragRule *fragRule,
 
           prevMonomer = mp_polymer->at(index - 1);
         }
-      else if(fragEnd & libmass::FRAG_END_RIGHT)
+      else if(fragEnd & libXpertMass::FRAG_END_RIGHT)
         {
           if(index == mp_polymer->size() - 1)
             // There cannot be any prevCode since currCode is already
@@ -2096,7 +2096,7 @@ Fragmenter::accountFragRule(libmass::FragRule *fragRule,
   // else if (!fragRule->prevCode().isEmpty())
   else if(!fragRule->nextCode().isEmpty())
     {
-      if(fragEnd & libmass::FRAG_END_LEFT || fragEnd & libmass::FRAG_END_NONE)
+      if(fragEnd & libXpertMass::FRAG_END_LEFT || fragEnd & libXpertMass::FRAG_END_NONE)
         {
           if(index == mp_polymer->size() - 1)
             // There cannot be any nextCode since currCode is already
@@ -2108,7 +2108,7 @@ Fragmenter::accountFragRule(libmass::FragRule *fragRule,
 
           nextMonomer = mp_polymer->at(index + 1);
         }
-      else if(fragEnd & libmass::FRAG_END_RIGHT)
+      else if(fragEnd & libXpertMass::FRAG_END_RIGHT)
         {
           if(!index)
             // There cannot be any prevCode since currCode is already
@@ -2188,7 +2188,7 @@ Fragmenter::accountFormulas(OligomerList *oligomerList,
   if(!oligomerList->size())
     qDebug() << "The oligomer list is empty.";
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     mcsp_polChemDef->getIsotopicDataCstSPtr();
 
   int count = 0;
@@ -2204,11 +2204,11 @@ Fragmenter::accountFormulas(OligomerList *oligomerList,
   // At this point check if the fragOptions.m_formulaList has items
   // in it.
 
-  const QList<libmass::Formula *> &formulaList = fragOptions.formulaList();
+  const QList<libXpertMass::Formula *> &formulaList = fragOptions.formulaList();
 
   for(int iter = 0; iter < formulaList.size(); ++iter)
     {
-      libmass::Formula *formula = formulaList.at(iter);
+      libXpertMass::Formula *formula = formulaList.at(iter);
 
       // qDebug() << "Handling supplementary formula:" << formula->toString();
 
@@ -2267,7 +2267,7 @@ Fragmenter::accountIonizationLevels(OligomerList *oligomerList,
 
   bool wasFailure = false;
 
-  libmass::IsotopicDataCstSPtr isotopic_data_csp =
+  libXpertMass::IsotopicDataCstSPtr isotopic_data_csp =
     mcsp_polChemDef->getIsotopicDataCstSPtr();
 
   // We ge a list of oligomers (or only one, in fact, if no
@@ -2308,7 +2308,7 @@ Fragmenter::accountIonizationLevels(OligomerList *oligomerList,
 
       for(int kter = startIonizeLevel; kter < endIonizeLevel + 1; ++kter)
         {
-          libmass::IonizeRule ionizeRule(m_ionizeRule);
+          libXpertMass::IonizeRule ionizeRule(m_ionizeRule);
           ionizeRule.setLevel(kter);
 
           FragmentOligomerSPtr new_oligomer_sp =
@@ -2427,4 +2427,4 @@ Fragmenter::emptyOligomerList()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
