@@ -32,15 +32,15 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/Polymer.hpp>
-#include <libmass/Oligomer.hpp>
+#include <libXpertMass/Polymer.hpp>
+#include <libXpertMass/Oligomer.hpp>
 
 
 /////////////////////// Local includes
 #include "OligomerList.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace massxpert
@@ -48,15 +48,15 @@ namespace massxpert
 
 
 OligomerList::OligomerList(QString name,
-                           libmass::Polymer *polymer,
-                           libmass::MassType massType)
+                           libXpertMass::Polymer *polymer,
+                           libXpertMass::MassType massType)
   : m_name(name), mp_polymer(polymer), m_massType(massType)
 {
 }
 
 
 OligomerList::OligomerList(const OligomerList *other)
-  : QList<libmass::OligomerSPtr>(*other),
+  : QList<libXpertMass::OligomerSPtr>(*other),
     m_name(other->m_name),
     m_comment(other->m_comment),
     mp_polymer(other->mp_polymer),
@@ -64,7 +64,7 @@ OligomerList::OligomerList(const OligomerList *other)
 {
   // And now copy all the items from other in here:
   for(int iter = 0; iter < other->size(); ++iter)
-    append(std::make_shared<libmass::Oligomer>(*other->at(iter)));
+    append(std::make_shared<libXpertMass::Oligomer>(*other->at(iter)));
 }
 
 
@@ -110,7 +110,7 @@ OligomerList::comment() const
 }
 
 
-const libmass::Polymer *
+const libXpertMass::Polymer *
 OligomerList::polymer() const
 {
   return mp_polymer;
@@ -118,20 +118,20 @@ OligomerList::polymer() const
 
 
 void
-OligomerList::setMassType(libmass::MassType massType)
+OligomerList::setMassType(libXpertMass::MassType massType)
 {
   m_massType = massType;
 }
 
 
-libmass::MassType
+libXpertMass::MassType
 OligomerList::massType() const
 {
   return m_massType;
 }
 
 
-libmass::OligomerSPtr
+libXpertMass::OligomerSPtr
 OligomerList::findOligomerEncompassing(int index, int *listIndex)
 {
   // Is there any oligomer that emcompasses the index ? If so return
@@ -153,7 +153,7 @@ OligomerList::findOligomerEncompassing(int index, int *listIndex)
 
   for(; iter < size(); ++iter)
     {
-      libmass::OligomerSPtr oligomer_sp = at(iter);
+      libXpertMass::OligomerSPtr oligomer_sp = at(iter);
 
       if(oligomer_sp->encompasses(index))
         {
@@ -168,8 +168,8 @@ OligomerList::findOligomerEncompassing(int index, int *listIndex)
 }
 
 
-libmass::OligomerSPtr
-OligomerList::findOligomerEncompassing(const libmass::Monomer *monomer,
+libXpertMass::OligomerSPtr
+OligomerList::findOligomerEncompassing(const libXpertMass::Monomer *monomer,
                                        int *listIndex)
 {
   // Is there any oligomer that emcompasses the monomer ? If so return
@@ -193,7 +193,7 @@ OligomerList::findOligomerEncompassing(const libmass::Monomer *monomer,
 
   for(; iter < size(); ++iter)
     {
-      libmass::OligomerSPtr oligomer_sp = at(iter);
+      libXpertMass::OligomerSPtr oligomer_sp = at(iter);
 
       if(oligomer_sp->encompasses(monomer))
         {
@@ -209,19 +209,19 @@ OligomerList::findOligomerEncompassing(const libmass::Monomer *monomer,
 
 
 QString *
-OligomerList::makeMassText(libmass::MassType massType)
+OligomerList::makeMassText(libXpertMass::MassType massType)
 {
   QString *text = new QString();
 
-  libmass::MassType localMassType = libmass::MassType::MASS_NONE;
+  libXpertMass::MassType localMassType = libXpertMass::MassType::MASS_NONE;
 
-  if(massType == libmass::MassType::MASS_BOTH)
+  if(massType == libXpertMass::MassType::MASS_BOTH)
     {
       delete text;
       return 0;
     }
 
-  if(massType & libmass::MassType::MASS_NONE)
+  if(massType & libXpertMass::MassType::MASS_NONE)
     localMassType = m_massType;
   else
     localMassType = massType;
@@ -230,13 +230,13 @@ OligomerList::makeMassText(libmass::MassType massType)
     {
       double value = 0;
 
-      if(localMassType & libmass::MassType::MASS_MONO)
+      if(localMassType & libXpertMass::MassType::MASS_MONO)
         value = at(iter)->mono();
       else
         value = at(iter)->avg();
 
       QString mass;
-      mass.setNum(value, 'f', libmass::OLIGOMER_DEC_PLACES);
+      mass.setNum(value, 'f', libXpertMass::OLIGOMER_DEC_PLACES);
 
       text->append(mass + "\n");
     }
@@ -246,8 +246,8 @@ OligomerList::makeMassText(libmass::MassType massType)
 
 
 bool
-OligomerList::lessThanMono(const libmass::OligomerSPtr o1,
-                           const libmass::OligomerSPtr o2)
+OligomerList::lessThanMono(const libXpertMass::OligomerSPtr o1,
+                           const libXpertMass::OligomerSPtr o2)
 {
   qDebug() << "o1 is:" << o1.get() << "o2 is:" << o2.get();
 
@@ -256,8 +256,8 @@ OligomerList::lessThanMono(const libmass::OligomerSPtr o1,
 
 
 bool
-OligomerList::lessThanAvg(const libmass::OligomerSPtr o1,
-                          const libmass::OligomerSPtr o2)
+OligomerList::lessThanAvg(const libXpertMass::OligomerSPtr o1,
+                          const libXpertMass::OligomerSPtr o2)
 {
   qDebug() << "o1 is:" << o1.get() << "o2 is:" << o2.get();
 
@@ -272,8 +272,8 @@ OligomerList::sortAscending()
   // handle, and that cannot be anything other than MassType::MASS_MONO
   // or MASS_AVG.
 
-  if(m_massType == libmass::MassType::MASS_BOTH ||
-     m_massType & libmass::MassType::MASS_NONE)
+  if(m_massType == libXpertMass::MassType::MASS_BOTH ||
+     m_massType & libXpertMass::MassType::MASS_NONE)
     {
       qDebug() << "Could not sort the oligomer list: "
                   "m_massType is not correct";
@@ -281,7 +281,7 @@ OligomerList::sortAscending()
       return;
     }
 
-  if(m_massType == libmass::MassType::MASS_MONO)
+  if(m_massType == libXpertMass::MassType::MASS_MONO)
     std::sort(begin(), end(), OligomerList::lessThanMono);
   else
     std::sort(begin(), end(), OligomerList::lessThanAvg);
@@ -289,4 +289,4 @@ OligomerList::sortAscending()
 
 } // namespace massxpert
 
-} // namespace msxps
+} // namespace MsXpS
